@@ -28,7 +28,10 @@ if [[ -z "${TAR}" ]]; then
 fi
 
 if [[ -z "${SHASUM}" ]]; then
-  SHASUM="/usr/bin/shasum"
+  SHASUM="sha512sum"
+  if [ "$(uname -s)" = "Darwin" ]; then
+    SHASUM="shasum -a 512"
+  fi
 fi
 
 if [[ -z "${WORKING_DIR}" ]]; then
@@ -50,7 +53,7 @@ usage() {
 function git_clone() {
   echo "Clone the source"
   # clone source
-  git clone https://github.com/apache/zeppelin "${WORKING_DIR}/zeppelin"
+  git clone https://gitbox.apache.org/repos/asf/zeppelin.git "${WORKING_DIR}/zeppelin"
 
   if [[ $? -ne 0 ]]; then
     echo "Can not clone source repository"
