@@ -46,7 +46,7 @@ if [[ $RELEASE_VERSION == *"SNAPSHOT"* ]]; then
   DO_SNAPSHOT="yes"
 fi
 
-PUBLISH_PROFILES="-Ppublish-distr -Pweb-angular"
+PUBLISH_PROFILES="-Ppublish-distr -Pweb-classic"
 PROJECT_OPTIONS="-pl !zeppelin-distribution -Dmaven.javadoc.skip=true"
 NEXUS_STAGING="https://repository.apache.org/service/local/staging"
 NEXUS_PROFILE="153446d1ac37c4"
@@ -138,9 +138,8 @@ function publish_to_maven() {
 
   echo "Creating hash and signature files"
   for file in $(find . -type f); do
-    gpg --batch --pinentry-mode loopback --passphrase "${GPG_PASSPHRASE}" --armor \
-      --output "${file}.asc" \
-      --detach-sig "${file}"
+    echo "${GPG_PASSPHRASE}" | gpg --passphrase-fd 0 --output "${file}.asc" \
+      --detach-sig --armor "${file}"
     md5 -q "${file}" > "${file}.md5"
     ${SHASUM} -a 1 "${file}" | cut -f1 -d' ' > "${file}.sha1"
   done
