@@ -44,6 +44,7 @@ import org.apache.flink.table.catalog.hive.HiveCatalog
 import org.apache.flink.table.functions.{AggregateFunction, ScalarFunction, TableAggregateFunction, TableFunction}
 import org.apache.flink.table.module.hive.HiveModule
 import org.apache.flink.yarn.cli.FlinkYarnSessionCli
+import org.apache.zeppelin.conf.ZeppelinConfiguration
 import org.apache.zeppelin.dep.DependencyResolver
 import org.apache.zeppelin.flink.internal.FlinkShell
 import org.apache.zeppelin.flink.internal.FlinkShell._
@@ -65,7 +66,8 @@ import scala.tools.nsc.interpreter.{Completion, IMain, IR, JPrintWriter, Results
  * @param properties
  */
 abstract class FlinkScalaInterpreter(val properties: Properties,
-                                     val flinkScalaClassLoader: ClassLoader) {
+                                     val flinkScalaClassLoader: ClassLoader,
+                                     val zConf: ZeppelinConfiguration) {
 
   private lazy val LOGGER: Logger = LoggerFactory.getLogger(getClass)
 
@@ -491,7 +493,7 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
       throw new InterpreterException("HIVE_CONF_DIR is not specified");
     }
     val database = properties.getProperty("zeppelin.flink.hive.database", "default")
-    val hiveVersion = properties.getProperty("zeppelin.flink.hive.version", "2.3.4")
+    val hiveVersion = properties.getProperty("zeppelin.flink.hive.version", "2.3.7")
     val hiveCatalog = new HiveCatalog("hive", database, hiveConfDir.toString, hiveVersion)
     this.btenv.registerCatalog("hive", hiveCatalog)
     this.btenv.useCatalog("hive")
@@ -798,7 +800,7 @@ abstract class FlinkScalaInterpreter(val properties: Properties,
     val flinkPackageJars =
       if (!StringUtils.isBlank(properties.getProperty("flink.execution.packages", ""))) {
         val packages = properties.getProperty("flink.execution.packages")
-        val dependencyResolver = new DependencyResolver(System.getProperty("user.home") + "/.m2/repository")
+        val dependencyResolver = new DependencyResolver(System.getProperty("user.home") + "/.m2/repository", zConf)
         packages.split(",")
           .flatMap(e => JavaConversions.asScalaBuffer(dependencyResolver.load(e)))
           .map(e => e.getAbsolutePath).toSeq
