@@ -71,7 +71,7 @@ import static org.mockito.Mockito.mock;
 @RunWith(FlinkStandaloneHiveRunner.class)
 public abstract class FlinkSqlInterpreterTest {
 
-  protected static final Logger LOGGER = LoggerFactory.getLogger(FlinkSqlInterpreterTest.class);
+  private static final Logger LOGGER = LoggerFactory.getLogger(FlinkSqlInterpreterTest.class);
 
 
   protected FlinkInterpreter flinkInterpreter;
@@ -90,7 +90,7 @@ public abstract class FlinkSqlInterpreterTest {
     p.setProperty("zeppelin.flink.enableHive", "true");
     p.setProperty("taskmanager.managed.memory.size", "32");
     p.setProperty("taskmanager.memory.task.off-heap.size", "80mb");
-    p.setProperty("zeppelin.flink.hive.version", "2.3.4");
+    p.setProperty("zeppelin.flink.hive.version", "2.3.7");
     p.setProperty("zeppelin.pyflink.useIPython", "false");
     p.setProperty("local.number-taskmanager", "4");
     p.setProperty("zeppelin.python.gatewayserver_address", "127.0.0.1");
