@@ -17,6 +17,12 @@
 
 package org.apache.zeppelin.shell;
 
+import java.util.Arrays;
+import java.util.List;
+import java.util.Map;
+import javax.websocket.ClientEndpointConfig;
+import javax.websocket.ClientEndpointConfig.Builder;
+import javax.websocket.ClientEndpointConfig.Configurator;
 import org.apache.zeppelin.interpreter.InterpreterContext;
 import org.apache.zeppelin.interpreter.InterpreterException;
 import org.apache.zeppelin.interpreter.InterpreterResult;
@@ -34,6 +40,7 @@ import javax.websocket.Session;
 import javax.websocket.WebSocketContainer;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
@@ -81,11 +88,17 @@ class TerminalInterpreterTest extends BaseInterpreterTest {
       boolean running = terminal.terminalThreadIsRunning();
       assertTrue(running);
 
-      URI uri = URI.create("ws://localhost:" + terminal.getTerminalPort() + "/terminal/");
+      URI webSocketConnectionUri = URI.create("ws://" + terminal.getTerminalHostIp() +
+          ":" + terminal.getTerminalPort() + "/terminal/");
+      LOGGER.info("webSocketConnectionUri: " + webSocketConnectionUri);
+      String origin = "http://" + terminal.getTerminalHostIp() + ":" + terminal.getTerminalPort();
+      LOGGER.info("origin: " + origin);
+      ClientEndpointConfig clientEndpointConfig = getOriginRequestHeaderConfig(origin);
       webSocketContainer = ContainerProvider.getWebSocketContainer();
 
       // Attempt Connect
-      session = webSocketContainer.connectToServer(TerminalSocketTest.class, uri);
+      session = webSocketContainer.connectToServer(
+          TerminalSocketTest.class, clientEndpointConfig, webSocketConnectionUri);
 
       // Send Start terminal service message
       String terminalReadyCmd = String.format("{\"type\":\"TERMINAL_READY\"," +
@@ -161,11 +174,17 @@ class TerminalInterpreterTest extends BaseInterpreterTest {
       boolean running = terminal.terminalThreadIsRunning();
       assertTrue(running);
 
-      URI uri = URI.create("ws://localhost:" + terminal.getTerminalPort() + "/terminal/");
+      URI webSocketConnectionUri = URI.create("ws://" + terminal.getTerminalHostIp() +
+          ":" + terminal.getTerminalPort() + "/terminal/");
+      LOGGER.info("webSocketConnectionUri: " + webSocketConnectionUri);
+      String origin = "http://" + terminal.getTerminalHostIp() + ":" + terminal.getTerminalPort();
+      LOGGER.info("origin: " + origin);
+      ClientEndpointConfig clientEndpointConfig = getOriginRequestHeaderConfig(origin);
       webSocketContainer = ContainerProvider.getWebSocketContainer();
 
       // Attempt Connect
-      session = webSocketContainer.connectToServer(TerminalSocketTest.class, uri);
+      session = webSocketContainer.connectToServer(
+          TerminalSocketTest.class, clientEndpointConfig, webSocketConnectionUri);
 
       // Send Start terminal service message
       String terminalReadyCmd = String.format("{\"type\":\"TERMINAL_READY\"," +
@@ -229,4 +248,118 @@ class TerminalInterpreterTest extends BaseInterpreterTest {
       }
     }
   }
+
+  @Test
+  void testValidOrigin() {
+    Session session = null;
+
+    // mock connect terminal
+    boolean running = terminal.terminalThreadIsRunning();
+    assertTrue(running);
+
+    URI webSocketConnectionUri = URI.create("ws://" + terminal.getTerminalHostIp() +
+        ":" + terminal.getTerminalPort() + "/terminal/");
+    LOGGER.info("webSocketConnectionUri: " + webSocketConnectionUri);
+    String origin = "http://" + terminal.getTerminalHostIp() + ":" + terminal.getTerminalPort();
+    LOGGER.info("origin: " + origin);
+    ClientEndpointConfig clientEndpointConfig = getOriginRequestHeaderConfig(origin);
+    WebSocketContainer webSocketContainer = ContainerProvider.getWebSocketContainer();
+
+    Throwable exception = null;
+    try {
+      // Attempt Connect
+      session = webSocketContainer.connectToServer(
+          TerminalSocketTest.class, clientEndpointConfig, webSocketConnectionUri);
+    } catch (DeploymentException e) {
+      exception = e;
+    } catch (IOException e) {
+      exception = e;
+    } finally {
+      if (session != null) {
+        try {
+          session.close();
+        } catch (IOException e) {
+          LOGGER.error(e.getMessage(), e);
+        }
+      }
+
+      // Force lifecycle stop when done with container.
+      // This is to free up threads and resources that the
+      // JSR-356 container allocates. But unfortunately
+      // the JSR-356 spec does not handle lifecycles (yet)
+      if (webSocketContainer instanceof LifeCycle) {
+        try {
+          ((LifeCycle) webSocketContainer).stop();
+        } catch (Exception e) {
+          LOGGER.error(e.getMessage(), e);
+        }
+      }
+    }
+
+    assertNull(exception);
+  }
+
+  @Test
+  void testInvalidOrigin() {
+    Session session = null;
+
+    // mock connect terminal
+    boolean running = terminal.terminalThreadIsRunning();
+    assertTrue(running);
+
+    URI webSocketConnectionUri = URI.create("ws://" + terminal.getTerminalHostIp() +
+        ":" + terminal.getTerminalPort() + "/terminal/");
+    LOGGER.info("webSocketConnectionUri: " + webSocketConnectionUri);
+    String origin = "http://invalid-origin";
+    LOGGER.info("origin: " + origin);
+    ClientEndpointConfig clientEndpointConfig = getOriginRequestHeaderConfig(origin);
+    WebSocketContainer webSocketContainer = ContainerProvider.getWebSocketContainer();
+
+    Throwable exception = null;
+    try {
+      // Attempt Connect
+      session = webSocketContainer.connectToServer(
+          TerminalSocketTest.class, clientEndpointConfig, webSocketConnectionUri);
+    } catch (DeploymentException e) {
+      exception = e;
+    } catch (IOException e) {
+      exception = e;
+    } finally {
+      if (session != null) {
+        try {
+          session.close();
+        } catch (IOException e) {
+          LOGGER.error(e.getMessage(), e);
+        }
+      }
+
+      // Force lifecycle stop when done with container.
+      // This is to free up threads and resources that the
+      // JSR-356 container allocates. But unfortunately
+      // the JSR-356 spec does not handle lifecycles (yet)
+      if (webSocketContainer instanceof LifeCycle) {
+        try {
+          ((LifeCycle) webSocketContainer).stop();
+        } catch (Exception e) {
+          LOGGER.error(e.getMessage(), e);
+        }
+      }
+    }
+
+    assertTrue(exception instanceof IOException);
+    assertEquals("Connect failure", exception.getMessage());
+  }
+
+  private static ClientEndpointConfig getOriginRequestHeaderConfig(String origin) {
+    Configurator configurator = new Configurator() {
+      @Override
+      public void beforeRequest(Map<String, List<String>> headers) {
+        headers.put("Origin", Arrays.asList(origin));
+      }
+    };
+    ClientEndpointConfig clientEndpointConfig = Builder.create()
+        .configurator(configurator)
+        .build();
+    return clientEndpointConfig;
+  }
 }
