@@ -20,6 +20,7 @@ package org.apache.zeppelin.spark;
 import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.apache.spark.SparkContext;
 import org.apache.spark.sql.AnalysisException;
+import org.apache.spark.sql.SQLContext;
 import org.apache.zeppelin.interpreter.AbstractInterpreter;
 import org.apache.zeppelin.interpreter.ZeppelinContext;
 import org.apache.zeppelin.interpreter.InterpreterContext;
@@ -57,7 +58,7 @@ public class SparkSqlInterpreter extends AbstractInterpreter {
     this.sqlSplitter = new SqlSplitter();
   }
 
-  public boolean concurrentSQL() {
+  private boolean concurrentSQL() {
     return Boolean.parseBoolean(getProperty("zeppelin.spark.concurrentSQL"));
   }
 
@@ -83,7 +84,7 @@ public class SparkSqlInterpreter extends AbstractInterpreter {
     }
     Utils.printDeprecateMessage(sparkInterpreter.getSparkVersion(), context, properties);
     sparkInterpreter.getZeppelinContext().setInterpreterContext(context);
-    Object sqlContext = sparkInterpreter.getSQLContext();
+    SQLContext sqlContext = sparkInterpreter.getSQLContext();
     SparkContext sc = sparkInterpreter.getSparkContext();
 
     List<String> sqls = sqlSplitter.splitSql(st);
@@ -95,15 +96,11 @@ public class SparkSqlInterpreter extends AbstractInterpreter {
     String curSql = null;
     ClassLoader originalClassLoader = Thread.currentThread().getContextClassLoader();
     try {
-      if (!sparkInterpreter.isScala212()) {
-        // TODO(zjffdu) scala 2.12 still doesn't work for codegen (ZEPPELIN-4627)
       Thread.currentThread().setContextClassLoader(sparkInterpreter.getScalaShellClassLoader());
-      }
-      Method method = sqlContext.getClass().getMethod("sql", String.class);
       for (String sql : sqls) {
         curSql = sql;
         String result = sparkInterpreter.getZeppelinContext()
-                .showData(method.invoke(sqlContext, sql), maxResult);
+                .showData(sqlContext.sql(sql), maxResult);
         context.out.write(result);
       }
       context.out.flush();
@@ -115,14 +112,23 @@ public class SparkSqlInterpreter extends AbstractInterpreter {
           context.out.flush();
           return new InterpreterResult(Code.ERROR);
         } else {
+          LOGGER.error("Error happens in sql: {}", curSql, e);
           context.out.write("\nError happens in sql: " + curSql + "\n");
           if (Boolean.parseBoolean(getProperty("zeppelin.spark.sql.stacktrace", "false"))) {
-            context.out.write(ExceptionUtils.getStackTrace(e.getCause()));
+            if (e.getCause() != null) {
+              context.out.write(ExceptionUtils.getStackTrace(e.getCause()));
+            } else {
+              context.out.write(ExceptionUtils.getStackTrace(e));
+            }
           } else {
-            LOGGER.error("Invocation target exception", e);
-            String msg = e.getCause().getMessage()
-                    + "\nset zeppelin.spark.sql.stacktrace = true to see full stacktrace";
-            context.out.write(msg);
+            StringBuilder msgBuilder = new StringBuilder();
+            if (e.getCause() != null) {
+              msgBuilder.append(e.getCause().getMessage());
+            } else {
+              msgBuilder.append(e.getMessage());
+            }
+            msgBuilder.append("\nset zeppelin.spark.sql.stacktrace = true to see full stacktrace");
+            context.out.write(msgBuilder.toString());
           }
           context.out.flush();
           return new InterpreterResult(Code.ERROR);
@@ -133,9 +139,7 @@ public class SparkSqlInterpreter extends AbstractInterpreter {
       }
     } finally {
       sc.clearJobGroup();
-      if (!sparkInterpreter.isScala212()) {
-        Thread.currentThread().setContextClassLoader(originalClassLoader);
-      }
+      Thread.currentThread().setContextClassLoader(originalClassLoader);
     }
 
     return new InterpreterResult(Code.SUCCESS);
@@ -152,7 +156,6 @@ public class SparkSqlInterpreter extends AbstractInterpreter {
     return FormType.SIMPLE;
   }
 
-
   @Override
   public int getProgress(InterpreterContext context) throws InterpreterException {
     return sparkInterpreter.getProgress(context);
@@ -179,10 +182,4 @@ public class SparkSqlInterpreter extends AbstractInterpreter {
       }
     }
   }
-
-  @Override
-  public List<InterpreterCompletion> completion(String buf, int cursor,
-      InterpreterContext interpreterContext) {
-    return null;
-  }
 }
