@@ -43,12 +43,6 @@ public class ZeppelinITUtils {
     }
   }
 
-  public static void restartZeppelin() {
-    CommandExecutor.executeCommandLocalHost("../bin/zeppelin-daemon.sh restart",
-        false, ProcessData.Types_Of_Data.OUTPUT);
-    //wait for server to start.
-    sleep(5000, false);
-  }
 
   public static void turnOffImplicitWaits(WebDriver driver) {
     driver.manage().timeouts().implicitlyWait(Duration.ofSeconds(0));
