@@ -24,9 +24,12 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 import java.io.IOException;
 
 import org.apache.zeppelin.AbstractZeppelinIT;
+import org.apache.zeppelin.MiniZeppelinServer;
 import org.apache.zeppelin.WebDriverManager;
 import org.apache.zeppelin.ZeppelinITUtils;
+import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
@@ -50,19 +53,37 @@ import org.slf4j.LoggerFactory;
  *
  */
 class ZeppelinIT extends AbstractZeppelinIT {
-  private static final Logger LOG = LoggerFactory.getLogger(ZeppelinIT.class);
+  private static final Logger LOGGER = LoggerFactory.getLogger(ZeppelinIT.class);
 
+  private static MiniZeppelinServer zepServer;
+
+  @BeforeAll
+  static void init() throws Exception {
+
+    zepServer = new MiniZeppelinServer(ZeppelinIT.class.getSimpleName());
+    zepServer.addInterpreter("md");
+    zepServer.addInterpreter("angular");
+    zepServer.addInterpreter("sh");
+    zepServer.copyLogProperties();
+    zepServer.copyBinDir();
+    zepServer.start(true, ZeppelinIT.class.getSimpleName());
+  }
 
   @BeforeEach
   public void startUp() throws IOException {
-    manager = new WebDriverManager();
+    manager = new WebDriverManager(zepServer.getZeppelinConfiguration().getServerPort());
   }
 
   @AfterEach
-  public void tearDown() throws IOException {
+  public void tearDownManager() throws IOException {
     manager.close();
   }
 
+  @AfterAll
+  public static void tearDown() throws Exception {
+    zepServer.destroy();
+  }
+
   @Test
   @Disabled("Doesnt work")
   void testAngularDisplay() throws Exception {
@@ -192,7 +213,7 @@ class ZeppelinIT extends AbstractZeppelinIT {
           "//div[@class='modal-footer']//button[contains(.,'OK')]"));
       ZeppelinITUtils.sleep(100, false);
 
-      LOG.info("testCreateNotebook Test executed");
+      LOGGER.info("testCreateNotebook Test executed");
     } catch (Exception e) {
       handleException("Exception in ZeppelinIT while testAngularDisplay ", e);
     }
@@ -325,7 +346,7 @@ class ZeppelinIT extends AbstractZeppelinIT {
       deleteTestNotebook(manager.getWebDriver());
       ZeppelinITUtils.sleep(1000, false);
 
-      LOG.info("testAngularRunParagraph Test executed");
+      LOGGER.info("testAngularRunParagraph Test executed");
     }  catch (Exception e) {
       handleException("Exception in ZeppelinIT while testAngularRunParagraph", e);
     }
@@ -341,7 +362,7 @@ class ZeppelinIT extends AbstractZeppelinIT {
       waitForParagraph(1, "READY");
 
       String currentUrl = manager.getWebDriver().getCurrentUrl();
-      LOG.info("currentUrl = " + currentUrl);
+      LOGGER.info("currentUrl = " + currentUrl);
 
       //delete created notebook to trash
       deleteTestNotebook(manager.getWebDriver());
@@ -354,7 +375,7 @@ class ZeppelinIT extends AbstractZeppelinIT {
       // delete note from trash
       deleteTrashNotebook(manager.getWebDriver());
       ZeppelinITUtils.sleep(2000, false);
-      LOG.info("deleteTrashNode executed");
+      LOGGER.info("deleteTrashNode executed");
     }  catch (Exception e) {
       handleException("Exception in ZeppelinIT while deleteTrashNode", e);
     }
