@@ -18,11 +18,14 @@
 package org.apache.zeppelin.integration;
 
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.hdfs.MiniDFSCluster;
 import org.apache.hadoop.yarn.api.protocolrecords.GetApplicationsRequest;
 import org.apache.hadoop.yarn.api.protocolrecords.GetApplicationsResponse;
 import org.apache.hadoop.yarn.api.records.YarnApplicationState;
 import org.apache.hadoop.yarn.conf.YarnConfiguration;
 import org.apache.hadoop.yarn.exceptions.YarnException;
+import org.apache.zeppelin.test.DownloadUtils;
+import org.apache.zeppelin.MiniZeppelinServer;
 import org.apache.zeppelin.interpreter.ExecutionContext;
 import org.apache.zeppelin.interpreter.Interpreter;
 import org.apache.zeppelin.interpreter.InterpreterContext;
@@ -31,10 +34,9 @@ import org.apache.zeppelin.interpreter.InterpreterFactory;
 import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.interpreter.InterpreterSetting;
 import org.apache.zeppelin.interpreter.InterpreterSettingManager;
-import org.apache.zeppelin.interpreter.integration.DownloadUtils;
 import org.junit.jupiter.api.AfterAll;
-import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -47,15 +49,14 @@ import java.io.IOException;
 import java.util.EnumSet;
 
 public abstract class FlinkIntegrationTest {
-  private static Logger LOGGER = LoggerFactory.getLogger(FlinkIntegrationTest.class);
+  private static final Logger LOGGER = LoggerFactory.getLogger(FlinkIntegrationTest.class);
 
   private static MiniHadoopCluster hadoopCluster;
-  private static MiniZeppelin zeppelin;
+  private static MiniZeppelinServer zepServer;
   private static InterpreterFactory interpreterFactory;
   private static InterpreterSettingManager interpreterSettingManager;
 
   private String flinkVersion;
-  private String scalaVersion;
   private String hadoopHome;
   private String flinkHome;
 
@@ -63,34 +64,42 @@ public abstract class FlinkIntegrationTest {
     LOGGER.info("Testing FlinkVersion: " + flinkVersion);
     LOGGER.info("Testing ScalaVersion: " + scalaVersion);
     this.flinkVersion = flinkVersion;
-    this.scalaVersion = scalaVersion;
     this.flinkHome = DownloadUtils.downloadFlink(flinkVersion, scalaVersion);
-    this.hadoopHome = DownloadUtils.downloadHadoop("2.7.7");
+    this.hadoopHome = DownloadUtils.downloadHadoop("3.3.6");
   }
 
   @BeforeAll
-  public static void setUp() throws IOException {
+  public static void setUp() throws Exception {
     Configuration conf = new Configuration();
     conf.setBoolean(YarnConfiguration.YARN_MINICLUSTER_FIXED_PORTS, true);
+    conf.set(MiniDFSCluster.HDFS_MINIDFS_BASEDIR, "target/hadoop-minicluster");
     hadoopCluster = new MiniHadoopCluster(conf);
     hadoopCluster.start();
 
-    zeppelin = new MiniZeppelin();
-    zeppelin.start(FlinkIntegrationTest.class);
-    interpreterFactory = zeppelin.getInterpreterFactory();
-    interpreterSettingManager = zeppelin.getInterpreterSettingManager();
+    zepServer = new MiniZeppelinServer(FlinkIntegrationTest.class.getSimpleName());
+    zepServer.addInterpreter("flink");
+    zepServer.addInterpreter("flink-cmd");
+    zepServer.copyLogProperties();
+    zepServer.copyBinDir();
+    zepServer.addLauncher("YarnInterpreterLauncher");
+    zepServer.addLauncher("FlinkInterpreterLauncher");
+    zepServer.start();
   }
 
   @AfterAll
-  public static void tearDown() throws IOException {
-    if (zeppelin != null) {
-      zeppelin.stop();
-    }
+  public static void tearDown() throws Exception {
+    zepServer.destroy();
     if (hadoopCluster != null) {
       hadoopCluster.stop();
     }
   }
 
+  @BeforeEach
+  void setup() {
+    interpreterSettingManager = zepServer.getService(InterpreterSettingManager.class);
+    interpreterFactory = new InterpreterFactory(interpreterSettingManager);
+  }
+
   private void testInterpreterBasics() throws IOException, InterpreterException {
     // test FlinkInterpreter
     Interpreter flinkInterpreter = interpreterFactory.getInterpreter("flink", new ExecutionContext("user1", "note1", "flink"));
@@ -128,7 +137,7 @@ public abstract class FlinkIntegrationTest {
   public void testLocalMode() throws IOException, YarnException, InterpreterException {
     InterpreterSetting flinkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("flink");
     flinkInterpreterSetting.setProperty("FLINK_HOME", flinkHome);
-    flinkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
+    flinkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zepServer.getZeppelinConfiguration().getConfDir());
     flinkInterpreterSetting.setProperty("flink.execution.mode", "local");
 
     testInterpreterBasics();
@@ -141,14 +150,13 @@ public abstract class FlinkIntegrationTest {
     interpreterSettingManager.close();
   }
 
-  // TODO(zjffdu) enable it when make yarn integration test work
   @Test
   public void testYarnMode() throws IOException, InterpreterException, YarnException {
     InterpreterSetting flinkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("flink");
     flinkInterpreterSetting.setProperty("HADOOP_CONF_DIR", hadoopCluster.getConfigPath());
     flinkInterpreterSetting.setProperty("FLINK_HOME", flinkHome);
     flinkInterpreterSetting.setProperty("PATH", hadoopHome + "/bin:" + System.getenv("PATH"));
-    flinkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
+    flinkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zepServer.getZeppelinConfiguration().getConfDir());
     flinkInterpreterSetting.setProperty("flink.execution.mode", "yarn");
     flinkInterpreterSetting.setProperty("zeppelin.flink.run.asLoginUser", "false");
 
@@ -172,7 +180,7 @@ public abstract class FlinkIntegrationTest {
     flinkInterpreterSetting.setProperty("HADOOP_CONF_DIR", hadoopCluster.getConfigPath());
     flinkInterpreterSetting.setProperty("FLINK_HOME", flinkHome);
     flinkInterpreterSetting.setProperty("PATH", hadoopHome + "/bin:" + System.getenv("PATH"));
-    flinkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
+    flinkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zepServer.getZeppelinConfiguration().getConfDir());
     flinkInterpreterSetting.setProperty("flink.execution.mode", "yarn-application");
     // parameters with whitespace
     flinkInterpreterSetting.setProperty("flink.yarn.appName", "hello flink");
