@@ -17,7 +17,6 @@
 
 package org.apache.zeppelin.integration;
 
-import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.hadoop.yarn.api.protocolrecords.GetApplicationsRequest;
 import org.apache.hadoop.yarn.api.protocolrecords.GetApplicationsResponse;
@@ -27,6 +26,9 @@ import org.apache.hadoop.yarn.api.records.YarnApplicationState;
 import org.apache.hadoop.yarn.exceptions.YarnException;
 import org.apache.maven.model.Model;
 import org.apache.maven.model.io.xpp3.MavenXpp3Reader;
+import org.apache.zeppelin.test.DownloadUtils;
+import org.apache.zeppelin.MiniZeppelinServer;
+import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.interpreter.ExecutionContext;
 import org.apache.zeppelin.interpreter.Interpreter;
 import org.apache.zeppelin.interpreter.InterpreterContext;
@@ -36,7 +38,6 @@ import org.apache.zeppelin.interpreter.InterpreterOption;
 import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.interpreter.InterpreterSetting;
 import org.apache.zeppelin.interpreter.InterpreterSettingManager;
-import org.apache.zeppelin.interpreter.integration.DownloadUtils;
 import org.codehaus.plexus.util.xml.pull.XmlPullParserException;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
@@ -58,10 +59,9 @@ import java.util.List;
 import java.util.stream.Collectors;
 
 public abstract class SparkIntegrationTest {
-  private static Logger LOGGER = LoggerFactory.getLogger(SparkIntegrationTest.class);
+  private static final Logger LOGGER = LoggerFactory.getLogger(SparkIntegrationTest.class);
 
   private static MiniHadoopCluster hadoopCluster;
-  private static MiniZeppelin zeppelin;
   private static InterpreterFactory interpreterFactory;
   protected static InterpreterSettingManager interpreterSettingManager;
 
@@ -69,6 +69,8 @@ public abstract class SparkIntegrationTest {
   private String hadoopVersion;
   private String sparkHome;
 
+  private static MiniZeppelinServer zepServer;
+
   public void prepareSpark(String sparkVersion, String hadoopVersion) {
     LOGGER.info("Testing Spark Version: " + sparkVersion);
     LOGGER.info("Testing Hadoop Version: " + hadoopVersion);
@@ -78,21 +80,26 @@ public abstract class SparkIntegrationTest {
   }
 
   @BeforeAll
-  public static void setUp() throws IOException {
+  static void init() throws Exception {
     hadoopCluster = new MiniHadoopCluster();
     hadoopCluster.start();
 
-    zeppelin = new MiniZeppelin();
-    zeppelin.start(SparkIntegrationTest.class);
-    interpreterFactory = zeppelin.getInterpreterFactory();
-    interpreterSettingManager = zeppelin.getInterpreterSettingManager();
+    zepServer = new MiniZeppelinServer(SparkIntegrationTest.class.getSimpleName());
+    zepServer.addInterpreter("sh");
+    zepServer.addInterpreter("spark");
+    zepServer.addInterpreter("spark-submit");
+    zepServer.copyBinDir();
+    zepServer.copyLogProperties();
+    zepServer.getZeppelinConfiguration().setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_HELIUM_REGISTRY.getVarName(),
+        "helium");
+    zepServer.start();
+    interpreterSettingManager = zepServer.getService(InterpreterSettingManager.class);
+    interpreterFactory = zepServer.getService(InterpreterFactory.class);
   }
 
   @AfterAll
-  public static void tearDown() throws IOException {
-    if (zeppelin != null) {
-      zeppelin.stop();
-    }
+  public static void tearDown() throws Exception {
+    zepServer.destroy();
     if (hadoopCluster != null) {
       hadoopCluster.stop();
     }
@@ -122,8 +129,8 @@ public abstract class SparkIntegrationTest {
    * @throws IOException
    */
   private void setupIvySettings(InterpreterSetting interpreterSetting) throws IOException {
-    File ivysettings = new File(zeppelin.getZeppelinConfDir(), "ivysettings.xml");
-    FileUtils.copyToFile(SparkIntegrationTest.class.getResourceAsStream("/ivysettings.xml"), ivysettings);
+    String ivysettingsContent = IOUtils.toString(SparkIntegrationTest.class.getResourceAsStream("/ivysettings.xml"), StandardCharsets.UTF_8.name());
+    File ivysettings = zepServer.addConfigFile("ivysettings.xml", ivysettingsContent);
     interpreterSetting.setProperty("spark.jars.ivySettings", ivysettings.getAbsolutePath());
   }
 
@@ -197,7 +204,7 @@ public abstract class SparkIntegrationTest {
     InterpreterSetting sparkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("spark");
     sparkInterpreterSetting.setProperty("spark.master", "local[*]");
     sparkInterpreterSetting.setProperty("SPARK_HOME", sparkHome);
-    sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
+    sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zepServer.getZeppelinConfiguration().getConfDir());
     sparkInterpreterSetting.setProperty("zeppelin.spark.useHiveContext", "false");
     sparkInterpreterSetting.setProperty("zeppelin.pyspark.useIPython", "false");
     sparkInterpreterSetting.setProperty("zeppelin.spark.scala.color", "false");
@@ -226,7 +233,7 @@ public abstract class SparkIntegrationTest {
     sparkInterpreterSetting.setProperty("spark.master", "yarn-client");
     sparkInterpreterSetting.setProperty("HADOOP_CONF_DIR", hadoopCluster.getConfigPath());
     sparkInterpreterSetting.setProperty("SPARK_HOME", sparkHome);
-    sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
+    sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zepServer.getZeppelinConfiguration().getConfDir());
     sparkInterpreterSetting.setProperty("zeppelin.spark.useHiveContext", "false");
     sparkInterpreterSetting.setProperty("zeppelin.pyspark.useIPython", "false");
     sparkInterpreterSetting.setProperty("PYSPARK_PYTHON", getPythonExec());
@@ -235,6 +242,7 @@ public abstract class SparkIntegrationTest {
     sparkInterpreterSetting.setProperty("zeppelin.spark.deprecatedMsg.show", "false");
     sparkInterpreterSetting.setProperty("spark.user.name", "#{user}");
     sparkInterpreterSetting.setProperty("zeppelin.spark.run.asLoginUser", "false");
+    sparkInterpreterSetting.setProperty("spark.r.command", getRScriptExec());
 
     try {
       setUpSparkInterpreterSetting(sparkInterpreterSetting);
@@ -279,10 +287,13 @@ public abstract class SparkIntegrationTest {
     sparkInterpreterSetting.setProperty("spark.master", "yarn-cluster");
     sparkInterpreterSetting.setProperty("HADOOP_CONF_DIR", hadoopCluster.getConfigPath());
     sparkInterpreterSetting.setProperty("SPARK_HOME", sparkHome);
-    sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
+    sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zepServer.getZeppelinConfiguration().getConfDir());
     sparkInterpreterSetting.setProperty("zeppelin.spark.useHiveContext", "false");
     sparkInterpreterSetting.setProperty("zeppelin.pyspark.useIPython", "false");
     sparkInterpreterSetting.setProperty("PYSPARK_PYTHON", getPythonExec());
+    sparkInterpreterSetting.setProperty("spark.pyspark.python", getPythonExec());
+    sparkInterpreterSetting.setProperty("zeppelin.R.cmd", getRExec());
+    sparkInterpreterSetting.setProperty("spark.r.command", getRScriptExec());
     sparkInterpreterSetting.setProperty("spark.driver.memory", "512m");
     sparkInterpreterSetting.setProperty("zeppelin.spark.scala.color", "false");
     sparkInterpreterSetting.setProperty("zeppelin.spark.deprecatedMsg.show", "false");
@@ -346,7 +357,7 @@ public abstract class SparkIntegrationTest {
       sparkInterpreterSetting.setProperty("spark.master", "local[*]");
       sparkInterpreterSetting.setProperty("spark.submit.deployMode", "client");
       sparkInterpreterSetting.setProperty("SPARK_HOME", sparkHome);
-      sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zeppelin.getZeppelinConfDir().getAbsolutePath());
+      sparkInterpreterSetting.setProperty("ZEPPELIN_CONF_DIR", zepServer.getZeppelinConfiguration().getConfDir());
       sparkInterpreterSetting.setProperty("zeppelin.spark.useHiveContext", "false");
       sparkInterpreterSetting.setProperty("zeppelin.pyspark.useIPython", "false");
       sparkInterpreterSetting.setProperty("zeppelin.spark.scala.color", "false");
@@ -389,4 +400,20 @@ public abstract class SparkIntegrationTest {
     }
     return IOUtils.toString(process.getInputStream(), StandardCharsets.UTF_8).trim();
   }
+
+  private String getRScriptExec() throws IOException, InterruptedException {
+    Process process = Runtime.getRuntime().exec(new String[]{"which", "Rscript"});
+    if (process.waitFor() != 0) {
+      throw new RuntimeException("Fail to run command: which Rscript.");
+    }
+    return IOUtils.toString(process.getInputStream(), StandardCharsets.UTF_8).trim();
+  }
+
+  private String getRExec() throws IOException, InterruptedException {
+    Process process = Runtime.getRuntime().exec(new String[]{"which", "R"});
+    if (process.waitFor() != 0) {
+      throw new RuntimeException("Fail to run command: which R.");
+    }
+    return IOUtils.toString(process.getInputStream(), StandardCharsets.UTF_8).trim();
+  }
 }
