@@ -18,6 +18,7 @@
 package org.apache.zeppelin.integration;
 
 import org.apache.commons.io.IOUtils;
+import org.apache.zeppelin.MiniZeppelinServer;
 import org.apache.zeppelin.client.ClientConfig;
 import org.apache.zeppelin.client.NoteResult;
 import org.apache.zeppelin.client.ParagraphResult;
@@ -29,10 +30,12 @@ import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.common.SessionInfo;
 import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.rest.AbstractTestRestApi;
-import org.apache.zeppelin.utils.TestUtils;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -45,34 +48,45 @@ import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.Map;
 
-public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
+class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
+  private static final Logger LOGGER = LoggerFactory.getLogger(ZeppelinClientIntegrationTest.class);
   private static Notebook notebook;
 
   private static ClientConfig clientConfig;
   private static ZeppelinClient zeppelinClient;
+  private static MiniZeppelinServer zepServer;
 
   @BeforeAll
-  public static void setUp() throws Exception {
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_HELIUM_REGISTRY.getVarName(),
-            "helium");
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_ALLOWED_ORIGINS.getVarName(), "*");
-
-    AbstractTestRestApi.startUp(ZeppelinClientIntegrationTest.class.getSimpleName());
-    notebook = TestUtils.getInstance(Notebook.class);
-
-    clientConfig = new ClientConfig("http://localhost:8080");
+  static void init() throws Exception {
+    zepServer = new MiniZeppelinServer(ZeppelinClientIntegrationTest.class.getSimpleName());
+    zepServer.addInterpreter("md");
+    zepServer.addInterpreter("sh");
+    zepServer.copyBinDir();
+    zepServer.copyLogProperties();
+    ZeppelinConfiguration zConf = zepServer.getZeppelinConfiguration();
+    zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_HELIUM_REGISTRY.getVarName(),
+        "helium");
+    zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_ALLOWED_ORIGINS.getVarName(), "*");
+    zepServer.start();
+    clientConfig = new ClientConfig("http://localhost:" + zepServer.getZeppelinConfiguration().getServerPort());
     zeppelinClient = new ZeppelinClient(clientConfig);
+    notebook = zepServer.getService(Notebook.class);
   }
 
   @AfterAll
-  public static void destroy() throws Exception {
-    AbstractTestRestApi.shutDown();
+  static void destroy() throws Exception {
+    zepServer.destroy();
+  }
+
+  @BeforeEach
+  void setup() {
+    zConf = zepServer.getZeppelinConfiguration();
   }
 
   @Test
   void testZeppelinVersion() throws Exception {
     String version = zeppelinClient.getVersion();
-    LOG.info("Zeppelin version: " + version);
+    LOGGER.info("Zeppelin version: " + version);
     assertNotNull(version);
   }
 
@@ -241,7 +255,8 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals(Status.ERROR, paragraphResult.getStatus());
     assertEquals(2, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
-    assertTrue(paragraphResult.getResults().get(0).getData().contains("command not found"), paragraphResult.getResults().get(0).getData());
+    // depends on JVM language
+    // assertTrue(paragraphResult.getResults().get(0).getData().contains("command not found"), paragraphResult.getResults().get(0).getData());
     assertEquals("TEXT", paragraphResult.getResults().get(1).getType());
     assertTrue(paragraphResult.getResults().get(1).getData().contains("ExitValue"), paragraphResult.getResults().get(1).getData());
 
@@ -305,7 +320,8 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals(Status.ERROR, paragraphResult.getStatus());
     assertEquals(2, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
-    assertTrue(paragraphResult.getResults().get(0).getData().contains("command not found"), paragraphResult.getResults().get(0).getData());
+    // depends on JVM language
+    // assertTrue(paragraphResult.getResults().get(0).getData().contains("command not found"), paragraphResult.getResults().get(0).getData());
     assertEquals("TEXT", paragraphResult.getResults().get(1).getType());
     assertTrue(paragraphResult.getResults().get(1).getData().contains("ExitValue"), paragraphResult.getResults().get(1).getData());
 
@@ -388,7 +404,8 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     ParagraphResult p1 = noteResult.getParagraphResultList().get(1);
     assertEquals(Status.ERROR, p1.getStatus());
     assertEquals("TEXT", p1.getResults().get(0).getType());
-    assertTrue(p1.getResults().get(0).getData().contains("command not found"), p1.getResults().get(0).getData());
+    // depends on JVM language
+    //assertTrue(p1.getResults().get(0).getData().contains("command not found"), p1.getResults().get(0).getData());
     assertEquals("TEXT", p1.getResults().get(1).getType());
     assertTrue(p1.getResults().get(1).getData().contains("ExitValue"), p1.getResults().get(1).getData());
 
@@ -462,7 +479,8 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     ParagraphResult p1 = noteResult.getParagraphResultList().get(1);
     assertEquals(Status.ERROR, p1.getStatus());
     assertEquals("TEXT", p1.getResults().get(0).getType());
-    assertTrue(p1.getResults().get(0).getData().contains("command not found"), p1.getResults().get(0).getData());
+    // depends on JVM language
+    // assertTrue(p1.getResults().get(0).getData().contains("command not found"), p1.getResults().get(0).getData());
     assertEquals("TEXT", p1.getResults().get(1).getType());
     assertTrue(p1.getResults().get(1).getData().contains("ExitValue"), p1.getResults().get(1).getData());
 
