@@ -22,6 +22,7 @@ import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.reflect.FieldUtils;
 import org.apache.zeppelin.annotation.Experimental;
 import org.apache.zeppelin.annotation.ZeppelinApi;
+import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
 import org.apache.zeppelin.scheduler.Scheduler;
 import org.apache.zeppelin.scheduler.SchedulerFactory;
@@ -149,6 +150,7 @@ public abstract class Interpreter {
   private URL[] classloaderUrls;
   protected Properties properties;
   protected String userName;
+  protected ZeppelinConfiguration zConf;
 
   @ZeppelinApi
   public Interpreter(Properties properties) {
@@ -198,6 +200,10 @@ public abstract class Interpreter {
     return this.userName;
   }
 
+  public void setZeppelinConfiguration(ZeppelinConfiguration zConf) {
+    this.zConf = zConf;
+  }
+
   public void setInterpreterGroup(InterpreterGroup interpreterGroup) {
     this.interpreterGroup = interpreterGroup;
   }
