@@ -30,7 +30,7 @@ import org.slf4j.LoggerFactory;
  */
 public class JobProgressPoller extends Thread {
   public static final long DEFAULT_INTERVAL_MSEC = 500;
-  private static final Logger logger = LoggerFactory.getLogger(JobProgressPoller.class);
+  private static final Logger LOGGER = LoggerFactory.getLogger(JobProgressPoller.class);
 
   private Job<?> job;
   private long intervalMs;
@@ -55,7 +55,7 @@ public class JobProgressPoller extends Thread {
               listener.onProgressUpdate(job, job.progress());
             }
           } catch (Exception e) {
-            logger.error("Can not get or update progress", e);
+            LOGGER.error("Can not get or update progress", e);
           }
         }
         Thread.sleep(intervalMs);
