@@ -18,6 +18,7 @@
 package org.apache.zeppelin.helium;
 
 import org.apache.commons.io.FileUtils;
+import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.dep.DependencyResolver;
 import org.apache.zeppelin.interpreter.InterpreterOutput;
 import org.apache.zeppelin.resource.LocalResourcePool;
@@ -52,7 +53,8 @@ class ApplicationLoaderTest {
   void loadUnloadApplication() throws Exception {
     // given
     LocalResourcePool resourcePool = new LocalResourcePool("pool1");
-    DependencyResolver dep = new DependencyResolver(tmpDir.getAbsolutePath());
+    DependencyResolver dep =
+        new DependencyResolver(tmpDir.getAbsolutePath(), ZeppelinConfiguration.load());
     ApplicationLoader appLoader = new ApplicationLoader(resourcePool, dep);
 
     HeliumPackage pkg1 = createPackageInfo(MockApplication1.class.getName(), "artifact1");
