@@ -17,28 +17,28 @@
 
 package org.apache.zeppelin.interpreter;
 
-import org.junit.Test;
-
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-public class LazyOpenInterpreterTest {
+import org.junit.jupiter.api.Test;
+
+class LazyOpenInterpreterTest {
   Interpreter interpreter = mock(Interpreter.class);
 
   @Test
-  public void isOpenTest() throws InterpreterException {
+  void isOpenTest() throws InterpreterException {
     InterpreterResult interpreterResult = new InterpreterResult(InterpreterResult.Code.SUCCESS, "");
     when(interpreter.interpret(any(String.class), any(InterpreterContext.class)))
         .thenReturn(interpreterResult);
 
     LazyOpenInterpreter lazyOpenInterpreter = new LazyOpenInterpreter(interpreter);
 
-    assertFalse("Interpreter is not open", lazyOpenInterpreter.isOpen());
+    assertFalse(lazyOpenInterpreter.isOpen(), "Interpreter is not open");
     InterpreterContext interpreterContext = mock(InterpreterContext.class);
     lazyOpenInterpreter.interpret("intp 1", interpreterContext);
-    assertTrue("Interpeter is open", lazyOpenInterpreter.isOpen());
+    assertTrue(lazyOpenInterpreter.isOpen(), "Interpeter is open");
   }
 }
