@@ -17,19 +17,18 @@
 
 package org.apache.zeppelin.interpreter;
 
-import org.junit.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-import java.io.Serializable;
 import java.util.Arrays;
 import java.util.List;
 
-import static org.junit.Assert.assertEquals;
+import org.junit.jupiter.api.Test;
 
-public class SingleRowInterpreterResultTest {
+class SingleRowInterpreterResultTest {
 
   @Test
-  public void testHtml() {
-    List<Serializable> list = Arrays.asList("2020-01-01", 10);
+  void testHtml() {
+    List<Object> list = Arrays.asList("2020-01-01", 10);
     String template = "Total count:{1} for {0}";
     InterpreterContext context = InterpreterContext.builder().build();
     SingleRowInterpreterResult singleRowInterpreterResult = new SingleRowInterpreterResult(list, template, context);
@@ -38,8 +37,8 @@ public class SingleRowInterpreterResultTest {
   }
 
   @Test
-  public void testAngular() {
-    List<Serializable> list = Arrays.asList("2020-01-01", 10);
+  void testAngular() {
+    List<Object> list = Arrays.asList("2020-01-01", 10);
     String template = "Total count:{1} for {0}";
     InterpreterContext context = InterpreterContext.builder().build();
     SingleRowInterpreterResult singleRowInterpreterResult = new SingleRowInterpreterResult(list, template, context);
