@@ -93,9 +93,10 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
   @VisibleForTesting
   boolean uploadLocalLibToContainter = true;
 
-  private ZeppelinConfiguration zconf;
+  private ZeppelinConfiguration zConf;
 
   private String zeppelinHome;
+  private final String containerZeppelinHome;
 
   @VisibleForTesting
   final String containerSparkHome;
@@ -106,7 +107,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
   private static final String CONTAINER_UPLOAD_TAR_DIR = "/tmp/zeppelin-tar";
 
   public DockerInterpreterProcess(
-      ZeppelinConfiguration zconf,
+      ZeppelinConfiguration zConf,
       String containerImage,
       String interpreterGroupId,
       String interpreterGroupName,
@@ -127,11 +128,12 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     this.properties = properties;
     this.envs = new HashMap<>(envs);
 
-    this.zconf = zconf;
+    this.zConf = zConf;
     this.containerName = interpreterGroupId.toLowerCase();
 
-    containerSparkHome = zconf.getString(ConfVars.ZEPPELIN_DOCKER_CONTAINER_SPARK_HOME);
-    uploadLocalLibToContainter = zconf.getBoolean(
+    containerZeppelinHome = zConf.getString(ConfVars.ZEPPELIN_DOCKER_CONTAINER_HOME);
+    containerSparkHome = zConf.getString(ConfVars.ZEPPELIN_DOCKER_CONTAINER_SPARK_HOME);
+    uploadLocalLibToContainter = zConf.getBoolean(
         ConfVars.ZEPPELIN_DOCKER_UPLOAD_LOCAL_LIB_TO_CONTAINTER);
 
     try {
@@ -139,7 +141,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     } catch (IOException e) {
       LOGGER.error(e.getMessage(), e);
     }
-    dockerHost = zconf.getString(ConfVars.ZEPPELIN_DOCKER_HOST);
+    dockerHost = zConf.getString(ConfVars.ZEPPELIN_DOCKER_HOST);
   }
 
   @Override
@@ -190,7 +192,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     // check if the interpreter process exit script
     // if interpreter process exit, then container need exit
     StringBuilder sbStartCmd = new StringBuilder();
-    sbStartCmd.append("sleep 10; ");
+    sbStartCmd.append("sleep 20; ");
     sbStartCmd.append("process=RemoteInterpreterServer; ");
     sbStartCmd.append("RUNNING_PIDS=$(ps x | grep $process | grep -v grep | awk '{print $1}'); ");
     sbStartCmd.append("while [ ! -z \"$RUNNING_PIDS\" ]; ");
@@ -241,6 +243,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     long timeoutTime = startTime + getConnectTimeout();
     // wait until interpreter send dockerStarted message through thrift rpc
     synchronized (dockerStarted) {
+      LOGGER.info("Waiting for interpreter container to be ready");
       while (!dockerStarted.get() && !Thread.currentThread().isInterrupted()) {
         long timeToTimeout = timeoutTime - System.currentTimeMillis();
         if (timeToTimeout <= 0) {
@@ -293,7 +296,7 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     Properties dockerProperties = new Properties();
 
     // docker template properties
-    dockerProperties.put("CONTAINER_ZEPPELIN_HOME", zeppelinHome);
+    dockerProperties.put("CONTAINER_ZEPPELIN_HOME", containerZeppelinHome);
     dockerProperties.put("zeppelin.interpreter.container.image", containerImage);
     dockerProperties.put("zeppelin.interpreter.group.id", interpreterGroupId);
     dockerProperties.put("zeppelin.interpreter.group.name", interpreterGroupName);
@@ -313,13 +316,19 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
   @VisibleForTesting
   List<String> getListEnvs() {
     // environment variables
-    envs.put("ZEPPELIN_HOME", zeppelinHome);
-    envs.put("ZEPPELIN_CONF_DIR", zeppelinHome + "/conf");
+    envs.put("ZEPPELIN_HOME", containerZeppelinHome);
+    envs.put("ZEPPELIN_CONF_DIR", containerZeppelinHome + "/conf");
     envs.put("ZEPPELIN_FORCE_STOP", "true");
     envs.put("SPARK_HOME", this.containerSparkHome);
 
+    // remove JAVA_HOME from envs to avoid misconfiguration in container
+    envs.remove("JAVA_HOME");
+
+    // remove PATH from envs to avoid misconfiguration in container
+    envs.remove("PATH");
+
     // set container time zone
-    envs.put("TZ", zconf.getString(ConfVars.ZEPPELIN_DOCKER_TIME_ZONE));
+    envs.put("TZ", zConf.getString(ConfVars.ZEPPELIN_DOCKER_TIME_ZONE));
 
     List<String> listEnv = new ArrayList<>();
     for (Map.Entry<String, String> entry : this.envs.entrySet()) {
@@ -432,9 +441,8 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     return null;
   }
 
-  // upload configure file to submarine interpreter container
+  // upload keytab and configuration file to interpreter container:
   // keytab file & zeppelin-site.xml & krb5.conf
-  // The submarine configures the mount file into the container through `localization`
   // NOTE: The path to the file uploaded to the container,
   // Can not be repeated, otherwise it will lead to failure.
   private void copyRunFileToContainer(String containerId)
@@ -442,18 +450,20 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
     HashMap<String, String> copyFiles = new HashMap<>();
 
     // Rebuild directory
-    rmInContainer(containerId, zeppelinHome);
-    mkdirInContainer(containerId, zeppelinHome);
+    rmInContainer(containerId, containerZeppelinHome);
+    mkdirInContainer(containerId, containerZeppelinHome);
 
 
     // 1) zeppelin-site.xml is uploaded to `${CONTAINER_ZEPPELIN_HOME}` directory in the container
     String confPath = "/conf";
     String zeplConfPath = getPathByHome(zeppelinHome, confPath);
-    mkdirInContainer(containerId, zeplConfPath);
-    copyFiles.put(zeplConfPath + "/zeppelin-site.xml", zeplConfPath + "/zeppelin-site.xml");
-    copyFiles.put(zeplConfPath + "/log4j.properties", zeplConfPath + "/log4j.properties");
+    mkdirInContainer(containerId, containerZeppelinHome);
+    String containerZeplConfPath = containerZeppelinHome + confPath;
+    copyFiles.put(
+        zeplConfPath + "/zeppelin-site.xml", containerZeplConfPath + "/zeppelin-site.xml");
+    copyFiles.put(zeplConfPath + "/log4j.properties", containerZeplConfPath + "/log4j.properties");
     copyFiles.put(zeplConfPath + "/log4j_yarn_cluster.properties",
-        zeplConfPath + "/log4j_yarn_cluster.properties");
+        containerZeplConfPath + "/log4j_yarn_cluster.properties");
 
     // 2) upload krb5.conf to container
     String krb5conf = "/etc/krb5.conf";
@@ -476,23 +486,19 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
       intpKeytab = properties.getProperty("spark.yarn.keytab", "");
     }
     if (StringUtils.isBlank(intpKeytab)) {
-      // 3.3) submarine interpreter properties keytab file
-      intpKeytab = properties.getProperty("submarine.hadoop.keytab", "");
-    }
-    if (StringUtils.isBlank(intpKeytab)) {
-      // 3.4) livy interpreter properties keytab file
+      // 3.3) livy interpreter properties keytab file
       intpKeytab = properties.getProperty("zeppelin.livy.keytab", "");
     }
     if (StringUtils.isBlank(intpKeytab)) {
-      // 3.5) jdbc interpreter properties keytab file
+      // 3.4) jdbc interpreter properties keytab file
       intpKeytab = properties.getProperty("zeppelin.jdbc.keytab.location", "");
     }
     if (!StringUtils.isBlank(intpKeytab)) {
       LOGGER.info("intpKeytab : {}", intpKeytab);
       copyFiles.putIfAbsent(intpKeytab, intpKeytab);
     }
-    // 3.6) zeppelin server keytab file
-    String zeppelinServerKeytab = zconf.getString(ZEPPELIN_SERVER_KERBEROS_KEYTAB);
+    // 3.5) zeppelin server keytab file
+    String zeppelinServerKeytab = zConf.getString(ZEPPELIN_SERVER_KERBEROS_KEYTAB);
     if (!StringUtils.isBlank(zeppelinServerKeytab)) {
       copyFiles.putIfAbsent(zeppelinServerKeytab, zeppelinServerKeytab);
     }
@@ -517,26 +523,31 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
       //    directory in the container
       String binPath = "/bin";
       String zeplBinPath = getPathByHome(zeppelinHome, binPath);
-      mkdirInContainer(containerId, zeplBinPath);
-      docker.copyToContainer(new File(zeplBinPath).toPath(), containerId, zeplBinPath);
+      String containerZeplBinPath = containerZeppelinHome + binPath;
+      mkdirInContainer(containerId, containerZeplBinPath);
+      docker.copyToContainer(new File(zeplBinPath).toPath(), containerId, containerZeplBinPath);
 
       // 7) ${ZEPPELIN_HOME}/interpreter/spark is uploaded to `${CONTAINER_ZEPPELIN_HOME}`
       //    directory in the container
       String intpGrpPath = "/interpreter/" + interpreterGroupName;
       String intpGrpAllPath = getPathByHome(zeppelinHome, intpGrpPath);
-      mkdirInContainer(containerId, intpGrpAllPath);
-      docker.copyToContainer(new File(intpGrpAllPath).toPath(), containerId, intpGrpAllPath);
+      String containerIntpGrpPath = containerZeppelinHome + intpGrpPath;
+      mkdirInContainer(containerId, containerIntpGrpPath);
+      docker.copyToContainer(new File(intpGrpAllPath).toPath(), containerId, containerIntpGrpPath);
 
       // 8) ${ZEPPELIN_HOME}/lib/interpreter/zeppelin-interpreter-shaded-<version>.jar
       //    is uploaded to `${CONTAINER_ZEPPELIN_HOME}` directory in the container
       String intpPath = "/interpreter";
       String intpAllPath = getPathByHome(zeppelinHome, intpPath);
+      String containerIntpAllPath = containerZeppelinHome + intpPath;
       Collection<File> listFiles = FileUtils.listFiles(new File(intpAllPath),
           FileFilterUtils.suffixFileFilter("jar"), null);
       for (File jarfile : listFiles) {
         String jarfilePath = jarfile.getAbsolutePath();
+        String jarfileName = jarfile.getName();
+        String containerJarfilePath = containerIntpAllPath + "/" + jarfileName;
         if (!StringUtils.isBlank(jarfilePath)) {
-          copyFiles.putIfAbsent(jarfilePath, jarfilePath);
+          copyFiles.putIfAbsent(jarfilePath, containerJarfilePath);
         }
       }
     }
@@ -625,9 +636,9 @@ public class DockerInterpreterProcess extends RemoteInterpreterProcess {
 
   private String getZeppelinHome() throws IOException {
     // check zeppelinHome is exist
-    File fileZeppelinHome = new File(zconf.getZeppelinHome());
+    File fileZeppelinHome = new File(zConf.getZeppelinHome());
     if (fileZeppelinHome.exists() && fileZeppelinHome.isDirectory()) {
-      return zconf.getZeppelinHome();
+      return zConf.getZeppelinHome();
     }
 
     throw new IOException("Can't find zeppelin home path!");
