@@ -28,7 +28,6 @@ import com.google.cloud.storage.StorageException;
 import com.google.cloud.storage.StorageOptions;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Preconditions;
-import com.google.gson.JsonParseException;
 
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -47,6 +46,8 @@ import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars;
 import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.NoteInfo;
+import org.apache.zeppelin.notebook.NoteParser;
+import org.apache.zeppelin.notebook.exception.CorruptedNoteException;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -65,7 +66,7 @@ import org.slf4j.LoggerFactory;
  * @see <a href="https://github.com/google/google-auth-library-java">
  *   google-auth-library-java</a>.
  */
-public class GCSNotebookRepo implements NotebookRepo {
+public class GCSNotebookRepo extends AbstractNotebookRepo {
 
   private static final Logger LOGGER = LoggerFactory.getLogger(GCSNotebookRepo.class);
   private String encoding;
@@ -78,15 +79,24 @@ public class GCSNotebookRepo implements NotebookRepo {
   }
 
   @VisibleForTesting
-  public GCSNotebookRepo(ZeppelinConfiguration zConf, Storage storage) throws IOException {
-    init(zConf);
+  public GCSNotebookRepo(ZeppelinConfiguration zConf, NoteParser noteParser, Storage storage)
+      throws IOException
+  {
+    try {
+      init(zConf, noteParser);
+    } catch (IOException e) {
+      // Skip Credentials Exception during tests
+      if (!e.getMessage().contains("Default Credentials")) {
+        throw e;
+      }
+    }
     this.storage = storage;
   }
 
   @Override
-  public void init(ZeppelinConfiguration zConf) throws IOException {
+  public void init(ZeppelinConfiguration zConf, NoteParser noteParser) throws IOException {
+    super.init(zConf, noteParser);
     this.encoding =  zConf.getString(ConfVars.ZEPPELIN_ENCODING);
-
     String gcsStorageDir = zConf.getGCSStorageDir();
     if (gcsStorageDir.isEmpty()) {
       throw new IOException("GCS storage directory must be set using 'zeppelin.notebook.gcs.dir'");
@@ -182,8 +192,8 @@ public class GCSNotebookRepo implements NotebookRepo {
     }
 
     try {
-      return Note.fromJson(noteId, new String(contents, encoding));
-    } catch (JsonParseException jpe) {
+      return noteParser.fromJson(noteId, new String(contents, encoding));
+    } catch (CorruptedNoteException jpe) {
       throw new IOException(
           "Could note parse as json " + blobId.toString() + jpe.getMessage(), jpe);
     }
