@@ -30,8 +30,10 @@ import de.flapdoodle.embed.mongo.config.Net;
 import de.flapdoodle.embed.mongo.distribution.Version;
 import de.flapdoodle.embed.process.runtime.Network;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
+import org.apache.zeppelin.notebook.GsonNoteParser;
 import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.NoteInfo;
+import org.apache.zeppelin.notebook.NoteParser;
 import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.junit.jupiter.api.AfterEach;
@@ -43,11 +45,14 @@ class MongoNotebookRepoTest {
   private MongodExecutable mongodExecutable;
 
   private ZeppelinConfiguration zConf;
+  private NoteParser noteParser;
 
   private MongoNotebookRepo notebookRepo;
 
   @BeforeEach
   void setUp() throws IOException {
+    zConf = ZeppelinConfiguration.load();
+    noteParser = new GsonNoteParser(zConf);
     String bindIp = "localhost";
     ServerSocket socket = new ServerSocket(0);
     int port = socket.getLocalPort();
@@ -62,10 +67,10 @@ class MongoNotebookRepoTest {
         .prepare(mongodConfig);
     mongodExecutable.start();
 
-    System.setProperty(ZEPPELIN_NOTEBOOK_MONGO_URI.getVarName(), "mongodb://" + bindIp + ":" + port);
-    zConf = ZeppelinConfiguration.create();
+    zConf.setProperty(ZEPPELIN_NOTEBOOK_MONGO_URI.getVarName(), "mongodb://" + bindIp + ":" + port);
+
     notebookRepo = new MongoNotebookRepo();
-    notebookRepo.init(zConf);
+    notebookRepo.init(zConf, noteParser);
   }
 
   @AfterEach
@@ -82,6 +87,8 @@ class MongoNotebookRepoTest {
     // create note1
     Note note1 = new Note();
     note1.setPath("/my_project/my_note1");
+    note1.setNoteParser(noteParser);
+    note1.setZeppelinConfiguration(zConf);
     Paragraph p1 = note1.insertNewParagraph(0, AuthenticationInfo.ANONYMOUS);
     p1.setText("%md hello world");
     p1.setTitle("my title");
@@ -96,6 +103,8 @@ class MongoNotebookRepoTest {
     // create note2
     Note note2 = new Note();
     note2.setPath("/my_note2");
+    note2.setNoteParser(noteParser);
+    note2.setZeppelinConfiguration(zConf);
     Paragraph p2 = note2.insertNewParagraph(0, AuthenticationInfo.ANONYMOUS);
     p2.setText("%md hello world2");
     p2.setTitle("my title2");
@@ -134,9 +143,11 @@ class MongoNotebookRepoTest {
     Note note = new Note();
     String notePath = "/folder1/folder2/folder3/folder4/folder5/my_note";
     note.setPath(notePath);
+    note.setNoteParser(noteParser);
+    note.setZeppelinConfiguration(zConf);
     notebookRepo.save(note, AuthenticationInfo.ANONYMOUS);
 
-    notebookRepo.init(zConf);
+    notebookRepo.init(zConf, noteParser);
     Map<String, NoteInfo> noteInfos = notebookRepo.list(AuthenticationInfo.ANONYMOUS);
     assertEquals(1, notebookRepo.list(AuthenticationInfo.ANONYMOUS).size());
     assertEquals(notePath, noteInfos.get(note.getId()).getPath());
