@@ -17,7 +17,6 @@
 package org.apache.zeppelin.rest.exception;
 
 import static javax.ws.rs.core.Response.Status.FORBIDDEN;
-import static javax.ws.rs.core.Response.Status.UNAUTHORIZED;
 
 import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Response;
@@ -26,26 +25,13 @@ import org.apache.zeppelin.utils.ExceptionUtils;
 
 /**
  * UnauthorizedException handler for WebApplicationException.
- * 
  */
 public class ForbiddenException extends WebApplicationException {
-  private static final long serialVersionUID = 4394749068760407567L;
-  private static final String FORBIDDEN_MSG = "Not allowed to access";
-
-  public ForbiddenException() {
-    super(forbiddenJson(FORBIDDEN_MSG));
-  }
-
   private static Response forbiddenJson(String message) {
     return ExceptionUtils.jsonResponseContent(FORBIDDEN, message);
   }
-  
-  public ForbiddenException(Throwable cause, String message) {
-    super(cause, forbiddenJson(message));
-  }
-  
+
   public ForbiddenException(String message) {
     super(forbiddenJson(message));
   }
-
 }
