@@ -41,25 +41,28 @@ import io.micrometer.prometheus.PrometheusMeterRegistry;
 import java.io.File;
 import java.io.IOException;
 import java.lang.management.ManagementFactory;
+import java.net.MalformedURLException;
 import java.nio.file.Files;
 import java.security.GeneralSecurityException;
 import java.util.Base64;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Optional;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.EnumSet;
-import javax.inject.Inject;
 import javax.inject.Singleton;
 import javax.management.remote.JMXServiceURL;
 import javax.servlet.DispatcherType;
 import javax.servlet.ServletContextEvent;
 import javax.servlet.ServletContextListener;
+import javax.websocket.server.ServerEndpointConfig;
 
 import org.apache.commons.lang3.StringUtils;
 import org.apache.shiro.web.env.EnvironmentLoaderListener;
 import org.apache.shiro.web.servlet.ShiroFilter;
-import org.apache.zeppelin.cluster.ClusterManagerServer;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars;
+import org.apache.zeppelin.conf.ZeppelinConfiguration.DEFAULT_UI;
 import org.apache.zeppelin.display.AngularObjectRegistryListener;
 import org.apache.zeppelin.healthcheck.HealthChecks;
 import org.apache.zeppelin.helium.ApplicationEventListener;
@@ -67,17 +70,16 @@ import org.apache.zeppelin.helium.Helium;
 import org.apache.zeppelin.helium.HeliumApplicationFactory;
 import org.apache.zeppelin.helium.HeliumBundleFactory;
 import org.apache.zeppelin.interpreter.InterpreterFactory;
-import org.apache.zeppelin.interpreter.InterpreterOutput;
-import org.apache.zeppelin.interpreter.InterpreterSetting;
 import org.apache.zeppelin.interpreter.InterpreterSettingManager;
-import org.apache.zeppelin.interpreter.recovery.RecoveryStorage;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterProcessListener;
 import org.apache.zeppelin.metric.JVMInfoBinder;
 import org.apache.zeppelin.metric.PrometheusServlet;
 import org.apache.zeppelin.notebook.NoteEventListener;
 import org.apache.zeppelin.notebook.NoteManager;
+import org.apache.zeppelin.notebook.NoteParser;
 import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.notebook.AuthorizationService;
+import org.apache.zeppelin.notebook.GsonNoteParser;
 import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.notebook.repo.NotebookRepo;
 import org.apache.zeppelin.notebook.repo.NotebookRepoSync;
@@ -85,7 +87,6 @@ import org.apache.zeppelin.notebook.scheduler.NoSchedulerService;
 import org.apache.zeppelin.notebook.scheduler.QuartzSchedulerService;
 import org.apache.zeppelin.notebook.scheduler.SchedulerService;
 import org.apache.zeppelin.plugin.PluginManager;
-import org.apache.zeppelin.rest.exception.WebApplicationExceptionMapper;
 import org.apache.zeppelin.search.LuceneSearch;
 import org.apache.zeppelin.search.NoSearchService;
 import org.apache.zeppelin.search.SearchService;
@@ -93,9 +94,10 @@ import org.apache.zeppelin.service.*;
 import org.apache.zeppelin.service.AuthenticationService;
 import org.apache.zeppelin.socket.ConnectionManager;
 import org.apache.zeppelin.socket.NotebookServer;
+import org.apache.zeppelin.socket.SessionConfigurator;
+import org.apache.zeppelin.storage.ConfigStorage;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.apache.zeppelin.user.Credentials;
-import org.apache.zeppelin.util.ReflectionUtils;
 import org.apache.zeppelin.utils.PEMImporter;
 import org.eclipse.jetty.http.HttpScheme;
 import org.eclipse.jetty.http.HttpVersion;
@@ -115,7 +117,6 @@ import org.eclipse.jetty.util.ssl.SslContextFactory;
 import org.eclipse.jetty.webapp.WebAppContext;
 import org.eclipse.jetty.websocket.jsr356.server.deploy.WebSocketServerContainerInitializer;
 import org.eclipse.jetty.websocket.servlet.WebSocketServlet;
-import org.glassfish.hk2.api.Immediate;
 import org.glassfish.hk2.api.ServiceLocator;
 import org.glassfish.hk2.api.ServiceLocatorFactory;
 import org.glassfish.hk2.utilities.ServiceLocatorUtilities;
@@ -125,64 +126,71 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /** Main class of Zeppelin. */
-public class ZeppelinServer {
-  private static final Logger LOG = LoggerFactory.getLogger(ZeppelinServer.class);
-  private static final String WEB_APP_CONTEXT_NEXT = "/next";
+public class ZeppelinServer implements AutoCloseable {
+  private static final Logger LOGGER = LoggerFactory.getLogger(ZeppelinServer.class);
+  private static final String NON_DEFAULT_NEW_UI_WEB_APP_CONTEXT_PATH = "/new";
+  private static final String NON_DEFAULT_CLASSIC_UI_WEB_APP_CONTEXT_PATH = "/classic";
+  public static final String DEFAULT_SERVICE_LOCATOR_NAME = "shared-locator";
 
-  public static final String SERVICE_LOCATOR_NAME= "shared-locator";
+  private final AtomicBoolean duringShutdown = new AtomicBoolean(false);
+  private final ZeppelinConfiguration zConf;
+  private final Optional<PrometheusMeterRegistry> promMetricRegistry;
+  private final Server jettyWebServer;
+  private final ServiceLocator sharedServiceLocator;
+  private final ConfigStorage storage;
 
-  @Inject
-  public ZeppelinServer(ZeppelinConfiguration conf) {
-    LOG.info("Instantiated ZeppelinServer");
-    InterpreterOutput.LIMIT = conf.getInt(ConfVars.ZEPPELIN_INTERPRETER_OUTPUT_LIMIT);
+  public ZeppelinServer(ZeppelinConfiguration zConf) throws IOException {
+    this(zConf, DEFAULT_SERVICE_LOCATOR_NAME);
   }
 
-  public static void main(String[] args) throws IOException {
-    ZeppelinConfiguration conf = ZeppelinConfiguration.create();
-
-    Server jettyWebServer = setupJettyServer(conf);
-
-    PrometheusMeterRegistry promMetricRegistry = null;
-    if (conf.isPrometheusMetricEnabled()) {
-      promMetricRegistry = new PrometheusMeterRegistry(PrometheusConfig.DEFAULT);
-      Metrics.addRegistry(promMetricRegistry);
+  public ZeppelinServer(ZeppelinConfiguration zConf, String serviceLocatorName) throws IOException {
+    LOGGER.info("Instantiated ZeppelinServer");
+    this.zConf = zConf;
+    if (zConf.isPrometheusMetricEnabled()) {
+      promMetricRegistry = Optional.of(new PrometheusMeterRegistry(PrometheusConfig.DEFAULT));
+    } else {
+      promMetricRegistry = Optional.empty();
     }
-    initMetrics(conf);
+    jettyWebServer = setupJettyServer();
+    sharedServiceLocator = ServiceLocatorFactory.getInstance().create(serviceLocatorName);
+    storage = ConfigStorage.createConfigStorage(zConf);
+  }
+
+  public void startZeppelin() {
+    initMetrics();
 
     TimedHandler timedHandler = new TimedHandler(Metrics.globalRegistry, Tags.empty());
     jettyWebServer.setHandler(timedHandler);
 
     ContextHandlerCollection contexts = new ContextHandlerCollection();
     timedHandler.setHandler(contexts);
-
-    ServiceLocator sharedServiceLocator = ServiceLocatorFactory.getInstance().create(SERVICE_LOCATOR_NAME);
     ServiceLocatorUtilities.enableImmediateScope(sharedServiceLocator);
     ServiceLocatorUtilities.addClasses(sharedServiceLocator,
-      NotebookRepoSync.class,
       ImmediateErrorHandlerImpl.class);
     ImmediateErrorHandlerImpl handler = sharedServiceLocator.getService(ImmediateErrorHandlerImpl.class);
 
+
     ServiceLocatorUtilities.bind(
         sharedServiceLocator,
         new AbstractBinder() {
           @Override
           protected void configure() {
-            Credentials credentials = new Credentials(conf);
+            bind(storage).to(ConfigStorage.class);
+            bindAsContract(PluginManager.class).in(Singleton.class);
+            bind(GsonNoteParser.class).to(NoteParser.class).in(Singleton.class);
             bindAsContract(InterpreterFactory.class).in(Singleton.class);
-            bindAsContract(NotebookRepoSync.class).to(NotebookRepo.class).in(Immediate.class);
+            bindAsContract(NotebookRepoSync.class).to(NotebookRepo.class).in(Singleton.class);
             bindAsContract(Helium.class).in(Singleton.class);
-            bind(conf).to(ZeppelinConfiguration.class);
+            bind(zConf).to(ZeppelinConfiguration.class);
             bindAsContract(InterpreterSettingManager.class).in(Singleton.class);
             bindAsContract(InterpreterService.class).in(Singleton.class);
-            bind(credentials).to(Credentials.class);
-            bindAsContract(GsonProvider.class).in(Singleton.class);
-            bindAsContract(WebApplicationExceptionMapper.class).in(Singleton.class);
+            bindAsContract(Credentials.class).in(Singleton.class);
             bindAsContract(AdminService.class).in(Singleton.class);
             bindAsContract(AuthorizationService.class).in(Singleton.class);
             bindAsContract(ConnectionManager.class).in(Singleton.class);
             bindAsContract(NoteManager.class).in(Singleton.class);
             // TODO(jl): Will make it more beautiful
-            if (!StringUtils.isBlank(conf.getShiroPath())) {
+            if (!StringUtils.isBlank(zConf.getShiroPath())) {
               bind(ShiroAuthenticationService.class).to(AuthenticationService.class).in(Singleton.class);
             } else {
               // TODO(jl): Will be added more type
@@ -201,12 +209,12 @@ public class ZeppelinServer {
                 .to(NoteEventListener.class)
                 .to(WebSocketServlet.class)
                 .in(Singleton.class);
-            if (conf.isZeppelinNotebookCronEnable()) {
+            if (zConf.isZeppelinNotebookCronEnable()) {
               bind(QuartzSchedulerService.class).to(SchedulerService.class).in(Singleton.class);
             } else {
               bind(NoSchedulerService.class).to(SchedulerService.class).in(Singleton.class);
             }
-            if (conf.getBoolean(ConfVars.ZEPPELIN_SEARCH_ENABLE)) {
+            if (zConf.getBoolean(ConfVars.ZEPPELIN_SEARCH_ENABLE)) {
               bind(LuceneSearch.class).to(SearchService.class).in(Singleton.class);
             } else {
               bind(NoSearchService.class).to(SearchService.class).in(Singleton.class);
@@ -215,33 +223,37 @@ public class ZeppelinServer {
         });
 
     // Multiple Web UI
-    final WebAppContext defaultWebApp = setupWebAppContext(contexts, conf, conf.getString(ConfVars.ZEPPELIN_WAR), conf.getServerContextPath());
-    final WebAppContext nextWebApp = setupWebAppContext(contexts, conf, conf.getString(ConfVars.ZEPPELIN_ANGULAR_WAR), WEB_APP_CONTEXT_NEXT);
+    String classicUiWebAppContextPath;
+    String newUiWebAppContextPath;
+    if (isNewUiDefault(zConf)) {
+      classicUiWebAppContextPath = NON_DEFAULT_CLASSIC_UI_WEB_APP_CONTEXT_PATH;
+      newUiWebAppContextPath = zConf.getServerContextPath();
+    } else {
+      classicUiWebAppContextPath = zConf.getServerContextPath();
+      newUiWebAppContextPath = NON_DEFAULT_NEW_UI_WEB_APP_CONTEXT_PATH;
+    }
+    final WebAppContext newUiWebApp = setupWebAppContext(contexts, zConf, zConf.getString(ConfVars.ZEPPELIN_ANGULAR_WAR),
+        newUiWebAppContextPath);
+    final WebAppContext classicUiWebApp = setupWebAppContext(contexts, zConf, zConf.getString(ConfVars.ZEPPELIN_WAR),
+        classicUiWebAppContextPath);
 
-    initWebApp(defaultWebApp, conf, sharedServiceLocator, promMetricRegistry);
-    initWebApp(nextWebApp, conf, sharedServiceLocator, promMetricRegistry);
-    // Cluster Manager Server
-    setupClusterManagerServer(sharedServiceLocator, conf);
+    initWebApp(newUiWebApp);
+    initWebApp(classicUiWebApp);
 
-    // JMX Enable
-    if (conf.isJMXEnabled()) {
-      int port = conf.getJMXPort();
-      // Setup JMX
-      MBeanContainer mbeanContainer = new MBeanContainer(ManagementFactory.getPlatformMBeanServer());
-      jettyWebServer.addBean(mbeanContainer);
-      JMXServiceURL jmxURL =
-        new JMXServiceURL(
-            String.format(
-                "service:jmx:rmi://0.0.0.0:%d/jndi/rmi://0.0.0.0:%d/jmxrmi",
-                port, port));
-      ConnectorServer jmxServer = new ConnectorServer(jmxURL, "org.eclipse.jetty.jmx:name=rmiconnectorserver");
-      jettyWebServer.addBean(jmxServer);
-      LOG.info("JMX Enabled with port: {}", port);
+    NotebookRepo repo =
+        ServiceLocatorUtilities.getService(sharedServiceLocator, NotebookRepo.class.getName());
+    NoteParser noteParser =
+        ServiceLocatorUtilities.getService(sharedServiceLocator, NoteParser.class.getName());
+    try {
+      repo.init(zConf, noteParser);
+    } catch (IOException e) {
+      LOGGER.error("Failed to init NotebookRepo", e);
     }
 
-    runNoteOnStart(conf, jettyWebServer, sharedServiceLocator);
+    initJMX();
 
-    Runtime.getRuntime().addShutdownHook(new Thread(() -> shutdown(conf, jettyWebServer, sharedServiceLocator)));
+    runNoteOnStart(sharedServiceLocator);
+    Runtime.getRuntime().addShutdownHook(new Thread(this::shutdown));
 
     // Try to get Notebook from ServiceLocator, because Notebook instantiation is lazy, it is
     // created when user open zeppelin in browser if we don't get it explicitly here.
@@ -257,54 +269,83 @@ public class ZeppelinServer {
     // Try to recover here, don't do it in constructor of Notebook, because it would cause deadlock.
     notebook.recoveryIfNecessary();
 
-    LOG.info("Starting zeppelin server");
+    LOGGER.info("Starting zeppelin server");
     try {
       jettyWebServer.start(); // Instantiates ZeppelinServer
-      if (conf.getJettyName() != null) {
-        org.eclipse.jetty.http.HttpGenerator.setJettyVersion(conf.getJettyName());
+      if (zConf.getJettyName() != null) {
+        org.eclipse.jetty.http.HttpGenerator.setJettyVersion(zConf.getJettyName());
       }
     } catch (Exception e) {
-      LOG.error("Error while running jettyServer", e);
+      LOGGER.error("Error while running jettyServer", e);
       System.exit(-1);
     }
 
-    LOG.info("Done, zeppelin server started");
+    LOGGER.info("Done, zeppelin server started");
     try {
       List<ErrorData> errorDatas = handler.waitForAtLeastOneConstructionError(5000);
       for (ErrorData errorData : errorDatas) {
-        LOG.error("Error in Construction", errorData.getThrowable());
+        LOGGER.error("Error in Construction", errorData.getThrowable());
       }
       if (!errorDatas.isEmpty()) {
-        LOG.error("{} error(s) while starting - Termination", errorDatas.size());
+        LOGGER.error("{} error(s) while starting - Termination", errorDatas.size());
         System.exit(-1);
       }
     } catch (InterruptedException e) {
       // Many fast unit tests interrupt the Zeppelin server at this point
-      LOG.error("Interrupt while waiting for construction errors - init shutdown", e);
-      shutdown(conf, jettyWebServer, sharedServiceLocator);
+      LOGGER.error("Interrupt while waiting for construction errors - init shutdown", e);
+      shutdown();
       Thread.currentThread().interrupt();
-
     }
+
     if (jettyWebServer.isStopped() || jettyWebServer.isStopping()) {
-      LOG.debug("jetty server is stopped {} - is stopping {}", jettyWebServer.isStopped(), jettyWebServer.isStopping());
+      LOGGER.debug("jetty server is stopped {} - is stopping {}", jettyWebServer.isStopped(), jettyWebServer.isStopping());
     } else {
       try {
         jettyWebServer.join();
       } catch (InterruptedException e) {
-        LOG.error("Interrupt while waiting for jetty threads - init shutdown", e);
-        shutdown(conf, jettyWebServer, sharedServiceLocator);
+        LOGGER.error("Interrupt while waiting for jetty threads - init shutdown", e);
+        shutdown();
         Thread.currentThread().interrupt();
       }
     }
-    if (!conf.isRecoveryEnabled()) {
-      sharedServiceLocator.getService(InterpreterSettingManager.class).close();
+  }
+
+  public static void main(String[] args) throws Exception {
+    ZeppelinConfiguration zConf = ZeppelinConfiguration.load();
+    zConf.printShortInfo();
+    try (ZeppelinServer server = new ZeppelinServer(zConf)) {
+      server.startZeppelin();
     }
   }
 
-  private static void initMetrics(ZeppelinConfiguration conf) {
-    if (conf.isJMXEnabled()) {
+  private void initJMX() {
+    // JMX Enable
+    if (zConf.isJMXEnabled()) {
+      int port = zConf.getJMXPort();
+      // Setup JMX
+      MBeanContainer mbeanContainer = new MBeanContainer(ManagementFactory.getPlatformMBeanServer());
+      jettyWebServer.addBean(mbeanContainer);
+      JMXServiceURL jmxURL;
+      try {
+        jmxURL = new JMXServiceURL(
+            String.format(
+                "service:jmx:rmi://0.0.0.0:%d/jndi/rmi://0.0.0.0:%d/jmxrmi",
+                port, port));
+        ConnectorServer jmxServer = new ConnectorServer(jmxURL, "org.eclipse.jetty.jmx:name=rmiconnectorserver");
+        jettyWebServer.addBean(jmxServer);
+        LOGGER.info("JMX Enabled with port: {}", port);
+      } catch (MalformedURLException e) {
+        LOGGER.error("Invalid JMXServiceURL - JMX Disabled", e);
+      }
+    }
+  }
+  private void initMetrics() {
+    if (zConf.isJMXEnabled()) {
       Metrics.addRegistry(new JmxMeterRegistry(JmxConfig.DEFAULT, Clock.SYSTEM));
     }
+    if (promMetricRegistry.isPresent()) {
+      Metrics.addRegistry(promMetricRegistry.get());
+    }
     new ClassLoaderMetrics().bindTo(Metrics.globalRegistry);
     new JvmMemoryMetrics().bindTo(Metrics.globalRegistry);
     new JvmThreadMetrics().bindTo(Metrics.globalRegistry);
@@ -314,57 +355,66 @@ public class ZeppelinServer {
     new JVMInfoBinder().bindTo(Metrics.globalRegistry);
   }
 
-  private static void shutdown(ZeppelinConfiguration conf, Server jettyWebServer, ServiceLocator sharedServiceLocator) {
-    LOG.info("Shutting down Zeppelin Server ... ");
-    try {
-      if (jettyWebServer != null) {
-        jettyWebServer.stop();
-      }
-      if (sharedServiceLocator != null) {
-        if (!conf.isRecoveryEnabled()) {
-          sharedServiceLocator.getService(InterpreterSettingManager.class).close();
+  public void shutdown(int exitCode) {
+    if (!duringShutdown.getAndSet(true)) {
+      LOGGER.info("Shutting down Zeppelin Server ... - ExitCode {}", exitCode);
+      try {
+        if (jettyWebServer != null) {
+          jettyWebServer.stop();
         }
-        sharedServiceLocator.getService(Notebook.class).close();
+        if (sharedServiceLocator != null) {
+          if (!zConf.isRecoveryEnabled()) {
+            sharedServiceLocator.getService(InterpreterSettingManager.class).close();
+          }
+          sharedServiceLocator.getService(Notebook.class).close();
+        }
+      } catch (Exception e) {
+        LOGGER.error("Error while stopping servlet container", e);
+      }
+      LOGGER.info("Bye");
+      if (exitCode != 0) {
+        System.exit(exitCode);
       }
-    } catch (Exception e) {
-      LOG.error("Error while stopping servlet container", e);
     }
-    LOG.info("Bye");
   }
 
-  private static Server setupJettyServer(ZeppelinConfiguration conf) {
+  public void shutdown() {
+    shutdown(0);
+  }
+
+  private Server setupJettyServer() {
     InstrumentedQueuedThreadPool threadPool =
       new InstrumentedQueuedThreadPool(Metrics.globalRegistry, Tags.empty(),
-                           conf.getInt(ConfVars.ZEPPELIN_SERVER_JETTY_THREAD_POOL_MAX),
-                           conf.getInt(ConfVars.ZEPPELIN_SERVER_JETTY_THREAD_POOL_MIN),
-                           conf.getInt(ConfVars.ZEPPELIN_SERVER_JETTY_THREAD_POOL_TIMEOUT));
+                           zConf.getInt(ConfVars.ZEPPELIN_SERVER_JETTY_THREAD_POOL_MAX),
+                           zConf.getInt(ConfVars.ZEPPELIN_SERVER_JETTY_THREAD_POOL_MIN),
+                           zConf.getInt(ConfVars.ZEPPELIN_SERVER_JETTY_THREAD_POOL_TIMEOUT));
     final Server server = new Server(threadPool);
-    initServerConnector(server, conf);
+    initServerConnector(server);
     return server;
   }
-  private static void initServerConnector(Server server, ZeppelinConfiguration conf) {
+  private void initServerConnector(Server server) {
 
     ServerConnector connector;
     HttpConfiguration httpConfig = new HttpConfiguration();
     httpConfig.addCustomizer(new ForwardedRequestCustomizer());
-    httpConfig.setSendServerVersion(conf.sendJettyName());
-    httpConfig.setRequestHeaderSize(conf.getJettyRequestHeaderSize());
-    if (conf.useSsl()) {
-      LOG.debug("Enabling SSL for Zeppelin Server on port {}", conf.getServerSslPort());
+    httpConfig.setSendServerVersion(zConf.sendJettyName());
+    httpConfig.setRequestHeaderSize(zConf.getJettyRequestHeaderSize());
+    if (zConf.useSsl()) {
+      LOGGER.debug("Enabling SSL for Zeppelin Server on port {}", zConf.getServerSslPort());
       httpConfig.setSecureScheme(HttpScheme.HTTPS.asString());
-      httpConfig.setSecurePort(conf.getServerSslPort());
+      httpConfig.setSecurePort(zConf.getServerSslPort());
 
       HttpConfiguration httpsConfig = new HttpConfiguration(httpConfig);
       httpsConfig.addCustomizer(new SecureRequestCustomizer());
 
-      SslConnectionFactory sslConnectionFactory = new SslConnectionFactory(getSslContextFactory(conf), HttpVersion.HTTP_1_1.asString());
+      SslConnectionFactory sslConnectionFactory = new SslConnectionFactory(getSslContextFactory(zConf), HttpVersion.HTTP_1_1.asString());
       HttpConnectionFactory httpsConnectionFactory = new HttpConnectionFactory(httpsConfig);
       connector =
               new ServerConnector(
                       server,
                       sslConnectionFactory,
                       httpsConnectionFactory);
-      connector.setPort(conf.getServerSslPort());
+      connector.setPort(zConf.getServerSslPort());
       connector.addBean(new JettySslHandshakeMetrics(Metrics.globalRegistry, Tags.empty()));
     } else {
       HttpConnectionFactory httpConnectionFactory = new HttpConnectionFactory(httpConfig);
@@ -372,172 +422,140 @@ public class ZeppelinServer {
               new ServerConnector(
                       server,
                       httpConnectionFactory);
-      connector.setPort(conf.getServerPort());
+      connector.setPort(zConf.getServerPort());
     }
     // Set some timeout options to make debugging easier.
     int timeout = 1000 * 30;
     connector.setIdleTimeout(timeout);
-    connector.setHost(conf.getServerAddress());
+    connector.setHost(zConf.getServerAddress());
     connector.addBean(new JettyConnectionMetrics(Metrics.globalRegistry, Tags.empty()));
     server.addConnector(connector);
   }
 
-  private static void runNoteOnStart(ZeppelinConfiguration conf, Server jettyWebServer, ServiceLocator sharedServiceLocator) throws IOException {
-    String noteIdToRun = conf.getNotebookRunId();
+  private void runNoteOnStart(ServiceLocator sharedServiceLocator) {
+    String noteIdToRun = zConf.getNotebookRunId();
     if (!StringUtils.isEmpty(noteIdToRun)) {
-      LOG.info("Running note {} on start", noteIdToRun);
+      LOGGER.info("Running note {} on start", noteIdToRun);
       NotebookService notebookService = ServiceLocatorUtilities.getService(
               sharedServiceLocator, NotebookService.class.getName());
 
       ServiceContext serviceContext;
-      String base64EncodedJsonSerializedServiceContext = conf.getNotebookRunServiceContext();
+      String base64EncodedJsonSerializedServiceContext = zConf.getNotebookRunServiceContext();
       if (StringUtils.isEmpty(base64EncodedJsonSerializedServiceContext)) {
-        LOG.info("No service context provided. use ANONYMOUS");
-        serviceContext = new ServiceContext(AuthenticationInfo.ANONYMOUS, new HashSet<String>() {});
+        LOGGER.info("No service context provided. use ANONYMOUS");
+        serviceContext = new ServiceContext(AuthenticationInfo.ANONYMOUS, new HashSet<>());
       } else {
         serviceContext = new Gson().fromJson(
                 new String(Base64.getDecoder().decode(base64EncodedJsonSerializedServiceContext)),
                 ServiceContext.class);
       }
 
-      boolean success = notebookService.runAllParagraphs(noteIdToRun, null, serviceContext, new ServiceCallback<Paragraph>() {
-        @Override
-        public void onStart(String message, ServiceContext context) throws IOException {
-        }
+      try {
+        boolean success = notebookService.runAllParagraphs(noteIdToRun, null, serviceContext, new ServiceCallback<Paragraph>() {
+          @Override
+          public void onStart(String message, ServiceContext context) throws IOException {
+          }
 
-        @Override
-        public void onSuccess(Paragraph result, ServiceContext context) throws IOException {
-        }
+          @Override
+          public void onSuccess(Paragraph result, ServiceContext context) throws IOException {
+          }
 
-        @Override
-        public void onFailure(Exception ex, ServiceContext context) throws IOException {
+          @Override
+          public void onFailure(Exception ex, ServiceContext context) throws IOException {
+          }
+        });
+        if (zConf.getNotebookRunAutoShutdown()) {
+          shutdown(success ? 0 : 1);
         }
-      });
-
-      if (conf.getNotebookRunAutoShutdown()) {
-        shutdown(conf, jettyWebServer, sharedServiceLocator);
-        System.exit(success ? 0 : 1);
+      } catch (IOException e) {
+        LOGGER.error("Error during Paragraph Execution", e);
       }
     }
   }
 
-  private static void setupNotebookServer(WebAppContext webapp, ZeppelinConfiguration conf) {
-    String maxTextMessageSize = conf.getWebsocketMaxTextMessageSize();
+  private void setupNotebookServer(WebAppContext webapp) {
+    String maxTextMessageSize = zConf.getWebsocketMaxTextMessageSize();
     WebSocketServerContainerInitializer
             .configure(webapp, (servletContext, wsContainer) -> {
               wsContainer.setDefaultMaxTextMessageBufferSize(Integer.parseInt(maxTextMessageSize));
-              wsContainer.addEndpoint(NotebookServer.class);
+              wsContainer.addEndpoint(ServerEndpointConfig.Builder.create(NotebookServer.class, "/ws")
+              .configurator(new SessionConfigurator(sharedServiceLocator)).build());
             });
   }
 
-  private static void setupClusterManagerServer(ServiceLocator serviceLocator, ZeppelinConfiguration conf) {
-    if (conf.isClusterMode()) {
-      LOG.info("Cluster mode is enabled, starting ClusterManagerServer");
-      ClusterManagerServer clusterManagerServer = ClusterManagerServer.getInstance(conf);
-
-      NotebookServer notebookServer = serviceLocator.getService(NotebookServer.class);
-      clusterManagerServer.addClusterEventListeners(ClusterManagerServer.CLUSTER_NOTE_EVENT_TOPIC, notebookServer);
-
-      AuthorizationService authorizationService = serviceLocator.getService(AuthorizationService.class);
-      clusterManagerServer.addClusterEventListeners(ClusterManagerServer.CLUSTER_AUTH_EVENT_TOPIC, authorizationService);
-
-      InterpreterSettingManager interpreterSettingManager = serviceLocator.getService(InterpreterSettingManager.class);
-      clusterManagerServer.addClusterEventListeners(ClusterManagerServer.CLUSTER_INTP_SETTING_EVENT_TOPIC, interpreterSettingManager);
-
-      // Since the ClusterInterpreterLauncher is lazy, dynamically generated, So in cluster mode,
-      // when the zeppelin service starts, Create a ClusterInterpreterLauncher object,
-      // This allows the ClusterInterpreterLauncher to listen for cluster events.
-      try {
-        InterpreterSettingManager intpSettingManager = serviceLocator.getService(InterpreterSettingManager.class);
-        RecoveryStorage recoveryStorage = ReflectionUtils.createClazzInstance(
-                conf.getRecoveryStorageClass(),
-                new Class[] {ZeppelinConfiguration.class, InterpreterSettingManager.class},
-                new Object[] {conf, intpSettingManager});
-        recoveryStorage.init();
-        PluginManager.get().loadInterpreterLauncher(InterpreterSetting.CLUSTER_INTERPRETER_LAUNCHER_NAME, recoveryStorage);
-      } catch (IOException e) {
-        LOG.error(e.getMessage(), e);
-      }
-
-      clusterManagerServer.start();
-    } else {
-      LOG.info("Cluster mode is disabled");
-    }
-  }
-
-  private static SslContextFactory getSslContextFactory(ZeppelinConfiguration conf) {
+  private static SslContextFactory getSslContextFactory(ZeppelinConfiguration zConf) {
     SslContextFactory.Server sslContextFactory = new SslContextFactory.Server();
 
     // initialize KeyStore
     // Check for PEM files
-    if (StringUtils.isNoneBlank(conf.getPemKeyFile(), conf.getPemCertFile())) {
-      setupKeystoreWithPemFiles(sslContextFactory, conf);
+    if (StringUtils.isNoneBlank(zConf.getPemKeyFile(), zConf.getPemCertFile())) {
+      setupKeystoreWithPemFiles(sslContextFactory, zConf);
     } else {
       // Set keystore
-      sslContextFactory.setKeyStorePath(conf.getKeyStorePath());
-      sslContextFactory.setKeyStoreType(conf.getKeyStoreType());
-      sslContextFactory.setKeyStorePassword(conf.getKeyStorePassword());
-      sslContextFactory.setKeyManagerPassword(conf.getKeyManagerPassword());
+      sslContextFactory.setKeyStorePath(zConf.getKeyStorePath());
+      sslContextFactory.setKeyStoreType(zConf.getKeyStoreType());
+      sslContextFactory.setKeyStorePassword(zConf.getKeyStorePassword());
+      sslContextFactory.setKeyManagerPassword(zConf.getKeyManagerPassword());
     }
 
     // initialize TrustStore
-    if (conf.useClientAuth()) {
-      if (StringUtils.isNotBlank(conf.getPemCAFile())) {
-        setupTruststoreWithPemFiles(sslContextFactory, conf);
+    if (zConf.useClientAuth()) {
+      if (StringUtils.isNotBlank(zConf.getPemCAFile())) {
+        setupTruststoreWithPemFiles(sslContextFactory, zConf);
       } else {
-        sslContextFactory.setNeedClientAuth(conf.useClientAuth());
+        sslContextFactory.setNeedClientAuth(zConf.useClientAuth());
         // Set truststore
-        sslContextFactory.setTrustStorePath(conf.getTrustStorePath());
-        sslContextFactory.setTrustStoreType(conf.getTrustStoreType());
-        sslContextFactory.setTrustStorePassword(conf.getTrustStorePassword());
+        sslContextFactory.setTrustStorePath(zConf.getTrustStorePath());
+        sslContextFactory.setTrustStoreType(zConf.getTrustStoreType());
+        sslContextFactory.setTrustStorePassword(zConf.getTrustStorePassword());
       }
     }
 
     return sslContextFactory;
   }
 
-  private static void setupKeystoreWithPemFiles(SslContextFactory.Server sslContextFactory, ZeppelinConfiguration conf) {
-    File pemKey = new File(conf.getPemKeyFile());
-    File pemCert = new File(conf.getPemCertFile());
+  private static void setupKeystoreWithPemFiles(SslContextFactory.Server sslContextFactory, ZeppelinConfiguration zConf) {
+    File pemKey = new File(zConf.getPemKeyFile());
+    File pemCert = new File(zConf.getPemCertFile());
     boolean isPemKeyFileReadable = Files.isReadable(pemKey.toPath());
     boolean isPemCertFileReadable = Files.isReadable(pemCert.toPath());
     if (!isPemKeyFileReadable) {
-      LOG.warn("PEM key file {} is not readable", pemKey);
+      LOGGER.warn("PEM key file {} is not readable", pemKey);
     }
     if (!isPemCertFileReadable) {
-      LOG.warn("PEM cert file {} is not readable", pemCert);
+      LOGGER.warn("PEM cert file {} is not readable", pemCert);
     }
     if (isPemKeyFileReadable && isPemCertFileReadable) {
       try {
-        String password = conf.getPemKeyPassword();
+        String password = zConf.getPemKeyPassword();
         sslContextFactory.setKeyStore(PEMImporter.loadKeyStore(pemCert, pemKey, password));
         sslContextFactory.setKeyStoreType("JKS");
         sslContextFactory.setKeyStorePassword(password);
       } catch (IOException | GeneralSecurityException e) {
-        LOG.error("Failed to initialize KeyStore from PEM files", e);
+        LOGGER.error("Failed to initialize KeyStore from PEM files", e);
       }
     } else {
-      LOG.error("Failed to read PEM files");
+      LOGGER.error("Failed to read PEM files");
     }
   }
 
-  private static void setupTruststoreWithPemFiles(SslContextFactory.Server sslContextFactory, ZeppelinConfiguration conf) {
-    File pemCa = new File(conf.getPemCAFile());
+  private static void setupTruststoreWithPemFiles(SslContextFactory.Server sslContextFactory, ZeppelinConfiguration zConf) {
+    File pemCa = new File(zConf.getPemCAFile());
     if (Files.isReadable(pemCa.toPath())) {
       try {
         sslContextFactory.setTrustStore(PEMImporter.loadTrustStore(pemCa));
         sslContextFactory.setTrustStoreType("JKS");
         sslContextFactory.setTrustStorePassword("");
-        sslContextFactory.setNeedClientAuth(conf.useClientAuth());
+        sslContextFactory.setNeedClientAuth(zConf.useClientAuth());
       } catch (IOException | GeneralSecurityException e) {
-        LOG.error("Failed to initialize TrustStore from PEM CA file", e);
+        LOGGER.error("Failed to initialize TrustStore from PEM CA file", e);
       }
     } else {
-      LOG.error("PEM CA file {} is not readable", pemCa);
+      LOGGER.error("PEM CA file {} is not readable", pemCa);
     }
   }
 
-  private static void setupRestApiContextHandler(WebAppContext webapp, ZeppelinConfiguration conf) {
+  private void setupRestApiContextHandler(WebAppContext webapp) {
     final ServletHolder servletHolder =
         new ServletHolder(new org.glassfish.jersey.servlet.ServletContainer());
 
@@ -545,7 +563,7 @@ public class ZeppelinServer {
     servletHolder.setName("rest");
     webapp.addServlet(servletHolder, "/api/*");
 
-    String shiroIniPath = conf.getShiroPath();
+    String shiroIniPath = zConf.getShiroPath();
     if (!StringUtils.isBlank(shiroIniPath)) {
       webapp.setInitParameter("shiroConfigLocations", new File(shiroIniPath).toURI().toString());
       webapp
@@ -555,8 +573,10 @@ public class ZeppelinServer {
     }
   }
 
-  private static void setupPrometheusContextHandler(WebAppContext webapp, PrometheusMeterRegistry promMetricRegistry) {
-    webapp.addServlet(new ServletHolder(new PrometheusServlet(promMetricRegistry)), "/metrics");
+  private void setupPrometheusContextHandler(WebAppContext webapp) {
+    if (promMetricRegistry.isPresent()) {
+      webapp.addServlet(new ServletHolder(new PrometheusServlet(promMetricRegistry.get())), "/metrics");
+    }
   }
 
   private static void setupHealthCheckContextHandler(WebAppContext webapp) {
@@ -566,10 +586,10 @@ public class ZeppelinServer {
   }
 
   private static WebAppContext setupWebAppContext(
-      ContextHandlerCollection contexts, ZeppelinConfiguration conf, String warPath, String contextPath) {
+      ContextHandlerCollection contexts, ZeppelinConfiguration zConf, String warPath, String contextPath) {
     WebAppContext webApp = new WebAppContext();
     webApp.setContextPath(contextPath);
-    LOG.info("warPath is: {}", warPath);
+    LOGGER.info("warPath is: {}", warPath);
     File warFile = new File(warPath);
     if (warFile.isDirectory()) {
       // Development mode, read from FS
@@ -579,24 +599,24 @@ public class ZeppelinServer {
       // use packaged WAR
       webApp.setWar(warFile.getAbsolutePath());
       webApp.setExtractWAR(false);
-      File warTempDirectory = new File(conf.getAbsoluteDir(ConfVars.ZEPPELIN_WAR_TEMPDIR) + contextPath);
+      File warTempDirectory = new File(zConf.getAbsoluteDir(ConfVars.ZEPPELIN_WAR_TEMPDIR) + contextPath);
       warTempDirectory.mkdir();
-      LOG.info("ZeppelinServer Webapp path: {}", warTempDirectory.getPath());
+      LOGGER.info("ZeppelinServer Webapp path: {}", warTempDirectory.getPath());
       webApp.setTempDirectory(warTempDirectory);
     }
     // Explicit bind to root
-    webApp.addServlet(new ServletHolder(new IndexHtmlServlet(conf)), "/index.html");
+    webApp.addServlet(new ServletHolder(new IndexHtmlServlet(zConf, contextPath)), "/index.html");
     contexts.addHandler(webApp);
 
-    webApp.addFilter(new FilterHolder(CorsFilter.class), "/*", EnumSet.allOf(DispatcherType.class));
+    webApp.addFilter(new FilterHolder(new CorsFilter(zConf)), "/*", EnumSet.allOf(DispatcherType.class));
 
     webApp.setInitParameter(
         "org.eclipse.jetty.servlet.Default.dirAllowed",
-        Boolean.toString(conf.getBoolean(ConfVars.ZEPPELIN_SERVER_DEFAULT_DIR_ALLOWED)));
+        Boolean.toString(zConf.getBoolean(ConfVars.ZEPPELIN_SERVER_DEFAULT_DIR_ALLOWED)));
     return webApp;
   }
 
-  private static void initWebApp(WebAppContext webApp, ZeppelinConfiguration conf, ServiceLocator sharedServiceLocator, PrometheusMeterRegistry promMetricRegistry) {
+  private void initWebApp(WebAppContext webApp) {
     webApp.addEventListener(
             new ServletContextListener() {
               @Override
@@ -611,16 +631,23 @@ public class ZeppelinServer {
             });
 
     // Create `ZeppelinServer` using reflection and setup REST Api
-    setupRestApiContextHandler(webApp, conf);
+    setupRestApiContextHandler(webApp);
 
     // prometheus endpoint
-    if (promMetricRegistry != null) {
-      setupPrometheusContextHandler(webApp, promMetricRegistry);
-    }
+    setupPrometheusContextHandler(webApp);
     // health endpoints
     setupHealthCheckContextHandler(webApp);
 
     // Notebook server
-    setupNotebookServer(webApp, conf);
+    setupNotebookServer(webApp);
+  }
+
+  private static boolean isNewUiDefault(ZeppelinConfiguration zConf) {
+    return zConf.getDefaultUi() == DEFAULT_UI.NEW;
+  }
+
+  @Override
+  public void close() throws Exception {
+    shutdown();
   }
 }
