@@ -45,22 +45,22 @@ public class JobManagerService {
 
   private final Notebook notebook;
   private final AuthorizationService authorizationService;
-  private final ZeppelinConfiguration conf;
+  private final ZeppelinConfiguration zConf;
 
   @Inject
   public JobManagerService(Notebook notebook,
                            AuthorizationService authorizationService,
-                           ZeppelinConfiguration conf) {
+                           ZeppelinConfiguration zConf) {
     this.notebook = notebook;
     this.authorizationService = authorizationService;
-    this.conf = conf;
+    this.zConf = zConf;
   }
 
   public List<NoteJobInfo> getNoteJobInfo(String noteId,
                                           ServiceContext context,
                                           ServiceCallback<List<NoteJobInfo>> callback)
       throws IOException {
-    if (!conf.isJobManagerEnabled()) {
+    if (!zConf.isJobManagerEnabled()) {
       return new ArrayList<>();
     }
 
@@ -84,7 +84,7 @@ public class JobManagerService {
                                                     ServiceContext context,
                                                     ServiceCallback<List<NoteJobInfo>> callback)
       throws IOException {
-    if (!conf.isJobManagerEnabled()) {
+    if (!zConf.isJobManagerEnabled()) {
       return new ArrayList<>();
     }
 
@@ -104,7 +104,7 @@ public class JobManagerService {
   public void removeNoteJobInfo(String noteId,
                                 ServiceContext context,
                                 ServiceCallback<List<NoteJobInfo>> callback) throws IOException {
-    if (!conf.isJobManagerEnabled()) {
+    if (!zConf.isJobManagerEnabled()) {
       return;
     }
     List<NoteJobInfo> notesJobInfo = new ArrayList<>();
