@@ -21,6 +21,7 @@ import com.google.gson.reflect.TypeToken;
 import org.apache.commons.io.FileUtils;
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.util.EntityUtils;
+import org.apache.zeppelin.MiniZeppelinServer;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.interpreter.InterpreterException;
 import org.apache.zeppelin.interpreter.InterpreterSetting;
@@ -32,55 +33,70 @@ import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.rest.AbstractTestRestApi;
 import org.apache.zeppelin.scheduler.Job;
-import org.apache.zeppelin.server.ZeppelinServer;
 import org.apache.zeppelin.user.AuthenticationInfo;
-import org.apache.zeppelin.utils.TestUtils;
-import org.glassfish.hk2.api.ServiceLocatorFactory;
-import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.fail;
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.awaitility.Awaitility.await;
 
 import java.io.File;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.Map;
+import java.util.concurrent.Callable;
 
 class RecoveryTest extends AbstractTestRestApi {
-
+  private static final Logger LOGGER = LoggerFactory.getLogger(RecoveryTest.class);
   private Gson gson = new Gson();
   private static File recoveryDir = null;
+  private static MiniZeppelinServer zepServer;
 
   private Notebook notebook;
 
   private AuthenticationInfo anonymous = new AuthenticationInfo("anonymous");
 
-  @BeforeEach
-  void init() throws Exception {
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_RECOVERY_STORAGE_CLASS.getVarName(),
-            FileSystemRecoveryStorage.class.getName());
+  @BeforeAll
+  static void init() throws Exception {
+    zepServer = new MiniZeppelinServer(RecoveryTest.class.getSimpleName());
+    zepServer.addInterpreter("sh");
+    zepServer.addInterpreter("python");
+    zepServer.copyLogProperties();
+    zepServer.copyBinDir();
+    zepServer.getZeppelinConfiguration().setProperty(
+        ZeppelinConfiguration.ConfVars.ZEPPELIN_RECOVERY_STORAGE_CLASS.getVarName(),
+        FileSystemRecoveryStorage.class.getName());
     recoveryDir = Files.createTempDirectory("recovery").toFile();
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_RECOVERY_DIR.getVarName(),
-            recoveryDir.getAbsolutePath());
-    startUp(RecoveryTest.class.getSimpleName());
+    zepServer.getZeppelinConfiguration().setProperty(
+        ZeppelinConfiguration.ConfVars.ZEPPELIN_RECOVERY_DIR.getVarName(),
+        recoveryDir.getAbsolutePath());
+    zepServer.start();
 
-    notebook = ServiceLocatorFactory.getInstance().find(ZeppelinServer.SERVICE_LOCATOR_NAME).getService(Notebook.class);
   }
 
-  @AfterEach
-  void destroy() throws Exception {
-    shutDown(true, true);
+  @AfterAll
+  static void destroy() throws Exception {
+    zepServer.destroy();
     FileUtils.deleteDirectory(recoveryDir);
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_RECOVERY_STORAGE_CLASS.getVarName(),
-            ZeppelinConfiguration.ConfVars.ZEPPELIN_RECOVERY_STORAGE_CLASS.getStringValue());
   }
 
+  @BeforeEach
+  void setUp() {
+    zConf = zepServer.getZeppelinConfiguration();
+    notebook = zepServer.getService(Notebook.class);
+    anonymous = new AuthenticationInfo("anonymous");
+  }
+
+
   @Test
   void testRecovery() throws Exception {
-    LOG.info("Test testRecovery");
+    LOGGER.info("Test testRecovery");
     String note1Id = null;
     try {
       note1Id = notebook.createNote("note1", anonymous);
@@ -102,17 +118,17 @@ class RecoveryTest extends AbstractTestRestApi {
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           assertEquals(Job.Status.FINISHED, p1.getStatus());
-          TestUtils.getInstance(Notebook.class).saveNote(note1, anonymous);
+          notebook.saveNote(note1, anonymous);
           return null;
         });
 
       // shutdown zeppelin and restart it
-      shutDown();
-      startUp(RecoveryTest.class.getSimpleName(), false);
+      zepServer.shutDown(false);
+      zepServer.start();
 
       // run the paragraph again, but change the text to print variable `user`
       Thread.sleep(10 * 1000);
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           p1 = note1.getParagraph(p1.getId());
@@ -122,7 +138,7 @@ class RecoveryTest extends AbstractTestRestApi {
       post = httpPost("/notebook/job/" + note1Id + "?blocking=true", "");
       assertEquals("OK", resp.get("status"));
       post.close();
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           assertEquals(Job.Status.FINISHED, p1.getStatus());
@@ -130,18 +146,18 @@ class RecoveryTest extends AbstractTestRestApi {
           return null;
         });
     } catch (Exception e) {
-      LOG.error(e.toString(), e);
+      LOGGER.error(e.toString(), e);
       throw e;
     } finally {
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testRecovery_2() throws Exception {
-    LOG.info("Test testRecovery_2");
+    LOGGER.info("Test testRecovery_2");
     String note1Id = null;
     try {
       note1Id = notebook.createNote("note2", AuthenticationInfo.ANONYMOUS);
@@ -163,10 +179,10 @@ class RecoveryTest extends AbstractTestRestApi {
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           assertEquals(Job.Status.FINISHED, p1.getStatus());
-          TestUtils.getInstance(Notebook.class).saveNote(note1, AuthenticationInfo.ANONYMOUS);
+          notebook.saveNote(note1, AuthenticationInfo.ANONYMOUS);
           // restart the python interpreter
           try {
-            TestUtils.getInstance(Notebook.class).getInterpreterSettingManager().restart(
+            notebook.getInterpreterSettingManager().restart(
                 ((ManagedInterpreterGroup) p1.getBindedInterpreter().getInterpreterGroup())
                     .getInterpreterSetting().getId()
             );
@@ -177,13 +193,13 @@ class RecoveryTest extends AbstractTestRestApi {
         });
 
       // shutdown zeppelin and restart it
-      shutDown();
-      startUp(RecoveryTest.class.getSimpleName(), false);
+      zepServer.shutDown();
+      zepServer.start();
 
       Thread.sleep(5 * 1000);
       // run the paragraph again, but change the text to print variable `user`.
       // can not recover the python interpreter, because it has been shutdown.
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           p1.setText("%python print(user)");
@@ -192,29 +208,29 @@ class RecoveryTest extends AbstractTestRestApi {
       post = httpPost("/notebook/job/" + note1Id + "?blocking=true", "");
       assertEquals("OK", resp.get("status"));
       post.close();
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           assertEquals(Job.Status.ERROR, p1.getStatus());
           return null;
         });
     } catch (Exception e) {
-      LOG.error(e.toString(), e);
+      LOGGER.error(e.toString(), e);
       throw e;
     } finally {
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testRecovery_3() throws Exception {
-    LOG.info("Test testRecovery_3");
+    LOGGER.info("Test testRecovery_3");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note3", AuthenticationInfo.ANONYMOUS);
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      note1Id = notebook.createNote("note3", AuthenticationInfo.ANONYMOUS);
+      notebook.processNote(note1Id,
         note1 -> {
           // run python interpreter and create new variable `user`
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -228,24 +244,22 @@ class RecoveryTest extends AbstractTestRestApi {
               new TypeToken<Map<String, Object>>() {}.getType());
       assertEquals("OK", resp.get("status"));
       post.close();
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           assertEquals(Job.Status.FINISHED, p1.getStatus());
-          TestUtils.getInstance(Notebook.class).saveNote(note1, AuthenticationInfo.ANONYMOUS);
+          notebook.saveNote(note1, AuthenticationInfo.ANONYMOUS);
           return null;
         });
 
       // shutdown zeppelin and restart it
-      shutDown();
-      StopInterpreter.main(new String[]{});
-
-      startUp(RecoveryTest.class.getSimpleName(), false);
-
+      zepServer.shutDown();
+      new StopInterpreter(zConf);
+      zepServer.start();
       Thread.sleep(5 * 1000);
       // run the paragraph again, but change the text to print variable `user`.
       // can not recover the python interpreter, because it has been shutdown.
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           p1.setText("%python print(user)");
@@ -255,29 +269,38 @@ class RecoveryTest extends AbstractTestRestApi {
       post = httpPost("/notebook/job/" + note1Id + "?blocking=true", "");
       assertEquals("OK", resp.get("status"));
       post.close();
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           assertEquals(Job.Status.ERROR, p1.getStatus());
           return null;
         });
     } catch (Exception e ) {
-      LOG.error(e.toString(), e);
+      LOGGER.error(e.toString(), e);
       throw e;
     } finally {
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
+  private Callable<Boolean> hasParagraphStatus(Paragraph p, Job.Status status) {
+    return () -> p.getStatus().equals(status);
+  }
+
+  private Callable<Boolean> isParagraphTerminated(Paragraph p) {
+    return () -> p.isTerminated();
+  }
+
   @Test
   void testRecovery_Running_Paragraph_sh() throws Exception {
-    LOG.info("Test testRecovery_Running_Paragraph_sh");
+    LOGGER.info("Test testRecovery_Running_Paragraph_sh");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note4", AuthenticationInfo.ANONYMOUS);
-      Paragraph p1 = TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      note1Id = notebook.createNote("note4",
+          AuthenticationInfo.ANONYMOUS);
+      Paragraph p1 = notebook.processNote(note1Id,
         note1 -> {
           return note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
         });
@@ -286,58 +309,48 @@ class RecoveryTest extends AbstractTestRestApi {
       CloseableHttpResponse post = httpPost("/notebook/job/" + note1Id + "/" + p1.getId(), "");
       assertThat(post, isAllowed());
       post.close();
-      long start = System.currentTimeMillis();
       // wait until paragraph is RUNNING
-      while((System.currentTimeMillis() - start) < 10 * 1000) {
-        if (p1.getStatus() == Job.Status.RUNNING) {
-          break;
-        }
-        Thread.sleep(1000);
-      }
+      await().until(hasParagraphStatus(p1, Job.Status.RUNNING));
       if (p1.getStatus() != Job.Status.RUNNING) {
         fail("Fail to run paragraph: " + p1.getReturn());
       }
 
       // shutdown zeppelin and restart it
-      shutDown();
-      startUp(RecoveryTest.class.getSimpleName(), false);
+      zepServer.shutDown();
+      zepServer.start();
 
       // wait until paragraph is finished
-      start = System.currentTimeMillis();
-      while((System.currentTimeMillis() - start) < 10 * 1000) {
-        if (p1.isTerminated()) {
-          break;
-        }
-        Thread.sleep(1000);
-      }
-
+      await().until(isParagraphTerminated(p1));
+      // Wait because paragraph is re submited
+      Thread.sleep(11 * 1000);
       assertEquals(Job.Status.FINISHED, p1.getStatus());
       assertEquals("hello\n", p1.getReturn().message().get(0).getData());
       Thread.sleep(5 * 1000);
     } catch (Exception e ) {
-      LOG.error(e.toString(), e);
+      LOGGER.error(e.toString(), e);
       throw e;
     } finally {
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testRecovery_Finished_Paragraph_python() throws Exception {
-    LOG.info("Test testRecovery_Finished_Paragraph_python");
+    LOGGER.info("Test testRecovery_Finished_Paragraph_python");
     String note1Id = null;
     try {
-      InterpreterSettingManager interpreterSettingManager = TestUtils.getInstance(InterpreterSettingManager.class);
+      InterpreterSettingManager interpreterSettingManager =
+          zepServer.getService(InterpreterSettingManager.class);
       InterpreterSetting interpreterSetting = interpreterSettingManager.getInterpreterSettingByName("python");
       interpreterSetting.setProperty("zeppelin.python.useIPython", "false");
       interpreterSetting.setProperty("zeppelin.interpreter.result.cache", "100");
 
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note4", AuthenticationInfo.ANONYMOUS);
+      note1Id = notebook.createNote("note4", AuthenticationInfo.ANONYMOUS);
 
       // run  paragraph async, print 'hello' after 10 seconds
-      Paragraph p1 = TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      Paragraph p1 = notebook.processNote(note1Id,
         note1 -> {
           return note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
         });
@@ -355,11 +368,11 @@ class RecoveryTest extends AbstractTestRestApi {
       }
 
       // shutdown zeppelin and restart it
-      shutDown();
+      zepServer.shutDown();
       // sleep 15 seconds to make sure the paragraph is finished
       Thread.sleep(15 * 1000);
 
-      startUp(RecoveryTest.class.getSimpleName(), false);
+      zepServer.start();
       // sleep 10 seconds to make sure recovering is finished
       Thread.sleep(10 * 1000);
 
@@ -374,11 +387,11 @@ class RecoveryTest extends AbstractTestRestApi {
               "8\n" +
               "9\n", p1.getReturn().message().get(0).getData());
     } catch (Exception e ) {
-      LOG.error(e.toString(), e);
+      LOGGER.error(e.toString(), e);
       throw e;
     } finally {
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
