@@ -24,19 +24,21 @@ import com.google.gson.reflect.TypeToken;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.util.EntityUtils;
+import org.apache.zeppelin.MiniZeppelinServer;
 import org.apache.zeppelin.interpreter.InterpreterOption;
 import org.apache.zeppelin.interpreter.InterpreterSetting;
 import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.scheduler.Job.Status;
 import org.apache.zeppelin.user.AuthenticationInfo;
-import org.apache.zeppelin.utils.TestUtils;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.MethodOrderer;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.TestMethodOrder;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
@@ -53,21 +55,29 @@ import static org.junit.jupiter.api.Assertions.assertNotNull;
  */
 @TestMethodOrder(MethodOrderer.MethodName.class)
 class InterpreterRestApiTest extends AbstractTestRestApi {
+  private static final Logger LOGGER = LoggerFactory.getLogger(InterpreterRestApiTest.class);
   private Gson gson = new Gson();
   private AuthenticationInfo anonymous;
+  private static MiniZeppelinServer zepServer;
+  private Notebook notebook;
 
   @BeforeAll
   static void init() throws Exception {
-    AbstractTestRestApi.startUp(InterpreterRestApiTest.class.getSimpleName());
+    zepServer = new MiniZeppelinServer(InterpreterRestApiTest.class.getSimpleName());
+    zepServer.copyBinDir();
+    zepServer.addInterpreter("md");
+    zepServer.start();
   }
 
   @AfterAll
   static void destroy() throws Exception {
-    AbstractTestRestApi.shutDown();
+    zepServer.destroy();
   }
 
   @BeforeEach
   void setUp() {
+    zConf = zepServer.getZeppelinConfiguration();
+    notebook = zepServer.getService(Notebook.class);
     anonymous = new AuthenticationInfo("anonymous");
   }
 
@@ -79,7 +89,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
 
     // then
     assertThat(get, isAllowed());
-    assertEquals(TestUtils.getInstance(Notebook.class).getInterpreterSettingManager()
+    assertEquals(notebook.getInterpreterSettingManager()
                     .getInterpreterSettingTemplates().size(), body.entrySet().size());
     get.close();
   }
@@ -119,7 +129,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
     JsonObject jsonRequest = gson.fromJson(rawRequest, JsonElement.class).getAsJsonObject();
     CloseableHttpResponse post = httpPost("/interpreter/setting/", jsonRequest.toString());
     String postResponse = EntityUtils.toString(post.getEntity(), StandardCharsets.UTF_8);
-    LOG.info("testSettingCRUD create response\n" + postResponse);
+    LOGGER.info("testSettingCRUD create response\n" + postResponse);
     InterpreterSetting created = convertResponseToInterpreterSetting(postResponse);
     String newSettingId = created.getId();
     // then : call create setting API
@@ -129,7 +139,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
     // when: call read setting API
     CloseableHttpResponse get = httpGet("/interpreter/setting/" + newSettingId);
     String getResponse = EntityUtils.toString(get.getEntity(), StandardCharsets.UTF_8);
-    LOG.info("testSettingCRUD get response\n" + getResponse);
+    LOGGER.info("testSettingCRUD get response\n" + getResponse);
     InterpreterSetting previouslyCreated = convertResponseToInterpreterSetting(getResponse);
     // then : read Setting API
     assertThat("Test get method:", get, isAllowed());
@@ -143,14 +153,14 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
     jsonObject.addProperty("type", "textarea");
     jsonRequest.getAsJsonObject("properties").add("propname2", jsonObject);
     CloseableHttpResponse put = httpPut("/interpreter/setting/" + newSettingId, jsonRequest.toString());
-    LOG.info("testSettingCRUD update response\n" + EntityUtils.toString(put.getEntity(), StandardCharsets.UTF_8));
+    LOGGER.info("testSettingCRUD update response\n" + EntityUtils.toString(put.getEntity(), StandardCharsets.UTF_8));
     // then: call update setting API
     assertThat("test update method:", put, isAllowed());
     put.close();
 
     // when: call delete setting API
     CloseableHttpResponse delete = httpDelete("/interpreter/setting/" + newSettingId);
-    LOG.info("testSettingCRUD delete response\n" +  EntityUtils.toString(delete.getEntity(), StandardCharsets.UTF_8));
+    LOGGER.info("testSettingCRUD delete response\n" +  EntityUtils.toString(delete.getEntity(), StandardCharsets.UTF_8));
     // then: call delete setting API
     assertThat("Test delete method:", delete, isAllowed());
     delete.close();
@@ -229,7 +239,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
   void testSettingsCreateWithEmptyJson() throws IOException {
     // Call Create Setting REST API
     CloseableHttpResponse post = httpPost("/interpreter/setting/", "");
-    LOG.info("testSettingCRUD create response\n" + EntityUtils.toString(post.getEntity(), StandardCharsets.UTF_8));
+    LOGGER.info("testSettingCRUD create response\n" + EntityUtils.toString(post.getEntity(), StandardCharsets.UTF_8));
     assertThat("test create method:", post, isBadRequest());
     post.close();
   }
@@ -261,7 +271,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
     JsonObject jsonRequest = gson.fromJson(StringUtils.replace(reqBody, "mdName", "mdValidName"), JsonElement.class).getAsJsonObject();
     CloseableHttpResponse post = httpPost("/interpreter/setting/", jsonRequest.toString());
     String postResponse = EntityUtils.toString(post.getEntity(), StandardCharsets.UTF_8);
-    LOG.info("testSetting with valid name\n" + postResponse);
+    LOGGER.info("testSetting with valid name\n" + postResponse);
     InterpreterSetting created = convertResponseToInterpreterSetting(postResponse);
     String newSettingId = created.getId();
     // then : call create setting API
@@ -270,7 +280,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
 
     // when: call delete setting API
     CloseableHttpResponse delete = httpDelete("/interpreter/setting/" + newSettingId);
-    LOG.info("testSetting delete response\n" + EntityUtils.toString(delete.getEntity(), StandardCharsets.UTF_8));
+    LOGGER.info("testSetting delete response\n" + EntityUtils.toString(delete.getEntity(), StandardCharsets.UTF_8));
     // then: call delete setting API
     assertThat("Test delete method:", delete, isAllowed());
     delete.close();
@@ -278,13 +288,13 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
 
     JsonObject jsonRequest2 = gson.fromJson(StringUtils.replace(reqBody, "mdName", "name space"), JsonElement.class).getAsJsonObject();
     CloseableHttpResponse post2 = httpPost("/interpreter/setting/", jsonRequest2.toString());
-    LOG.info("testSetting with name with space\n" + EntityUtils.toString(post2.getEntity(), StandardCharsets.UTF_8));
+    LOGGER.info("testSetting with name with space\n" + EntityUtils.toString(post2.getEntity(), StandardCharsets.UTF_8));
     assertThat("test create method with space:", post2, isNotFound());
     post2.close();
 
     JsonObject jsonRequest3 = gson.fromJson(StringUtils.replace(reqBody, "mdName", ""), JsonElement.class).getAsJsonObject();
     CloseableHttpResponse post3 = httpPost("/interpreter/setting/", jsonRequest3.toString());
-    LOG.info("testSetting with empty name\n" + EntityUtils.toString(post3.getEntity(), StandardCharsets.UTF_8));
+    LOGGER.info("testSetting with empty name\n" + EntityUtils.toString(post3.getEntity(), StandardCharsets.UTF_8));
     assertThat("test create method with empty name:", post3, isNotFound());
     post3.close();
 
@@ -295,9 +305,9 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
     String noteId = null;
     try {
       // when: create new note
-      noteId = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      noteId = notebook.createNote("note1", anonymous);
 
-      String pId = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      String pId = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Map<String, Object> config = p.getConfig();
@@ -311,21 +321,21 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
           return p.getId();
         });
 
-      Status status = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      Status status = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.getParagraph(pId);
           return p.getStatus();
         });
       while (status != Status.FINISHED) {
          Thread.sleep(100);
-         status = TestUtils.getInstance(Notebook.class).processNote(noteId,
+         status = notebook.processNote(noteId,
            note -> {
              Paragraph p = note.getParagraph(pId);
               return p.getStatus();
            });
       }
 
-      List<InterpreterSetting> settings = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      List<InterpreterSetting> settings = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.getParagraph(pId);
           assertEquals(p.getReturn().message().get(0).getData(), getSimulatedMarkdownResult("markdown"));
@@ -344,7 +354,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
       }
 
       // when: run markdown paragraph, again
-      String p2Id = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      String p2Id = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Map<String, Object> config = p.getConfig();
@@ -358,14 +368,14 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
           return p.getId();
         });
 
-      status = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      status = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.getParagraph(p2Id);
           return p.getStatus();
         });
       while (status != Status.FINISHED) {
         Thread.sleep(100);
-        status = TestUtils.getInstance(Notebook.class).processNote(noteId,
+        status = notebook.processNote(noteId,
           note -> {
             Paragraph p = note.getParagraph(p2Id);
             return p.getStatus();
@@ -373,7 +383,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
       }
 
       // then
-      status = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      status = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.getParagraph(p2Id);
           assertEquals(p.getReturn().message().get(0).getData(),
@@ -382,7 +392,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
         });
     } finally {
       if (null != noteId) {
-        TestUtils.getInstance(Notebook.class).removeNote(noteId, anonymous);
+        notebook.removeNote(noteId, anonymous);
       }
     }
   }
@@ -392,8 +402,8 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
     String noteId = null;
     try {
       // when: create new note
-      noteId = TestUtils.getInstance(Notebook.class).createNote("note2", anonymous);
-      String pId = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      noteId = notebook.createNote("note2", anonymous);
+      String pId = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Map<String, Object> config = p.getConfig();
@@ -406,20 +416,20 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
           return p.getId();
         });
 
-      Status status = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      Status status = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.getParagraph(pId);
           return p.getStatus();
         });
       while (status != Status.FINISHED) {
         Thread.sleep(100);
-        status = TestUtils.getInstance(Notebook.class).processNote(noteId,
+        status = notebook.processNote(noteId,
           note -> {
             Paragraph p = note.getParagraph(pId);
             return p.getStatus();
           });
       }
-      List<InterpreterSetting> settings = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      List<InterpreterSetting> settings = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.getParagraph(pId);
           assertEquals(p.getReturn().message().get(0).getData(), getSimulatedMarkdownResult("markdown"));
@@ -457,7 +467,7 @@ class InterpreterRestApiTest extends AbstractTestRestApi {
 
     } finally {
       if (null != noteId) {
-        TestUtils.getInstance(Notebook.class).removeNote(noteId, anonymous);
+        notebook.removeNote(noteId, anonymous);
       }
     }
   }
