@@ -24,14 +24,14 @@ import org.apache.zeppelin.interpreter.InterpreterSettingManager;
 import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.notebook.repo.NotebookRepoWithVersionControl;
 import org.apache.zeppelin.rest.message.ParametersRequest;
-import org.apache.zeppelin.socket.NotebookServer;
-import org.apache.zeppelin.utils.TestUtils;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.MethodOrderer;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.TestMethodOrder;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
@@ -39,6 +39,7 @@ import java.util.*;
 
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.util.EntityUtils;
+import org.apache.zeppelin.MiniZeppelinServer;
 import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.Paragraph;
@@ -58,35 +59,45 @@ import static org.junit.jupiter.api.Assertions.fail;
  */
 @TestMethodOrder(MethodOrderer.MethodName.class)
 class NotebookRestApiTest extends AbstractTestRestApi {
+  private static final Logger LOGGER = LoggerFactory.getLogger(NotebookRestApiTest.class);
   Gson gson = new Gson();
   AuthenticationInfo anonymous;
+  private Notebook notebook;
+  private static MiniZeppelinServer zepServer;
 
   @BeforeAll
   static void init() throws Exception {
-    startUp(NotebookRestApiTest.class.getSimpleName());
-    TestUtils.getInstance(Notebook.class).setParagraphJobListener(NotebookServer.getInstance());
+    zepServer = new MiniZeppelinServer(NotebookRestApiTest.class.getSimpleName());
+    zepServer.copyLogProperties();
+    zepServer.addInterpreter("md");
+    zepServer.addInterpreter("python");
+    zepServer.addInterpreter("sh");
+    zepServer.copyBinDir();
+    zepServer.start();
   }
 
   @AfterAll
   static void destroy() throws Exception {
-    AbstractTestRestApi.shutDown();
+    zepServer.destroy();
   }
 
   @BeforeEach
   void setUp() {
+    zConf = zepServer.getZeppelinConfiguration();
+    notebook = zepServer.getService(Notebook.class);
     anonymous = new AuthenticationInfo("anonymous");
   }
 
   @Test
   void testGetReloadNote() throws IOException {
-    LOG.info("Running testGetNote");
+    LOGGER.info("Running testGetNote");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      note1Id = notebook.createNote("note1", anonymous);
+      notebook.processNote(note1Id,
         note1 -> {
           note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
-          TestUtils.getInstance(Notebook.class).saveNote(note1, anonymous);
+            notebook.saveNote(note1, anonymous);
           return null;
         });
 
@@ -98,7 +109,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertEquals(1, ((List)noteObject.get("paragraphs")).size());
 
       // add one new paragraph, but don't save it and reload it again
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           return null;
@@ -114,22 +125,22 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testGetNoteByPath() throws IOException {
-    LOG.info("Running testGetNoteByPath");
+    LOGGER.info("Running testGetNoteByPath");
     String note1Id = null;
     try {
         String notePath = "dir1/note1";
-        note1Id = TestUtils.getInstance(Notebook.class).createNote(notePath, anonymous);
-        TestUtils.getInstance(Notebook.class).processNote(note1Id,
+        note1Id = notebook.createNote(notePath, anonymous);
+        notebook.processNote(note1Id,
                 note1 -> {
                     note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
-                    TestUtils.getInstance(Notebook.class).saveNote(note1, anonymous);
+              notebook.saveNote(note1, anonymous);
                     return null;
                 });
 
@@ -144,14 +155,14 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
         // cleanup
         if (null != note1Id) {
-            TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+          notebook.removeNote(note1Id, anonymous);
         }
     }
   }
 
   @Test
   void testGetNoteByPathWithPathNotExist() throws IOException {
-    LOG.info("Running testGetNoteByPathWithPathNotExist");
+    LOGGER.info("Running testGetNoteByPathWithPathNotExist");
     String notePath = "A note that doesn't exist";
     CloseableHttpResponse post = httpPost("/notebook/getByPath" , "{\"notePath\":\""+ notePath + "\"}" );
     assertThat(post, isNotFound());
@@ -164,9 +175,8 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testGetNoteRevisionHistory() throws IOException {
-    LOG.info("Running testGetNoteRevisionHistory");
+    LOGGER.info("Running testGetNoteRevisionHistory");
     String note1Id = null;
-    Notebook notebook = TestUtils.getInstance(Notebook.class);
     try {
       String notePath = "note1";
       note1Id = notebook.createNote(notePath, anonymous);
@@ -225,9 +235,8 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testGetNoteByRevision() throws IOException {
-    LOG.info("Running testGetNoteByRevision");
+    LOGGER.info("Running testGetNoteByRevision");
     String note1Id = null;
-    Notebook notebook = TestUtils.getInstance(Notebook.class);
     try {
       String notePath = "note1";
       note1Id = notebook.createNote(notePath, anonymous);
@@ -270,11 +279,11 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testGetNoteParagraphJobStatus() throws IOException {
-    LOG.info("Running testGetNoteParagraphJobStatus");
+    LOGGER.info("Running testGetNoteParagraphJobStatus");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
-      String paragraphId = TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      note1Id = notebook.createNote("note1", anonymous);
+      String paragraphId = notebook.processNote(note1Id,
         note1 -> {
           return note1.addNewParagraph(AuthenticationInfo.ANONYMOUS).getId();
         });
@@ -292,16 +301,15 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testCheckpointNote() throws IOException {
-    LOG.info("Running testCheckpointNote");
+    LOGGER.info("Running testCheckpointNote");
     String note1Id = null;
-    Notebook notebook = TestUtils.getInstance(Notebook.class);
     try {
       String notePath = "note1";
       note1Id = notebook.createNote(notePath, anonymous);
@@ -343,9 +351,8 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testSetNoteRevision() throws IOException {
-    LOG.info("Running testSetNoteRevision");
+    LOGGER.info("Running testSetNoteRevision");
     String note1Id = null;
-    Notebook notebook = TestUtils.getInstance(Notebook.class);
     try {
       String notePath = "note1";
       note1Id = notebook.createNote(notePath, anonymous);
@@ -392,11 +399,11 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testRunParagraphJob() throws Exception {
-    LOG.info("Running testRunParagraphJob");
+    LOGGER.info("Running testRunParagraphJob");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
-      Paragraph p = TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      note1Id = notebook.createNote("note1", anonymous);
+      Paragraph p = notebook.processNote(note1Id,
         note1 -> {
           return note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
         });
@@ -413,7 +420,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertEquals(Job.Status.FINISHED, p.getStatus());
 
       // run non-blank paragraph
-      p.setText("test");
+      p.setText("%python \n print(\"hello");
       post = httpPost("/notebook/job/" + note1Id + "/" + p.getId(), "");
       assertThat(post, isAllowed());
       resp = gson.fromJson(EntityUtils.toString(post.getEntity(), StandardCharsets.UTF_8),
@@ -425,16 +432,15 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testCancelNoteJob() throws Exception {
-    LOG.info("Running testCancelNoteJob");
+    LOGGER.info("Running testCancelNoteJob");
     String note1Id = null;
-    Notebook notebook = TestUtils.getInstance(Notebook.class);
     try {
       note1Id = notebook.createNote("note1", anonymous);
       // Add 3 paragraphs for the note.
@@ -476,11 +482,11 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testRunParagraphSynchronously() throws IOException {
-    LOG.info("Running testRunParagraphSynchronously");
+    LOGGER.info("Running testRunParagraphSynchronously");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
-      Paragraph p = TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      note1Id = notebook.createNote("note1", anonymous);
+      Paragraph p = notebook.processNote(note1Id,
         note1 -> {
           return note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
         });
@@ -517,7 +523,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertEquals("ERROR", stringMap.get("code"));
       List<Map> interpreterResults = (List<Map>) stringMap.get("msg");
       assertTrue(interpreterResults.get(0).get("data").toString()
-          .contains("invalid_cmd: command not found"), interpreterResults.get(0).toString());
+          .contains("invalid_cmd: "), interpreterResults.get(0).toString());
       post.close();
       assertNotEquals(Job.Status.READY, p.getStatus());
 
@@ -527,14 +533,14 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testCreateNote() throws Exception {
-    LOG.info("Running testCreateNote");
+    LOGGER.info("Running testCreateNote");
     String message1 = "{\n\t\"name\" : \"test1\",\n\t\"addingEmptyParagraph\" : true\n}";
     CloseableHttpResponse post1 = httpPost("/notebook/", message1);
     assertThat(post1, isAllowed());
@@ -544,7 +550,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     assertEquals("OK", resp1.get("status"));
 
     String note1Id = (String) resp1.get("body");
-    TestUtils.getInstance(Notebook.class).processNote(note1Id,
+    notebook.processNote(note1Id,
       note1 -> {
         assertEquals("test1", note1.getName());
         assertEquals(1, note1.getParagraphCount());
@@ -563,7 +569,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     assertEquals("OK", resp2.get("status"));
 
     String noteId2 = (String) resp2.get("body");
-    Note note2 = TestUtils.getInstance(Notebook.class).processNote(noteId2,
+    Note note2 = notebook.processNote(noteId2,
       note -> {
         return note;
       });
@@ -573,10 +579,10 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testRunNoteBlocking() throws IOException {
-    LOG.info("Running testRunNoteBlocking");
+    LOGGER.info("Running testRunNoteBlocking");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      note1Id = notebook.createNote("note1", anonymous);
       // 2 paragraphs
       // P1:
       //    %python
@@ -588,7 +594,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       //    %python
       //    print(user)
       //
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Paragraph p2 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -604,7 +610,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertEquals("OK", resp.get("status"));
       post.close();
 
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -616,17 +622,17 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testRunNoteNonBlocking() throws Exception {
-    LOG.info("Running testRunNoteNonBlocking");
+    LOGGER.info("Running testRunNoteNonBlocking");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      note1Id = notebook.createNote("note1", anonymous);
       // 2 paragraphs
       // P1:
       //    %python
@@ -638,7 +644,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       //    %%sh(interpolate=true)
       //    echo '{name}'
       //
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Paragraph p2 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -654,7 +660,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertEquals("OK", resp.get("status"));
       post.close();
 
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -672,22 +678,21 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testRunNoteBlocking_Isolated() throws IOException {
-    LOG.info("Running testRunNoteBlocking_Isolated");
+    LOGGER.info("Running testRunNoteBlocking_Isolated");
     String note1Id = null;
     try {
-      InterpreterSettingManager interpreterSettingManager =
-              TestUtils.getInstance(InterpreterSettingManager.class);
+      InterpreterSettingManager interpreterSettingManager = notebook.getInterpreterSettingManager();
       InterpreterSetting interpreterSetting = interpreterSettingManager.getInterpreterSettingByName("python");
       int pythonProcessNum = interpreterSetting.getAllInterpreterGroups().size();
 
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      note1Id = notebook.createNote("note1", anonymous);
       // 2 paragraphs
       // P1:
       //    %python
@@ -699,7 +704,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       //    %python
       //    print(user)
       //
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Paragraph p2 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -715,7 +720,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertEquals("OK", resp.get("status"));
       post.close();
 
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -729,22 +734,21 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testRunNoteNonBlocking_Isolated() throws IOException, InterruptedException {
-    LOG.info("Running testRunNoteNonBlocking_Isolated");
+    LOGGER.info("Running testRunNoteNonBlocking_Isolated");
     String note1Id = null;
     try {
-      InterpreterSettingManager interpreterSettingManager =
-              TestUtils.getInstance(InterpreterSettingManager.class);
+      InterpreterSettingManager interpreterSettingManager = notebook.getInterpreterSettingManager();
       InterpreterSetting interpreterSetting = interpreterSettingManager.getInterpreterSettingByName("python");
       int pythonProcessNum = interpreterSetting.getAllInterpreterGroups().size();
 
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      note1Id = notebook.createNote("note1", anonymous);
       // 2 paragraphs
       // P1:
       //    %python
@@ -756,7 +760,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       //    %python
       //    print(user)
       //
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Paragraph p2 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -774,12 +778,12 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       post.close();
 
       // wait for all the paragraphs are done
-      boolean isRunning = TestUtils.getInstance(Notebook.class).processNote(note1Id, Note::isRunning);
+      boolean isRunning = notebook.processNote(note1Id, Note::isRunning);
       while(isRunning) {
         Thread.sleep(1000);
-        isRunning = TestUtils.getInstance(Notebook.class).processNote(note1Id, Note::isRunning);
+        isRunning = notebook.processNote(note1Id, Note::isRunning);
       }
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -794,7 +798,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
@@ -803,7 +807,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
   void testRunNoteWithParams() throws IOException, InterruptedException {
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      note1Id = notebook.createNote("note1", anonymous);
       // 2 paragraphs
       // P1:
       //    %python
@@ -813,7 +817,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       //    %sh
       //    echo ${name|world}
       //
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Paragraph p2 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -834,12 +838,12 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       post.close();
 
       // wait for all the paragraphs are done
-      boolean isRunning = TestUtils.getInstance(Notebook.class).processNote(note1Id, Note::isRunning);
+      boolean isRunning = notebook.processNote(note1Id, Note::isRunning);
       while(isRunning) {
         Thread.sleep(1000);
-        isRunning = TestUtils.getInstance(Notebook.class).processNote(note1Id, Note::isRunning);
+        isRunning = notebook.processNote(note1Id, Note::isRunning);
       }
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -859,12 +863,12 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       post.close();
 
       // wait for all the paragraphs are done
-      isRunning = TestUtils.getInstance(Notebook.class).processNote(note1Id, Note::isRunning);
+      isRunning = notebook.processNote(note1Id, Note::isRunning);
       while(isRunning) {
         Thread.sleep(1000);
-        isRunning = TestUtils.getInstance(Notebook.class).processNote(note1Id, Note::isRunning);
+        isRunning = notebook.processNote(note1Id, Note::isRunning);
       }
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -877,17 +881,17 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testRunAllParagraph_FirstFailed() throws IOException {
-    LOG.info("Running testRunAllParagraph_FirstFailed");
+    LOGGER.info("Running testRunAllParagraph_FirstFailed");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      note1Id = notebook.createNote("note1", anonymous);
       // 2 paragraphs
       // P1:
       //    %python
@@ -901,7 +905,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       //    user2='abc'
       //    print(user2)
       //
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Paragraph p2 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -915,7 +919,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertThat(post, isAllowed());
       post.close();
 
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -927,20 +931,19 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
 
   @Test
   void testCloneNote() throws IOException {
-    LOG.info("Running testCloneNote");
+    LOGGER.info("Running testCloneNote");
     String note1Id = null;
     List<String> clonedNoteIds = new ArrayList<>();
     String text1 = "%text clone note";
     String text2 = "%text clone revision of note";
     try {
-      Notebook notebook = TestUtils.getInstance(Notebook.class);
       note1Id = notebook.createNote("note1", anonymous);
 
       // add text and commit note
@@ -970,7 +973,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
         String text = Arrays.asList(text1, text2).get(i);
 
         String postResponse = EntityUtils.toString(post.getEntity(), StandardCharsets.UTF_8);
-        LOG.info("testCloneNote response: {}", postResponse);
+        LOGGER.info("testCloneNote response: {}", postResponse);
         assertThat(post, isAllowed());
         Map<String, Object> resp = gson.fromJson(postResponse,
                 new TypeToken<Map<String, Object>>() {
@@ -993,11 +996,11 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
       if (null != clonedNoteIds) {
         for (String clonedNoteId : clonedNoteIds) {
-          TestUtils.getInstance(Notebook.class).removeNote(clonedNoteId, anonymous);
+          notebook.removeNote(clonedNoteId, anonymous);
         }
       }
     }
@@ -1005,12 +1008,12 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
   @Test
   void testRenameNote() throws IOException {
-    LOG.info("Running testRenameNote");
+    LOGGER.info("Running testRenameNote");
     String noteId = null;
     try {
       String oldName = "old_name";
-      noteId = TestUtils.getInstance(Notebook.class).createNote(oldName, anonymous);
-      assertEquals(oldName, TestUtils.getInstance(Notebook.class).processNote(noteId, Note::getName));
+      noteId = notebook.createNote(oldName, anonymous);
+      assertEquals(oldName, notebook.processNote(noteId, Note::getName));
 
       final String newName = "testName";
       String jsonRequest = "{\"name\": " + newName + "}";
@@ -1019,22 +1022,22 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertThat("test testRenameNote:", put, isAllowed());
       put.close();
 
-      assertEquals(newName, TestUtils.getInstance(Notebook.class).processNote(noteId, Note::getName));
+      assertEquals(newName, notebook.processNote(noteId, Note::getName));
     } finally {
       // cleanup
       if (null != noteId) {
-        TestUtils.getInstance(Notebook.class).removeNote(noteId, anonymous);
+        notebook.removeNote(noteId, anonymous);
       }
     }
   }
 
   @Test
   void testUpdateParagraphConfig() throws IOException {
-    LOG.info("Running testUpdateParagraphConfig");
+    LOGGER.info("Running testUpdateParagraphConfig");
     String noteId = null;
     try {
-      noteId = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
-      String paragraphId = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      noteId = notebook.createNote("note1", anonymous);
+      String paragraphId = notebook.processNote(noteId,
         note -> {
           Paragraph p = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           assertNull(p.getConfig().get("colWidth"));
@@ -1054,7 +1057,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       put.close();
 
       assertEquals(config.get("colWidth"), 6.0);
-      TestUtils.getInstance(Notebook.class).processNote(noteId,
+      notebook.processNote(noteId,
         note -> {
           assertEquals(note.getParagraph(paragraphId).getConfig().get("colWidth"), 6.0);
           return null;
@@ -1062,19 +1065,19 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != noteId) {
-        TestUtils.getInstance(Notebook.class).removeNote(noteId, anonymous);
+        notebook.removeNote(noteId, anonymous);
       }
     }
   }
 
   @Test
   void testClearAllParagraphOutput() throws IOException {
-    LOG.info("Running testClearAllParagraphOutput");
+    LOGGER.info("Running testClearAllParagraphOutput");
     String noteId = null;
     try {
       // Create note and set result explicitly
-      noteId = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
-      String p1Id = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      noteId = notebook.createNote("note1", anonymous);
+      String p1Id = notebook.processNote(noteId,
         note -> {
           Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           InterpreterResult result = new InterpreterResult(InterpreterResult.Code.SUCCESS,
@@ -1083,7 +1086,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
           return p1.getId();
         });
 
-      String p2Id = TestUtils.getInstance(Notebook.class).processNote(noteId,
+      String p2Id = notebook.processNote(noteId,
         note -> {
           Paragraph p2 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           InterpreterResult result = new InterpreterResult(InterpreterResult.Code.SUCCESS,
@@ -1094,7 +1097,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
 
       // clear paragraph result
       CloseableHttpResponse put = httpPut("/notebook/" + noteId + "/clear", "");
-      LOG.info("test clear paragraph output response\n" + EntityUtils.toString(put.getEntity(), StandardCharsets.UTF_8));
+      LOGGER.info("test clear paragraph output response\n" + EntityUtils.toString(put.getEntity(), StandardCharsets.UTF_8));
       assertThat(put, isAllowed());
       put.close();
 
@@ -1117,17 +1120,17 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != noteId) {
-        TestUtils.getInstance(Notebook.class).removeNote(noteId, anonymous);
+        notebook.removeNote(noteId, anonymous);
       }
     }
   }
 
   @Test
   void testRunWithServerRestart() throws Exception {
-    LOG.info("Running testRunWithServerRestart");
+    LOGGER.info("Running testRunWithServerRestart");
     String note1Id = null;
     try {
-      note1Id = TestUtils.getInstance(Notebook.class).createNote("note1", anonymous);
+      note1Id = notebook.createNote("note1", anonymous);
       // 2 paragraphs
       // P1:
       //    %python
@@ -1139,7 +1142,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       //    %python
       //    print(user)
       //
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
           Paragraph p2 = note1.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -1153,13 +1156,13 @@ class NotebookRestApiTest extends AbstractTestRestApi {
       assertThat(post1, isAllowed());
       post1.close();
       CloseableHttpResponse put = httpPut("/notebook/" + note1Id + "/clear", "");
-      LOG.info("test clear paragraph output response\n" + EntityUtils.toString(put.getEntity(), StandardCharsets.UTF_8));
+      LOGGER.info("test clear paragraph output response\n" + EntityUtils.toString(put.getEntity(), StandardCharsets.UTF_8));
       assertThat(put, isAllowed());
       put.close();
 
       // restart server (while keeping interpreter configuration)
-      AbstractTestRestApi.shutDown(false);
-      startUp(NotebookRestApiTest.class.getSimpleName(), false);
+      zepServer.shutDown(false);
+      zepServer.start();
 
       CloseableHttpResponse post2 = httpPost("/notebook/job/" + note1Id + "?blocking=true", "");
       assertThat(post2, isAllowed());
@@ -1167,7 +1170,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
           new TypeToken<Map<String, Object>>() {}.getType());
       assertEquals("OK", resp.get("status"));
       post2.close();
-      TestUtils.getInstance(Notebook.class).processNote(note1Id,
+      notebook.processNote(note1Id,
         note1 -> {
           Paragraph p1 = note1.getParagraph(0);
           Paragraph p2 = note1.getParagraph(1);
@@ -1180,7 +1183,7 @@ class NotebookRestApiTest extends AbstractTestRestApi {
     } finally {
       // cleanup
       if (null != note1Id) {
-        TestUtils.getInstance(Notebook.class).removeNote(note1Id, anonymous);
+        notebook.removeNote(note1Id, anonymous);
       }
     }
   }
