@@ -39,6 +39,7 @@ import java.nio.file.Files;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
@@ -54,9 +55,11 @@ import org.apache.zeppelin.interpreter.InterpreterSetting;
 import org.apache.zeppelin.interpreter.InterpreterSettingManager;
 import org.apache.zeppelin.interpreter.ManagedInterpreterGroup;
 import org.apache.zeppelin.notebook.AuthorizationService;
+import org.apache.zeppelin.notebook.GsonNoteParser;
 import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.NoteInfo;
 import org.apache.zeppelin.notebook.NoteManager;
+import org.apache.zeppelin.notebook.NoteParser;
 import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.notebook.exception.NotePathAlreadyExistsException;
@@ -65,12 +68,15 @@ import org.apache.zeppelin.notebook.repo.VFSNotebookRepo;
 import org.apache.zeppelin.notebook.scheduler.QuartzSchedulerService;
 import org.apache.zeppelin.search.LuceneSearch;
 import org.apache.zeppelin.search.SearchService;
+import org.apache.zeppelin.storage.ConfigStorage;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.apache.zeppelin.user.Credentials;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.mockito.ArgumentCaptor;
+import org.junit.jupiter.api.TestInfo;
+
 
 import com.google.gson.Gson;
 
@@ -79,6 +85,7 @@ class NotebookServiceTest {
   private static NotebookService notebookService;
 
   private File notebookDir;
+  private File confDir;
   private SearchService searchService;
   private Notebook notebook;
   private ServiceContext context =
@@ -86,17 +93,29 @@ class NotebookServiceTest {
 
   private ServiceCallback callback = mock(ServiceCallback.class);
 
-  private Gson gson = new Gson();
+  private NoteParser noteParser;
 
 
   @BeforeEach
-  void setUp() throws Exception {
+  void setUp(TestInfo testInfo) throws Exception {
     notebookDir = Files.createTempDirectory("notebookDir").toAbsolutePath().toFile();
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_DIR.getVarName(),
-            notebookDir.getAbsolutePath());
-    ZeppelinConfiguration zeppelinConfiguration = ZeppelinConfiguration.create();
+    ZeppelinConfiguration zConf = ZeppelinConfiguration.load();
+    zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_DIR.getVarName(),
+        notebookDir.getAbsolutePath());
+    // enable cron for testNoteUpdate method
+    if ("testNoteUpdate()".equals(testInfo.getDisplayName())){
+      confDir = Files.createTempDirectory("confDir").toAbsolutePath().toFile();
+      zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_CONF_DIR.getVarName(),
+            confDir.getAbsolutePath());
+      zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_CRON_ENABLE.getVarName(), "true");
+      String shiroPath = zConf.getAbsoluteDir(String.format("%s/shiro.ini", zConf.getConfDir()));
+      Files.createFile(new File(shiroPath).toPath());
+      context.getUserAndRoles().add("test");
+    }
+    noteParser = new GsonNoteParser(zConf);
+    ConfigStorage storage = ConfigStorage.createConfigStorage(zConf);
     NotebookRepo notebookRepo = new VFSNotebookRepo();
-    notebookRepo.init(zeppelinConfiguration);
+    notebookRepo.init(zConf, noteParser);
 
     InterpreterSettingManager mockInterpreterSettingManager = mock(InterpreterSettingManager.class);
     InterpreterFactory mockInterpreterFactory = mock(InterpreterFactory.class);
@@ -116,11 +135,12 @@ class NotebookServiceTest {
     when(mockInterpreterGroup.getInterpreterSetting()).thenReturn(mockInterpreterSetting);
     when(mockInterpreterSetting.getStatus()).thenReturn(InterpreterSetting.Status.READY);
     Credentials credentials = new Credentials();
-    NoteManager noteManager = new NoteManager(notebookRepo, zeppelinConfiguration);
-    AuthorizationService authorizationService = new AuthorizationService(noteManager, zeppelinConfiguration);
+    NoteManager noteManager = new NoteManager(notebookRepo, zConf);
+    AuthorizationService authorizationService =
+        new AuthorizationService(noteManager, zConf, storage);
     notebook =
         new Notebook(
-            zeppelinConfiguration,
+            zConf,
             authorizationService,
             notebookRepo,
             noteManager,
@@ -128,13 +148,13 @@ class NotebookServiceTest {
             mockInterpreterSettingManager,
             credentials,
             null);
-    searchService = new LuceneSearch(zeppelinConfiguration, notebook);
-    QuartzSchedulerService schedulerService = new QuartzSchedulerService(zeppelinConfiguration, notebook);
+    searchService = new LuceneSearch(zConf, notebook);
+    QuartzSchedulerService schedulerService = new QuartzSchedulerService(zConf, notebook);
     notebook.initNotebook();
     notebook.waitForFinishInit(1, TimeUnit.MINUTES);
     notebookService =
         new NotebookService(
-            notebook, authorizationService, zeppelinConfiguration, schedulerService);
+            notebook, authorizationService, zConf, schedulerService);
 
     String interpreterName = "test";
     when(mockInterpreterSetting.getName()).thenReturn(interpreterName);
@@ -145,6 +165,9 @@ class NotebookServiceTest {
   @AfterEach
   void tearDown() {
     notebookDir.delete();
+    if (confDir != null){
+      confDir.delete();
+    }
     searchService.close();
   }
 
@@ -387,6 +410,64 @@ class NotebookServiceTest {
     assertEquals(0, notesInfo.size());
   }
 
+  @Test
+  void testNoteUpdate() throws IOException {
+    // create note
+    String note1Id = notebookService.createNote("/folder_update/note_test_update", "test", true, context, callback);
+    // update note with cron for every 5 minutes
+    reset(callback);
+    Map<String, Object> updatedConfig = new HashMap<>();
+    updatedConfig.put("isZeppelinNotebookCronEnable", true);
+    updatedConfig.put("looknfeel", "looknfeel");
+    updatedConfig.put("personalizedMode", "false");
+    updatedConfig.put("cron", "0 0/5 * * * ?");
+    updatedConfig.put("cronExecutingRoles", "[\"test\"]");
+    updatedConfig.put("cronExecutingUser", "test");
+    notebookService.updateNote(note1Id, "note_test_update", updatedConfig, context, callback);
+    notebook.processNote(note1Id,
+            note1 -> {
+              assertEquals("note_test_update", note1.getName());
+              assertEquals("test", note1.getConfig().get("cronExecutingUser"));
+              assertEquals("[\"test\"]", note1.getConfig().get("cronExecutingRoles"));
+              assertEquals("0 0/5 * * * ?", note1.getConfig().get("cron"));
+              verify(callback).onSuccess(any(Note.class), any(ServiceContext.class));
+              return null;
+            });
+    // update note with cron for every 1 hour
+    reset(callback);
+    updatedConfig.put("cron", "0 0 0/1 * * ?");
+    notebookService.updateNote(note1Id, "note_test_update", updatedConfig, context, callback);
+    notebook.processNote(note1Id,
+            note1 -> {
+              assertEquals("0 0 0/1 * * ?", note1.getConfig().get("cron"));
+              verify(callback).onSuccess(any(Note.class), any(ServiceContext.class));
+              return null;
+            });
+    // update note with wrong user
+    reset(callback);
+    updatedConfig.put("cronExecutingUser", "wrong_user");
+    notebookService.updateNote(note1Id, "note_test_update", updatedConfig, context, callback);
+    notebook.processNote(note1Id,
+            note1 -> {
+              verify(callback).onFailure(any(IllegalArgumentException.class), any(ServiceContext.class));
+              return null;
+            });
+    // disable cron
+    reset(callback);
+    updatedConfig.put("cron", null);
+    updatedConfig.put("cronExecutingRoles", "");
+    updatedConfig.put("cronExecutingUser", "");
+    notebookService.updateNote(note1Id, "note_test_update", updatedConfig, context, callback);
+    notebook.processNote(note1Id,
+            note1 -> {
+              assertNull(note1.getConfig().get("cron"));
+              assertEquals("", note1.getConfig().get("cronExecutingRoles"));
+              assertEquals("", note1.getConfig().get("cronExecutingUser"));
+              verify(callback).onSuccess(any(Note.class), any(ServiceContext.class));
+              return null;
+            });
+  }
+
   @Test
   void testRenameNoteRejectsDuplicate() throws IOException {
     String note1Id = notebookService.createNote("/folder/note1", "test", true, context, callback);
