@@ -16,8 +16,9 @@
  */
 package org.apache.zeppelin.service;
 
-import static org.junit.Assert.assertEquals;
 import static org.mockito.Mockito.when;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 
 import java.io.IOException;
@@ -25,84 +26,75 @@ import java.security.Principal;
 import java.util.HashSet;
 import java.util.Set;
 
+import org.apache.commons.lang3.StringUtils;
 import org.apache.shiro.mgt.DefaultSecurityManager;
-import org.apache.shiro.subject.SimplePrincipalCollection;
+import org.apache.shiro.subject.Subject;
 import org.apache.shiro.util.LifecycleUtils;
 import org.apache.shiro.util.ThreadContext;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
-import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.realm.jwt.KnoxJwtRealm;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.mockito.Mock;
-import org.mockito.Mockito;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
+import org.apache.zeppelin.service.shiro.AbstractShiroTest;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-@RunWith(PowerMockRunner.class)
-@PrepareForTest(org.apache.shiro.SecurityUtils.class)
-public class ShiroAuthenticationServiceTest {
-  @Mock
-  org.apache.shiro.subject.Subject subject;
+class ShiroAuthenticationServiceTest extends AbstractShiroTest {
 
+  Subject subject;
   ShiroAuthenticationService shiroSecurityService;
-  ZeppelinConfiguration zeppelinConfiguration;
+  ZeppelinConfiguration zConf;
 
-  @Before
-  public void setup() throws Exception {
-    zeppelinConfiguration = ZeppelinConfiguration.create();
-    shiroSecurityService = new ShiroAuthenticationService(zeppelinConfiguration);
+  @BeforeEach
+  void setup() throws Exception {
+    subject = mock(Subject.class);
+    zConf = mock(ZeppelinConfiguration.class);
+    when(zConf.getShiroPath()).thenReturn(StringUtils.EMPTY);
+    setSubject(subject);
+    shiroSecurityService = new ShiroAuthenticationService(zConf);
   }
 
   @Test
-  public void canGetPrincipalName() {
+  void canGetPrincipalName() {
     String expectedName = "java.security.Principal.getName()";
     setupPrincipalName(expectedName);
     assertEquals(expectedName, shiroSecurityService.getPrincipal());
   }
 
   @Test
-  public void testUsernameForceLowerCase() throws IOException, InterruptedException {
+  void testUsernameForceLowerCase() throws IOException, InterruptedException {
     String expectedName = "java.security.Principal.getName()";
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_USERNAME_FORCE_LOWERCASE
-        .getVarName(), String.valueOf(true));
+    when(zConf.isUsernameForceLowerCase()).thenReturn(true);
     setupPrincipalName(expectedName);
     assertEquals(expectedName.toLowerCase(), shiroSecurityService.getPrincipal());
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_USERNAME_FORCE_LOWERCASE
-        .getVarName(), String.valueOf(false));
   }
 
   @Test
-  public void testKnoxGetRoles() {
+  void testKnoxGetRoles() {
     setupPrincipalName("test");
 
     KnoxJwtRealm realm = spy(new KnoxJwtRealm());
     LifecycleUtils.init(realm);
-    Set<String> testRoles = new HashSet<String>(){{
-        add("role1");
-        add("role2");
-    }};
+    Set<String> testRoles = new HashSet<String>();
+    testRoles.add("role1");
+    testRoles.add("role2");
+
     when(realm.mapGroupPrincipals("test")).thenReturn(testRoles);
-    
+
     DefaultSecurityManager securityManager = new DefaultSecurityManager(realm);
     ThreadContext.bind(securityManager);
-    
+
     Set<String> roles = shiroSecurityService.getAssociatedRoles();
     assertEquals(testRoles, roles);
   }
 
+  @AfterEach
+  public void tearDownSubject() {
+    clearSubject();
+  }
+
   private void setupPrincipalName(String expectedName) {
-    PowerMockito.mockStatic(org.apache.shiro.SecurityUtils.class);
-    when(org.apache.shiro.SecurityUtils.getSubject()).thenReturn(subject);
     when(subject.isAuthenticated()).thenReturn(true);
     when(subject.getPrincipal()).thenReturn(new TestPrincipal(expectedName));
-
-    Notebook notebook = Mockito.mock(Notebook.class);
-    when(notebook.getConf())
-        .thenReturn(ZeppelinConfiguration.create("zeppelin-site.xml"));
-
   }
 
   public class TestPrincipal implements Principal {
