@@ -1,5 +1,5 @@
 var baseConfig = {
-  baseUrl: 'http://localhost:8080/',
+  baseUrl: 'http://localhost:8080/classic',
   directConnect: true,
   capabilities: {
     browserName: 'chrome',
