@@ -486,20 +486,21 @@ function InterpreterCtrl($rootScope, $scope, $http, baseUrlSrv, ngToast, $timeou
   $scope.addNewInterpreterSetting = function() {
     // user input validation on interpreter creation
     if (!$scope.newInterpreterSetting.name ||
-      !$scope.newInterpreterSetting.name.trim() || !$scope.newInterpreterSetting.group) {
+        !$scope.newInterpreterSetting.name.trim() ||
+        !$scope.newInterpreterSetting.name.match(/^[-_a-zA-Z0-9]+$/g)) {
       BootstrapDialog.alert({
         closable: true,
         title: 'Add interpreter',
-        message: 'Please fill in interpreter name and choose a group',
+        message: 'Interpreter name shouldn\'t be empty, and can consist only of: -_a-zA-Z0-9',
       });
       return;
     }
 
-    if ($scope.newInterpreterSetting.name.indexOf('.') >= 0) {
+    if (!$scope.newInterpreterSetting.group) {
       BootstrapDialog.alert({
         closable: true,
         title: 'Add interpreter',
-        message: '\'.\' is invalid for interpreter name',
+        message: 'Please choose an interpreter group',
       });
       return;
     }
@@ -535,6 +536,7 @@ function InterpreterCtrl($rootScope, $scope, $http, baseUrlSrv, ngToast, $timeou
         newProperties[p] = {
           value: newSetting.properties[p].value,
           type: newSetting.properties[p].type,
+          description: newSetting.properties[p].description,
           name: p,
         };
       }
@@ -622,8 +624,8 @@ function InterpreterCtrl($rootScope, $scope, $http, baseUrlSrv, ngToast, $timeou
         return;
       }
 
-      setting.properties[setting.propertyKey] =
-        {value: setting.propertyValue, type: setting.propertyType};
+      setting.properties[setting.propertyKey] = {name: setting.propertyKey, value: setting.propertyValue,
+        type: setting.propertyType, description: setting.description};
 
       emptyNewProperty(setting);
     }
@@ -762,27 +764,6 @@ function InterpreterCtrl($rootScope, $scope, $http, baseUrlSrv, ngToast, $timeou
     getRepositories();
   };
 
-  $scope.showSparkUI = function(settingId) {
-    $http.get(baseUrlSrv.getRestApiBase() + '/interpreter/metadata/' + settingId)
-      .then(function(res) {
-        if (res.data.body === undefined) {
-          BootstrapDialog.alert({
-            message: 'No spark application running',
-          });
-          return;
-        }
-        if (res.data.body.url) {
-          window.open(res.data.body.url, '_blank');
-        } else {
-          BootstrapDialog.alert({
-            message: _.escape(res.data.body.message),
-          });
-        }
-      }).catch(function(res) {
-        console.log('Error %o %o', res.status, res.data ? res.data.message : '');
-      });
-  };
-
   $scope.getInterpreterBindingModeDocsLink = function() {
     const currentVersion = $rootScope.zeppelinVersion;
     return `https://zeppelin.apache.org/docs/${currentVersion}/usage/interpreter/interpreter_binding_mode.html`;
