@@ -51,7 +51,7 @@ import org.slf4j.LoggerFactory;
  * Manages helium packages
  */
 public class Helium {
-  private Logger logger = LoggerFactory.getLogger(Helium.class);
+  private static final Logger LOGGER = LoggerFactory.getLogger(Helium.class);
   private List<HeliumRegistry> registry = new LinkedList<>();
 
   private HeliumConf heliumConf;
@@ -65,19 +65,22 @@ public class Helium {
   private final HeliumApplicationFactory applicationFactory;
   private final InterpreterSettingManager interpreterSettingManager;
 
+  private final ZeppelinConfiguration zConf;
+
   @Inject
   public Helium(
-      ZeppelinConfiguration conf,
+      ZeppelinConfiguration zConf,
       HeliumBundleFactory heliumBundleFactory,
       HeliumApplicationFactory heliumApplicationFactory,
       InterpreterSettingManager interpreterSettingManager) throws IOException {
     this(
-        conf.getHeliumConfPath(),
-        conf.getHeliumRegistry(),
-        new File(conf.getAbsoluteDir(ConfVars.ZEPPELIN_DEP_LOCALREPO), "helium-registry-cache"),
+        zConf.getHeliumConfPath(),
+        zConf.getHeliumRegistry(),
+        new File(zConf.getAbsoluteDir(ConfVars.ZEPPELIN_DEP_LOCALREPO), "helium-registry-cache"),
         heliumBundleFactory,
         heliumApplicationFactory,
-        interpreterSettingManager);
+        interpreterSettingManager,
+        zConf);
   }
 
   @VisibleForTesting
@@ -87,7 +90,8 @@ public class Helium {
       File registryCacheDir,
       HeliumBundleFactory bundleFactory,
       HeliumApplicationFactory applicationFactory,
-      InterpreterSettingManager interpreterSettingManager)
+      InterpreterSettingManager interpreterSettingManager,
+      ZeppelinConfiguration zConf)
       throws IOException {
     this.heliumConfPath = heliumConfPath;
     this.registryPaths = registryPaths;
@@ -95,6 +99,7 @@ public class Helium {
     this.bundleFactory = bundleFactory;
     this.applicationFactory = applicationFactory;
     this.interpreterSettingManager = interpreterSettingManager;
+    this.zConf = zConf;
     heliumConf = loadConf(heliumConfPath);
     allPackages = getAllPackageInfo();
 
@@ -102,7 +107,7 @@ public class Helium {
     try {
       bundleFactory.buildAllPackages(getBundlePackagesToBundle());
     } catch (Exception e) {
-      logger.error(e.getMessage(), e);
+      LOGGER.error(e.getMessage(), e);
     }
   }
 
@@ -133,10 +138,10 @@ public class Helium {
       String[] paths = registryPaths.split(",");
       for (String uri : paths) {
         if (uri.startsWith("http://") || uri.startsWith("https://")) {
-          logger.info("Add helium online registry {}", uri);
-          registry.add(new HeliumOnlineRegistry(uri, uri, registryCacheDir));
+          LOGGER.info("Add helium online registry {}", uri);
+          registry.add(new HeliumOnlineRegistry(uri, uri, registryCacheDir, zConf));
         } else {
-          logger.info("Add helium local registry {}", uri);
+          LOGGER.info("Add helium local registry {}", uri);
           registry.add(new HeliumLocalRegistry(uri, uri));
         }
       }
@@ -144,7 +149,7 @@ public class Helium {
 
     File heliumConfFile = new File(path);
     if (!heliumConfFile.isFile()) {
-      logger.warn("{} does not exists", path);
+      LOGGER.warn("{} does not exists", path);
       return new HeliumConf();
     } else {
       String jsonString = FileUtils.readFileToString(heliumConfFile);
@@ -219,7 +224,7 @@ public class Helium {
               allPackages.get(name).add(new HeliumPackageSearchResult(r.name(), pkg, enabled));
             }
           } catch (IOException e) {
-            logger.error(e.getMessage(), e);
+            LOGGER.error(e.getMessage(), e);
           }
         }
       } else {
@@ -314,7 +319,7 @@ public class Helium {
     HeliumPackageSearchResult pkgInfo = getPackageInfo(name, artifact);
 
     if (pkgInfo == null) {
-      logger.info("Package {} not found", name);
+      LOGGER.info("Package {} not found", name);
       return false;
     }
 
@@ -341,7 +346,7 @@ public class Helium {
     String pkg = heliumConf.getEnabledPackages().get(name);
 
     if (pkg == null) {
-      logger.info("Package {} not found", name);
+      LOGGER.info("Package {} not found", name);
       return false;
     }
 
