@@ -45,7 +45,6 @@ import org.apache.zeppelin.interpreter.remote.RemoteAngularObjectRegistry;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreter;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterProcess;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterProcessListener;
-import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.plugin.PluginManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -133,13 +132,12 @@ public class InterpreterSetting {
   private transient ApplicationEventListener appEventListener;
   private transient DependencyResolver dependencyResolver;
 
-  private transient ZeppelinConfiguration conf = ZeppelinConfiguration.create();
+  private transient ZeppelinConfiguration zConf;
+  private transient PluginManager pluginManager;
 
   private transient RecoveryStorage recoveryStorage;
   private transient RemoteInterpreterEventServer interpreterEventServer;
 
-  public static final String CLUSTER_INTERPRETER_LAUNCHER_NAME = "ClusterInterpreterLauncher";
-
   ///////////////////////////////////////////////////////////////////////////////////////////
 
   /**
@@ -197,8 +195,14 @@ public class InterpreterSetting {
       return this;
     }
 
-    public Builder setConf(ZeppelinConfiguration conf) {
-      interpreterSetting.conf = conf;
+    public Builder setConf(ZeppelinConfiguration zConf) {
+      interpreterSetting.zConf = zConf;
+      interpreterSetting.option.setConf(zConf);
+      return this;
+    }
+
+    public Builder setPluginManager(PluginManager pluginManager) {
+      interpreterSetting.pluginManager = pluginManager;
       return this;
     }
 
@@ -263,7 +267,7 @@ public class InterpreterSetting {
     this.id = this.name;
     if (this.recoveryStorage == null) {
       try {
-        this.recoveryStorage = new NullRecoveryStorage(conf, interpreterSettingManager);
+        this.recoveryStorage = new NullRecoveryStorage(zConf, interpreterSettingManager);
       } catch (IOException e) {
         // ignore this exception as NullRecoveryStorage will do nothing.
       }
@@ -287,11 +291,12 @@ public class InterpreterSetting {
     this.dependencies = new ArrayList<>(o.getDependencies());
     this.interpreterDir = o.getInterpreterDir();
     this.interpreterRunner = o.getInterpreterRunner();
-    this.conf = o.getConf();
+    this.zConf = o.getConf();
+    this.pluginManager = o.getPluginMananger();
   }
 
   private InterpreterLauncher createLauncher(Properties properties) throws IOException {
-    return PluginManager.get().loadInterpreterLauncher(
+    return pluginManager.loadInterpreterLauncher(
         getLauncherPlugin(properties), recoveryStorage);
   }
 
@@ -635,15 +640,15 @@ public class InterpreterSetting {
 
     if (!jProperties.containsKey("zeppelin.interpreter.output.limit")) {
       jProperties.setProperty("zeppelin.interpreter.output.limit",
-          conf.getInt(ZEPPELIN_INTERPRETER_OUTPUT_LIMIT) + "");
+          zConf.getInt(ZEPPELIN_INTERPRETER_OUTPUT_LIMIT) + "");
     }
 
     if (!jProperties.containsKey(ZEPPELIN_INTERPRETER_CONNECTION_POOL_SIZE.getVarName())) {
       jProperties.setProperty(ZEPPELIN_INTERPRETER_CONNECTION_POOL_SIZE.getVarName(),
-          conf.getInt(ZEPPELIN_INTERPRETER_CONNECTION_POOL_SIZE) + "");
+          zConf.getInt(ZEPPELIN_INTERPRETER_CONNECTION_POOL_SIZE) + "");
     }
 
-    String interpreterLocalRepoPath = conf.getInterpreterLocalRepoPath();
+    String interpreterLocalRepoPath = zConf.getInterpreterLocalRepoPath();
     //TODO(zjffdu) change it to interpreterDir/{interpreter_name}
     jProperties.setProperty("zeppelin.interpreter.localRepo",
         interpreterLocalRepoPath + "/" + id);
@@ -651,11 +656,21 @@ public class InterpreterSetting {
   }
 
   public ZeppelinConfiguration getConf() {
-    return conf;
+    return zConf;
   }
 
-  public InterpreterSetting setConf(ZeppelinConfiguration conf) {
-    this.conf = conf;
+  public InterpreterSetting setConf(ZeppelinConfiguration zConf) {
+    this.zConf = zConf;
+    this.option.setConf(zConf);
+    return this;
+  }
+
+  public PluginManager getPluginMananger() {
+    return pluginManager;
+  }
+
+  public InterpreterSetting setPluginMananger(PluginManager pluginManager) {
+    this.pluginManager = pluginManager;
     return this;
   }
 
@@ -767,8 +782,6 @@ public class InterpreterSetting {
         return "FlinkInterpreterLauncher";
       }
       return "K8sStandardInterpreterLauncher";
-    } else if (isRunningOnCluster()) {
-      return InterpreterSetting.CLUSTER_INTERPRETER_LAUNCHER_NAME;
     } else if (isRunningOnDocker()) {
       return "DockerInterpreterLauncher";
     } else {
@@ -791,16 +804,11 @@ public class InterpreterSetting {
   }
 
   private boolean isRunningOnKubernetes() {
-    return conf.getRunMode() == ZeppelinConfiguration.RUN_MODE.K8S;
-  }
-
-
-  private boolean isRunningOnCluster() {
-    return conf.isClusterMode();
+    return zConf.getRunMode() == ZeppelinConfiguration.RUN_MODE.K8S;
   }
 
   private boolean isRunningOnDocker() {
-    return conf.getRunMode() == ZeppelinConfiguration.RUN_MODE.DOCKER;
+    return zConf.getRunMode() == ZeppelinConfiguration.RUN_MODE.DOCKER;
   }
 
   public boolean isUserAuthorized(List<String> userAndRoles) {
@@ -823,7 +831,7 @@ public class InterpreterSetting {
     Properties intpProperties = getJavaProperties();
     for (InterpreterInfo info : interpreterInfos) {
       Interpreter interpreter = new RemoteInterpreter(intpProperties, sessionId,
-          info.getClassName(), user);
+          info.getClassName(), user, zConf);
       if (info.isDefaultInterpreter()) {
         interpreters.add(0, interpreter);
       } else {
@@ -920,7 +928,7 @@ public class InterpreterSetting {
 
   private ManagedInterpreterGroup createInterpreterGroup(String groupId) {
     AngularObjectRegistry angularObjectRegistry;
-    ManagedInterpreterGroup interpreterGroup = new ManagedInterpreterGroup(groupId, this);
+    ManagedInterpreterGroup interpreterGroup = new ManagedInterpreterGroup(groupId, this, zConf);
     angularObjectRegistry =
         new RemoteAngularObjectRegistry(groupId, angularObjectRegistryListener, interpreterGroup);
     interpreterGroup.setAngularObjectRegistry(angularObjectRegistry);
@@ -958,7 +966,7 @@ public class InterpreterSetting {
       public void run() {
         try {
           // dependencies to prevent library conflict
-          File localRepoDir = new File(conf.getInterpreterLocalRepoPath() + '/' + id);
+          File localRepoDir = new File(zConf.getInterpreterLocalRepoPath() + '/' + id);
           if (localRepoDir.exists()) {
             try {
               FileUtils.forceDelete(localRepoDir);
@@ -973,7 +981,7 @@ public class InterpreterSetting {
             LOGGER.info("Start to download dependencies for interpreter: {}", name);
             for (Dependency d : deps) {
               File destDir = new File(
-                  conf.getAbsoluteDir(ZeppelinConfiguration.ConfVars.ZEPPELIN_DEP_LOCALREPO));
+                  zConf.getAbsoluteDir(ZeppelinConfiguration.ConfVars.ZEPPELIN_DEP_LOCALREPO));
 
               if (d.getExclusions() != null) {
                 dependencyResolver.load(d.getGroupArtifactVersion(), d.getExclusions(),
