@@ -39,10 +39,6 @@ import javax.inject.Inject;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.zeppelin.cluster.ClusterManagerServer;
-import org.apache.zeppelin.cluster.event.ClusterEvent;
-import org.apache.zeppelin.cluster.event.ClusterEventListener;
-import org.apache.zeppelin.cluster.event.ClusterMessage;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars;
 import org.apache.zeppelin.dep.Dependency;
@@ -61,6 +57,7 @@ import org.apache.zeppelin.notebook.NoteEventListener;
 import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.notebook.ParagraphTextParser;
+import org.apache.zeppelin.plugin.PluginManager;
 import org.apache.zeppelin.resource.Resource;
 import org.apache.zeppelin.resource.ResourcePool;
 import org.apache.zeppelin.resource.ResourceSet;
@@ -98,8 +95,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
 
-import static org.apache.zeppelin.cluster.ClusterManagerServer.CLUSTER_INTP_SETTING_EVENT_TOPIC;
-
 
 /**
  * InterpreterSettingManager is the component which manage all the interpreter settings.
@@ -107,7 +102,7 @@ import static org.apache.zeppelin.cluster.ClusterManagerServer.CLUSTER_INTP_SETT
  * TODO(zjffdu) We could move it into another separated component.
  */
 @ManagedObject("interpreterSettingManager")
-public class InterpreterSettingManager implements NoteEventListener, ClusterEventListener {
+public class InterpreterSettingManager implements NoteEventListener {
 
   private static final Pattern VALID_INTERPRETER_NAME = Pattern.compile("^[-_a-zA-Z0-9]+$");
   private static final Logger LOGGER = LoggerFactory.getLogger(InterpreterSettingManager.class);
@@ -115,7 +110,8 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
       "language", (Object) "text",
       "editOnDblClick", false);
 
-  private final ZeppelinConfiguration conf;
+  private final ZeppelinConfiguration zConf;
+  private final PluginManager pluginManager;
   private final Path interpreterDirPath;
 
   /**
@@ -151,48 +147,53 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
   private List<String> excludesInterpreters;
 
   @Inject
-  public InterpreterSettingManager(ZeppelinConfiguration zeppelinConfiguration,
+  public InterpreterSettingManager(ZeppelinConfiguration zConf,
                                    AngularObjectRegistryListener angularObjectRegistryListener,
                                    RemoteInterpreterProcessListener
                                        remoteInterpreterProcessListener,
-                                   ApplicationEventListener appEventListener)
+                                   ApplicationEventListener appEventListener,
+                                   ConfigStorage storage,
+                                   PluginManager pluginManager)
       throws IOException {
-    this(zeppelinConfiguration, new InterpreterOption(),
+    this(zConf, new InterpreterOption(),
         angularObjectRegistryListener,
         remoteInterpreterProcessListener,
         appEventListener,
-        ConfigStorage.getInstance(zeppelinConfiguration));
+        storage,
+        pluginManager);
   }
 
-  public InterpreterSettingManager(ZeppelinConfiguration conf,
+  public InterpreterSettingManager(ZeppelinConfiguration zConf,
       InterpreterOption defaultOption,
       AngularObjectRegistryListener angularObjectRegistryListener,
       RemoteInterpreterProcessListener remoteInterpreterProcessListener,
       ApplicationEventListener appEventListener,
-      ConfigStorage configStorage)
+      ConfigStorage configStorage,
+      PluginManager pluginManager)
       throws IOException {
-    this.conf = conf;
+    this.zConf = zConf;
+    this.pluginManager = pluginManager;
     this.defaultOption = defaultOption;
-    this.interpreterDirPath = Paths.get(conf.getInterpreterDir());
+    this.interpreterDirPath = Paths.get(zConf.getInterpreterDir());
     LOGGER.debug("InterpreterRootPath: {}", interpreterDirPath);
     this.dependencyResolver =
-        new DependencyResolver(conf.getString(ConfVars.ZEPPELIN_INTERPRETER_LOCALREPO));
+        new DependencyResolver(zConf.getString(ConfVars.ZEPPELIN_INTERPRETER_LOCALREPO), zConf);
     this.interpreterRepositories = dependencyResolver.getRepos();
-    this.defaultInterpreterGroup = conf.getString(ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT);
+    this.defaultInterpreterGroup = zConf.getString(ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT);
     this.gson = new GsonBuilder().setPrettyPrinting().create();
 
     this.angularObjectRegistryListener = angularObjectRegistryListener;
     this.remoteInterpreterProcessListener = remoteInterpreterProcessListener;
     this.appEventListener = appEventListener;
 
-    this.interpreterEventServer = new RemoteInterpreterEventServer(conf, this);
+    this.interpreterEventServer = new RemoteInterpreterEventServer(zConf, this);
     this.interpreterEventServer.start();
 
     this.recoveryStorage =
         ReflectionUtils.createClazzInstance(
-            conf.getRecoveryStorageClass(),
+            zConf.getRecoveryStorageClass(),
             new Class[] {ZeppelinConfiguration.class, InterpreterSettingManager.class},
-            new Object[] {conf, this});
+            new Object[] {zConf, this});
 
     LOGGER.info("Using RecoveryStorage: {}", this.recoveryStorage.getClass().getName());
 
@@ -222,7 +223,7 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
 
 
   private void initInterpreterSetting(InterpreterSetting interpreterSetting) {
-    interpreterSetting.setConf(conf)
+    interpreterSetting.setConf(zConf)
         .setInterpreterSettingManager(this)
         .setAngularObjectRegistryListener(angularObjectRegistryListener)
         .setRemoteInterpreterProcessListener(remoteInterpreterProcessListener)
@@ -230,6 +231,7 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
         .setDependencyResolver(dependencyResolver)
         .setRecoveryStorage(recoveryStorage)
         .setInterpreterEventServer(interpreterEventServer)
+        .setPluginMananger(pluginManager)
         .postProcessing();
   }
 
@@ -360,12 +362,12 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
 
   private void init() throws IOException {
     this.includesInterpreters =
-            Arrays.asList(conf.getString(ConfVars.ZEPPELIN_INTERPRETER_INCLUDES).split(","))
+            Arrays.asList(zConf.getString(ConfVars.ZEPPELIN_INTERPRETER_INCLUDES).split(","))
                     .stream()
                     .filter(t -> !t.isEmpty())
                     .collect(Collectors.toList());
     this.excludesInterpreters =
-            Arrays.asList(conf.getString(ConfVars.ZEPPELIN_INTERPRETER_EXCLUDES).split(","))
+            Arrays.asList(zConf.getString(ConfVars.ZEPPELIN_INTERPRETER_EXCLUDES).split(","))
                     .stream()
                     .filter(t -> !t.isEmpty())
                     .collect(Collectors.toList());
@@ -399,7 +401,7 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
   }
 
   private void loadJupyterKernelLanguageMap() throws IOException {
-    String kernels = conf.getString(ConfVars.ZEPPELIN_INTERPRETER_JUPYTER_KERNELS);
+    String kernels = zConf.getString(ConfVars.ZEPPELIN_INTERPRETER_JUPYTER_KERNELS);
     for (String kernel : kernels.split(",")) {
       String[] tokens = kernel.split(":");
       if (tokens.length != 2) {
@@ -414,7 +416,7 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
   private void loadInterpreterSettingFromDefaultDir(boolean override) throws IOException {
     // 1. detect interpreter setting via interpreter-setting.json in each interpreter folder
     // 2. detect interpreter setting in interpreter.json that is saved before
-    String interpreterJson = conf.getInterpreterJson();
+    String interpreterJson = zConf.getInterpreterJson();
     ClassLoader cl = Thread.currentThread().getContextClassLoader();
     if (Files.exists(interpreterDirPath)) {
       try (DirectoryStream<Path> directoryPaths = Files
@@ -531,7 +533,8 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
         .setRunner(runner)
         .setInterpreterDir(interpreterDir)
         .setRunner(runner)
-        .setConf(conf)
+        .setConf(zConf)
+        .setPluginManager(pluginManager)
         .setIntepreterSettingManager(this)
         .create();
 
@@ -786,7 +789,7 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
         LOGGER.info("Start to copy dependencies for interpreter: {}", setting.getName());
         for (Dependency d : deps) {
           File destDir = new File(
-              conf.getAbsoluteDir(ConfVars.ZEPPELIN_DEP_LOCALREPO));
+              zConf.getAbsoluteDir(ConfVars.ZEPPELIN_DEP_LOCALREPO));
 
           int numSplits = d.getGroupArtifactVersion().split(":").length;
           if (!(numSplits >= 3 && numSplits <= 6)) {
@@ -828,8 +831,6 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
     InterpreterSetting interpreterSetting = null;
     try {
       interpreterSetting = inlineCreateNewSetting(name, group, dependencies, option, properties);
-
-      broadcastClusterEvent(ClusterEvent.CREATE_INTP_SETTING, interpreterSetting);
     } catch (IOException e) {
       LOGGER.error(e.getMessage(), e);
       throw e;
@@ -949,8 +950,6 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
       throws InterpreterException, IOException {
     try {
       InterpreterSetting intpSetting = inlineSetPropertyAndRestart(id, option, properties, dependencies, true);
-      // broadcast cluster event
-      broadcastClusterEvent(ClusterEvent.UPDATE_INTP_SETTING, intpSetting);
     } catch (Exception e) {
       throw e;
     }
@@ -1015,7 +1014,6 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
       // broadcast cluster event
       InterpreterSetting intpSetting = new InterpreterSetting();
       intpSetting.setId(id);
-      broadcastClusterEvent(ClusterEvent.DELETE_INTP_SETTING, intpSetting);
     }
   }
 
@@ -1035,7 +1033,7 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
         // Cluster event accepting nodes do not need to save files repeatedly
         saveToFile();
       }
-      File localRepoPath = new File(conf.getInterpreterLocalRepoPath());
+      File localRepoPath = new File(zConf.getInterpreterLocalRepoPath());
       FileUtils.deleteDirectory(new File(localRepoPath, id));
       removed = true;
     }
@@ -1065,7 +1063,7 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
 
   public InterpreterSetting getDefaultInterpreterSetting() {
     InterpreterSetting setting =
-        getByName(conf.getString(ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT));
+        getByName(zConf.getString(ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT));
     if (setting != null) {
       return setting;
     } else {
@@ -1212,56 +1210,4 @@ public class InterpreterSettingManager implements NoteEventListener, ClusterEven
     // do nothing
   }
 
-  @Override
-  public void onClusterEvent(String msg) {
-    LOGGER.debug("onClusterEvent : {}", msg);
-
-    try {
-      ClusterMessage message = ClusterMessage.deserializeMessage(msg);
-      String jsonIntpSetting = message.get("intpSetting");
-      InterpreterSetting intpSetting = InterpreterSetting.fromJson(jsonIntpSetting);
-      String id = intpSetting.getId();
-      String name = intpSetting.getName();
-      String group = intpSetting.getGroup();
-      InterpreterOption option = intpSetting.getOption();
-      HashMap<String, InterpreterProperty> properties
-          = (HashMap<String, InterpreterProperty>) InterpreterSetting
-          .convertInterpreterProperties(intpSetting.getProperties());
-      List<Dependency> dependencies = intpSetting.getDependencies();
-
-      switch (message.clusterEvent) {
-        case CREATE_INTP_SETTING:
-          inlineCreateNewSetting(name, group, dependencies, option, properties);
-          break;
-        case UPDATE_INTP_SETTING:
-          inlineSetPropertyAndRestart(id, option, properties, dependencies, false);
-          break;
-        case DELETE_INTP_SETTING:
-          inlineRemove(id, false);
-          break;
-        default:
-          LOGGER.error("Unknown clusterEvent:{}, msg:{} ", message.clusterEvent, msg);
-          break;
-      }
-    } catch (IOException e) {
-      LOGGER.error(e.getMessage(), e);
-    } catch (InterpreterException e) {
-      LOGGER.error(e.getMessage(), e);
-    }
-  }
-
-  // broadcast cluster event
-  private void broadcastClusterEvent(ClusterEvent event, InterpreterSetting intpSetting) {
-    if (!conf.isClusterMode()) {
-      return;
-    }
-
-    String jsonIntpSetting = InterpreterSetting.toJson(intpSetting);
-
-    ClusterMessage message = new ClusterMessage(event);
-    message.put("intpSetting", jsonIntpSetting);
-    String msg = ClusterMessage.serializeMessage(message);
-    ClusterManagerServer.getInstance(conf).broadcastClusterEvent(
-        CLUSTER_INTP_SETTING_EVENT_TOPIC, msg);
-  }
 }
