@@ -21,6 +21,7 @@ import com.google.common.annotations.VisibleForTesting;
 import com.google.gson.Gson;
 import com.google.gson.reflect.TypeToken;
 import org.apache.thrift.TException;
+import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.display.AngularObject;
 import org.apache.zeppelin.display.AngularObjectRegistry;
 import org.apache.zeppelin.display.GUI;
@@ -70,11 +71,13 @@ public class RemoteInterpreter extends Interpreter {
   public RemoteInterpreter(Properties properties,
                            String sessionId,
                            String className,
-                           String userName) {
+                           String userName,
+                           ZeppelinConfiguration zConf) {
     super(properties);
     this.sessionId = sessionId;
     this.className = className;
     this.setUserName(userName);
+    this.setZeppelinConfiguration(zConf);
   }
 
   public boolean isOpened() {
