@@ -18,10 +18,6 @@
 package org.apache.zeppelin.notebook;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.gson.ExclusionStrategy;
-import com.google.gson.FieldAttributes;
-import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.zeppelin.common.JsonSerializable;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
@@ -40,7 +36,6 @@ import org.apache.zeppelin.interpreter.ManagedInterpreterGroup;
 import org.apache.zeppelin.interpreter.remote.RemoteAngularObject;
 import org.apache.zeppelin.interpreter.remote.RemoteAngularObjectRegistry;
 import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
-import org.apache.zeppelin.notebook.exception.CorruptedNoteException;
 import org.apache.zeppelin.notebook.utility.IdHashes;
 import org.apache.zeppelin.scheduler.ExecutorFactory;
 import org.apache.zeppelin.scheduler.Job.Status;
@@ -50,12 +45,10 @@ import org.apache.zeppelin.util.Util;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.IOException;
 import java.time.LocalDateTime;
 import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -65,6 +58,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 /**
  * Represent the note of Zeppelin. All the note and its paragraph operations are done
@@ -73,51 +67,6 @@ import java.util.concurrent.CopyOnWriteArrayList;
 public class Note implements JsonSerializable {
 
   private static final Logger LOGGER = LoggerFactory.getLogger(Note.class);
-
-  // serialize Paragraph#runtimeInfos and Note#path to frontend but not to note file
-  private static final ExclusionStrategy NOTE_GSON_EXCLUSION_STRATEGY =
-          new NoteJsonExclusionStrategy(ZeppelinConfiguration.create());
-
-  private static class NoteJsonExclusionStrategy implements ExclusionStrategy {
-    private Set<String> noteExcludeFields = new HashSet<>();
-    private Set<String> paragraphExcludeFields = new HashSet<>();
-
-    public NoteJsonExclusionStrategy(ZeppelinConfiguration zConf) {
-      String[] excludeFields = zConf.getNoteFileExcludedFields();
-      for (String field : excludeFields) {
-        if (field.startsWith("Paragraph")) {
-          paragraphExcludeFields.add(field.substring(10));
-        } else {
-          noteExcludeFields.add(field);
-        }
-      }
-    }
-
-    @Override
-    public boolean shouldSkipField(FieldAttributes field) {
-      if(field.getName().equals("path")) {
-        return true;
-      }
-      if (field.getDeclaringClass().equals(Paragraph.class)) {
-        return paragraphExcludeFields.contains(field.getName());
-      } else {
-        return noteExcludeFields.contains(field.getName());
-      }
-    }
-
-    @Override
-    public boolean shouldSkipClass(Class<?> aClass) {
-      return false;
-    }
-  }
-
-  private static final Gson GSON = new GsonBuilder()
-          .setPrettyPrinting()
-          .setDateFormat("yyyy-MM-dd HH:mm:ss.SSS")
-          .registerTypeAdapter(Date.class, new NotebookImportDeserializer())
-          .registerTypeAdapterFactory(Input.TypeAdapterFactory)
-          .setExclusionStrategies(NOTE_GSON_EXCLUSION_STRATEGY)
-          .create();
   private static final DateTimeFormatter DATE_TIME_FORMATTER =
           DateTimeFormatter.ofPattern("yyyy-MM-dd_HH-mm-ss");
 
@@ -149,15 +98,20 @@ public class Note implements JsonSerializable {
   private String path;
 
   /********************************** transient fields ******************************************/
-  private transient boolean loaded = false;
-  private transient boolean saved = false;
+  /*
+   * Do not use the fair algorithm, because it blocks read accesses when a write access is waiting.
+   * We have read accesses from different threads, which are dependent on each other.
+   * The fair behavior can therefore create a DeadLock.
+   */
+  private transient final ReentrantReadWriteLock lock = new ReentrantReadWriteLock(false);
   private transient boolean removed = false;
   private transient InterpreterFactory interpreterFactory;
   private transient InterpreterSettingManager interpreterSettingManager;
   private transient ParagraphJobListener paragraphJobListener;
   private transient List<NoteEventListener> noteEventListeners = new ArrayList<>();
   private transient Credentials credentials;
-  private transient ZeppelinConfiguration zConf = ZeppelinConfiguration.create();
+  private transient ZeppelinConfiguration zConf;
+  private transient NoteParser noteParser;
 
   public Note() {
     generateId();
@@ -165,7 +119,8 @@ public class Note implements JsonSerializable {
 
   public Note(String path, String defaultInterpreterGroup, InterpreterFactory factory,
               InterpreterSettingManager interpreterSettingManager, ParagraphJobListener paragraphJobListener,
-              Credentials credentials, List<NoteEventListener> noteEventListener) {
+              Credentials credentials, List<NoteEventListener> noteEventListener,
+              ZeppelinConfiguration zConf, NoteParser noteParser) {
     setPath(path);
     this.defaultInterpreterGroup = defaultInterpreterGroup;
     this.interpreterFactory = factory;
@@ -173,17 +128,14 @@ public class Note implements JsonSerializable {
     this.paragraphJobListener = paragraphJobListener;
     this.noteEventListeners = noteEventListener;
     this.credentials = credentials;
+    this.zConf = zConf;
+    this.noteParser = noteParser;
     this.version = Util.getVersion();
     generateId();
 
     setCronSupported(zConf);
   }
 
-  public Note(NoteInfo noteInfo) {
-    this.id = noteInfo.getId();
-    setPath(noteInfo.getPath());
-  }
-
   public String getPath() {
     return path;
   }
@@ -206,31 +158,6 @@ public class Note implements JsonSerializable {
     id = IdHashes.generateId();
   }
 
-  public boolean isLoaded() {
-    return loaded;
-  }
-
-  public void setLoaded(boolean loaded) {
-    this.loaded = loaded;
-  }
-
-  /**
-   * Release note memory
-   */
-  public void unLoad() {
-    if (isRunning() || isParagraphRunning()) {
-      LOGGER.warn("Unable to unload note because it is in RUNNING");
-    } else {
-      this.setLoaded(false);
-      this.paragraphs = null;
-      this.config = null;
-      this.info = null;
-      this.noteForms = null;
-      this.noteParams = null;
-      this.angularObjects = null;
-    }
-  }
-
   public boolean isParagraphRunning() {
     if (paragraphs != null) {
       for (Paragraph p : paragraphs) {
@@ -294,8 +221,8 @@ public class Note implements JsonSerializable {
 
   public String getDefaultInterpreterGroup() {
     if (StringUtils.isBlank(defaultInterpreterGroup)) {
-      defaultInterpreterGroup = ZeppelinConfiguration.create()
-              .getString(ZeppelinConfiguration.ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT);
+      defaultInterpreterGroup =
+          zConf.getString(ZeppelinConfiguration.ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT);
     }
     return defaultInterpreterGroup;
   }
@@ -355,13 +282,13 @@ public class Note implements JsonSerializable {
     this.paragraphJobListener = paragraphJobListener;
   }
 
-  public boolean isCronSupported(ZeppelinConfiguration config) {
-    if (config.isZeppelinNotebookCronEnable()) {
-      config.getZeppelinNotebookCronFolders();
-      if (StringUtils.isBlank(config.getZeppelinNotebookCronFolders())) {
+  public boolean isCronSupported(ZeppelinConfiguration zConf) {
+    if (zConf.isZeppelinNotebookCronEnable()) {
+      zConf.getZeppelinNotebookCronFolders();
+      if (StringUtils.isBlank(zConf.getZeppelinNotebookCronFolders())) {
         return true;
       } else {
-        for (String folder : config.getZeppelinNotebookCronFolders().split(",")) {
+        for (String folder : zConf.getZeppelinNotebookCronFolders().split(",")) {
           if (this.path.startsWith(folder)) {
             return true;
           }
@@ -371,8 +298,8 @@ public class Note implements JsonSerializable {
     return false;
   }
 
-  public void setCronSupported(ZeppelinConfiguration config) {
-    getConfig().put("isZeppelinNotebookCronEnable", isCronSupported(config));
+  public void setCronSupported(ZeppelinConfiguration zConf) {
+    getConfig().put("isZeppelinNotebookCronEnable", isCronSupported(zConf));
   }
 
   public Credentials getCredentials() {
@@ -440,12 +367,10 @@ public class Note implements JsonSerializable {
    * Delete the note AngularObject.
    */
   public void deleteAngularObject(String intpGroupId, String noteId, String paragraphId, String name) {
-    List<AngularObject> angularObjectList;
     if (angularObjects.containsKey(intpGroupId)) {
-      angularObjectList = angularObjects.get(intpGroupId);
 
       // Delete existing AngularObject
-      Iterator<AngularObject> iter = angularObjectList.iterator();
+      Iterator<AngularObject> iter = angularObjects.get(intpGroupId).iterator();
       while(iter.hasNext()){
         String noteIdCandidate = "";
         String paragraphIdCandidate = "";
@@ -506,7 +431,7 @@ public class Note implements JsonSerializable {
     LOGGER.debug("newParagraph user: {}", newParagraph.getUser());
 
     try {
-      String resultJson = GSON.toJson(srcParagraph.getReturn());
+      String resultJson = srcParagraph.getReturn().toJson();
       InterpreterResult result = InterpreterResult.fromJson(resultJson);
       newParagraph.setReturn(result, null);
     } catch (Exception e) {
@@ -516,28 +441,24 @@ public class Note implements JsonSerializable {
 
     paragraphs.add(newParagraph);
 
-    try {
-      fireParagraphCreateEvent(newParagraph);
-    } catch (IOException e) {
-      e.printStackTrace();
-    }
+    fireParagraphCreateEvent(newParagraph);
 
   }
 
-  public void fireParagraphCreateEvent(Paragraph p) throws IOException {
+  public void fireParagraphCreateEvent(Paragraph p) {
     for (NoteEventListener listener : noteEventListeners) {
       listener.onParagraphCreate(p);
     }
   }
 
-  public void fireParagraphRemoveEvent(Paragraph p) throws IOException {
+  public void fireParagraphRemoveEvent(Paragraph p) {
     for (NoteEventListener listener : noteEventListeners) {
       listener.onParagraphRemove(p);
     }
   }
 
 
-  public void fireParagraphUpdateEvent(Paragraph p) throws IOException {
+  public void fireParagraphUpdateEvent(Paragraph p) {
     for (NoteEventListener listener : noteEventListeners) {
       listener.onParagraphUpdate(p);
     }
@@ -569,11 +490,7 @@ public class Note implements JsonSerializable {
 
   private void insertParagraph(Paragraph paragraph, int index) {
     paragraphs.add(index, paragraph);
-    try {
-      fireParagraphCreateEvent(paragraph);
-    } catch (IOException e) {
-      e.printStackTrace();
-    }
+    fireParagraphCreateEvent(paragraph);
   }
 
   /**
@@ -588,11 +505,7 @@ public class Note implements JsonSerializable {
     for (Paragraph p : paragraphs) {
       if (p.getId().equals(paragraphId)) {
         paragraphs.remove(p);
-        try {
-          fireParagraphRemoveEvent(p);
-        } catch (IOException e) {
-          LOGGER.error("Fail to fire ParagraphRemoveEvent", e);
-        }
+        fireParagraphRemoveEvent(p);
         return p;
       }
     }
@@ -811,14 +724,12 @@ public class Note implements JsonSerializable {
             return;
           }
         } catch (InterpreterNotFoundException e) {
-          // ignore, because the following run method will fail if interpreter not found.
+          p.setInterpreterNotFound(e);
         } finally {
           // reset params to the original value
           p.settings.setParams(originalParams);
         }
       }
-    } catch (Exception e) {
-      throw e;
     } finally {
       if (isolated) {
         LOGGER.info("Releasing interpreters used by this note: {}", id);
@@ -900,7 +811,7 @@ public class Note implements JsonSerializable {
     return p.completion(buffer, cursor);
   }
 
-  public CopyOnWriteArrayList<Paragraph> getParagraphs() {
+  public List<Paragraph> getParagraphs() {
     return this.paragraphs;
   }
 
@@ -1027,8 +938,10 @@ public class Note implements JsonSerializable {
     Note newNote = new Note();
     newNote.name = getName();
     newNote.id = getId();
-    newNote.config = getConfig();
+    newNote.setConfig(getConfig());
     newNote.angularObjects = getAngularObjects();
+    newNote.setZeppelinConfiguration(zConf);
+    newNote.setNoteParser(noteParser);
 
     Paragraph newParagraph;
     for (Paragraph p : paragraphs) {
@@ -1123,27 +1036,7 @@ public class Note implements JsonSerializable {
 
   @Override
   public String toJson() {
-    return GSON.toJson(this);
-  }
-
-  /**
-   * Parse note json from note file. Throw IOException if fail to parse note json.
-   *
-   * @param json
-   * @return Note
-   * @throws IOException if fail to parse note json (note file may be corrupted)
-   */
-  public static Note fromJson(String noteId, String json) throws IOException {
-    try {
-      Note note = GSON.fromJson(json, Note.class);
-      convertOldInput(note);
-      note.info.remove("isRunning");
-      note.postProcessParagraphs();
-      return note;
-    } catch (Exception e) {
-      LOGGER.error("Fail to parse note json: {}", e.toString());
-      throw new CorruptedNoteException(noteId, "Fail to parse note json: " + json, e);
-    }
+    return noteParser.toJson(this);
   }
 
   public void postProcessParagraphs() {
@@ -1170,12 +1063,6 @@ public class Note implements JsonSerializable {
     }
   }
 
-  private static void convertOldInput(Note note) {
-    for (Paragraph p : note.paragraphs) {
-      p.settings.convertOldInput();
-    }
-  }
-
   @Override
   public boolean equals(Object o) {
     if (this == o) {
@@ -1217,21 +1104,12 @@ public class Note implements JsonSerializable {
     return result;
   }
 
-  @VisibleForTesting
-  public static Gson getGSON() {
-    return GSON;
-  }
-
   public void setNoteEventListeners(List<NoteEventListener> noteEventListeners) {
     this.noteEventListeners = noteEventListeners;
   }
 
-  public void setSaved(boolean saved) {
-    this.saved = saved;
-  }
-
-  public boolean isSaved() {
-    return saved;
+  public ReentrantReadWriteLock getLock() {
+    return lock;
   }
 
   public void setRemoved(boolean removed) {
@@ -1250,4 +1128,16 @@ public class Note implements JsonSerializable {
     executionContext.setStartTime(getStartTime());
     return executionContext;
   }
+
+  public NoteParser getNoteParser() {
+    return noteParser;
+  }
+
+  public void setZeppelinConfiguration(ZeppelinConfiguration zConf) {
+    this.zConf = zConf;
+  }
+
+  public void setNoteParser(NoteParser noteParser) {
+    this.noteParser = noteParser;
+  }
 }
