@@ -35,6 +35,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.function.Consumer;
 import java.util.function.Predicate;
 import java.util.stream.Collectors;
+
 import javax.inject.Inject;
 
 import org.apache.commons.lang3.StringUtils;
@@ -56,7 +57,7 @@ import org.apache.zeppelin.notebook.repo.NotebookRepoSync;
 import org.apache.zeppelin.notebook.repo.NotebookRepoWithVersionControl;
 import org.apache.zeppelin.notebook.repo.NotebookRepoWithVersionControl.Revision;
 import org.apache.zeppelin.scheduler.Job;
-import org.apache.zeppelin.scheduler.SchedulerThreadFactory;
+import org.apache.zeppelin.scheduler.NamedThreadFactory;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.apache.zeppelin.user.Credentials;
 import org.apache.zeppelin.util.ExecutorUtil;
@@ -77,7 +78,7 @@ public class Notebook {
   private NoteManager noteManager;
   private InterpreterFactory replFactory;
   private InterpreterSettingManager interpreterSettingManager;
-  private ZeppelinConfiguration conf;
+  private ZeppelinConfiguration zConf;
   private ParagraphJobListener paragraphJobListener;
   private NotebookRepo notebookRepo;
   private List<NoteEventListener> noteEventListeners = new CopyOnWriteArrayList<>();
@@ -92,7 +93,7 @@ public class Notebook {
    * @throws SchedulerException
    */
   public Notebook(
-      ZeppelinConfiguration conf,
+      ZeppelinConfiguration zConf,
       AuthorizationService authorizationService,
       NotebookRepo notebookRepo,
       NoteManager noteManager,
@@ -100,7 +101,7 @@ public class Notebook {
       InterpreterSettingManager interpreterSettingManager,
       Credentials credentials)
       {
-    this.conf = conf;
+    this.zConf = zConf;
     this.authorizationService = authorizationService;
     this.noteManager = noteManager;
     this.notebookRepo = notebookRepo;
@@ -114,7 +115,7 @@ public class Notebook {
   }
 
   public void recoveryIfNecessary() {
-    if (conf.isRecoveryEnabled()) {
+    if (zConf.isRecoveryEnabled()) {
       recoverRunningParagraphs();
     }
   }
@@ -137,7 +138,7 @@ public class Notebook {
   public void initNotebook() {
     if (initExecutor == null || initExecutor.isShutdown() || initExecutor.isTerminated()) {
       initExecutor = new ThreadPoolExecutor(0, Runtime.getRuntime().availableProcessors(), 1, TimeUnit.MINUTES,
-                     new LinkedBlockingQueue<>(), new SchedulerThreadFactory("NotebookInit"));
+                     new LinkedBlockingQueue<>(), new NamedThreadFactory("NotebookInit"));
     }
     for (NoteInfo noteInfo : getNotesInfo()) {
       initExecutor.execute(() -> {
@@ -211,7 +212,7 @@ public class Notebook {
 
   @Inject
   public Notebook(
-      ZeppelinConfiguration conf,
+      ZeppelinConfiguration zConf,
       AuthorizationService authorizationService,
       NotebookRepo notebookRepo,
       NoteManager noteManager,
@@ -221,7 +222,7 @@ public class Notebook {
       NoteEventListener noteEventListener)
       throws IOException {
     this(
-        conf,
+        zConf,
         authorizationService,
         notebookRepo,
         noteManager,
@@ -308,7 +309,8 @@ public class Notebook {
                          boolean save) throws IOException {
     Note note =
             new Note(notePath, defaultInterpreterGroup, replFactory, interpreterSettingManager,
-                    paragraphJobListener, credentials, noteEventListeners);
+                    paragraphJobListener, credentials, noteEventListeners, zConf,
+                    notebookRepo.getNoteParser());
     noteManager.addNote(note, subject);
     // init noteMeta
     authorizationService.createNoteAuth(note.getId(), subject);
@@ -351,7 +353,7 @@ public class Notebook {
    */
   public String importNote(String sourceJson, String notePath, AuthenticationInfo subject)
       throws IOException {
-    Note oldNote = Note.fromJson(null, sourceJson);
+    Note oldNote = notebookRepo.getNoteParser().fromJson(null, sourceJson);
     if (notePath == null) {
       notePath = oldNote.getName();
     }
@@ -645,7 +647,7 @@ public class Notebook {
     note.setCronSupported(getConf());
 
     if (note.getDefaultInterpreterGroup() == null) {
-      note.setDefaultInterpreterGroup(conf.getString(ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT));
+      note.setDefaultInterpreterGroup(zConf.getString(ConfVars.ZEPPELIN_INTERPRETER_GROUP_DEFAULT));
     }
 
     Map<String, SnapshotAngularObject> angularObjectSnapshot = new HashMap<>();
@@ -750,9 +752,9 @@ public class Notebook {
   }
 
   public List<NoteInfo> getNotesInfo(Predicate<String> func) {
-    String homescreenNoteId = conf.getString(ConfVars.ZEPPELIN_NOTEBOOK_HOMESCREEN);
+    String homescreenNoteId = zConf.getString(ConfVars.ZEPPELIN_NOTEBOOK_HOMESCREEN);
     boolean hideHomeScreenNotebookFromList =
-        conf.getBoolean(ConfVars.ZEPPELIN_NOTEBOOK_HOMESCREEN_HIDE);
+        zConf.getBoolean(ConfVars.ZEPPELIN_NOTEBOOK_HOMESCREEN_HIDE);
 
     synchronized (noteManager.getNotesInfo()) {
       List<NoteInfo> notesInfo = noteManager.getNotesInfo().entrySet().stream().filter(entry ->
@@ -814,7 +816,7 @@ public class Notebook {
   }
 
   public ZeppelinConfiguration getConf() {
-    return conf;
+    return zConf;
   }
 
   public void close() {
@@ -847,7 +849,7 @@ public class Notebook {
   }
 
   public Boolean isRevisionSupported() {
-    if(!conf.getBoolean(ConfVars.ZEPPELIN_NOTEBOOK_VERSIONED_MODE_ENABLE)) {
+    if(!zConf.getBoolean(ConfVars.ZEPPELIN_NOTEBOOK_VERSIONED_MODE_ENABLE)) {
       return false;
     }
     if (notebookRepo instanceof NotebookRepoSync) {
