@@ -21,6 +21,7 @@ package org.apache.zeppelin.notebook.repo;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.NoteInfo;
+import org.apache.zeppelin.notebook.NoteParser;
 import org.apache.zeppelin.user.AuthenticationInfo;
 
 import java.io.IOException;
@@ -29,13 +30,13 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-public class InMemoryNotebookRepo implements NotebookRepo {
+public class InMemoryNotebookRepo extends AbstractNotebookRepo {
 
   private Map<String, Note> notes = new HashMap<>();
 
   @Override
-  public void init(ZeppelinConfiguration zConf) throws IOException {
-
+  public void init(ZeppelinConfiguration zConf, NoteParser parser) throws IOException {
+    super.init(zConf, parser);
   }
 
   @Override
