@@ -38,6 +38,7 @@ import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars;
 import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.NoteInfo;
+import org.apache.zeppelin.notebook.NoteParser;
 import org.apache.zeppelin.notebook.exception.CorruptedNoteException;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.slf4j.Logger;
@@ -46,10 +47,9 @@ import org.slf4j.LoggerFactory;
 /**
 * NotebookRepo implementation based on apache vfs
 */
-public class VFSNotebookRepo implements NotebookRepo {
+public class VFSNotebookRepo extends AbstractNotebookRepo {
   private static final Logger LOGGER = LoggerFactory.getLogger(VFSNotebookRepo.class);
 
-  protected ZeppelinConfiguration conf;
   protected FileSystemManager fsManager;
   protected FileObject rootNotebookFileObject;
   protected String rootNotebookFolder;
@@ -59,16 +59,16 @@ public class VFSNotebookRepo implements NotebookRepo {
   }
 
   @Override
-  public void init(ZeppelinConfiguration conf) throws IOException {
-    this.conf = conf;
-    setNotebookDirectory(conf.getNotebookDir());
+  public void init(ZeppelinConfiguration zConf, NoteParser noteParser) throws IOException {
+    super.init(zConf, noteParser);
+    setNotebookDirectory(zConf.getNotebookDir());
   }
 
   protected void setNotebookDirectory(String notebookDirPath) throws IOException {
     URI filesystemRoot = null;
     try {
       LOGGER.info("Using notebookDir: {}", notebookDirPath);
-      if (conf.isWindowsPath(notebookDirPath)) {
+      if (zConf.isWindowsPath(notebookDirPath)) {
         filesystemRoot = new File(notebookDirPath).toURI();
       } else {
         filesystemRoot = new URI(notebookDirPath);
@@ -78,7 +78,7 @@ public class VFSNotebookRepo implements NotebookRepo {
     }
 
     if (filesystemRoot.getScheme() == null) { // it is local path
-      File f = new File(conf.getAbsoluteDir(filesystemRoot.getPath()));
+      File f = new File(zConf.getAbsoluteDir(filesystemRoot.getPath()));
       filesystemRoot = f.toURI();
     }
     this.fsManager = VFS.getManager();
@@ -131,22 +131,23 @@ public class VFSNotebookRepo implements NotebookRepo {
   }
 
   @Override
-  public Note get(String noteId, String notePath, AuthenticationInfo subject) throws IOException {
+  public Note get(String noteId, String notePath, AuthenticationInfo subject)
+      throws IOException {
     FileObject noteFile = rootNotebookFileObject.resolveFile(buildNoteFileName(noteId, notePath),
         NameScope.DESCENDENT);
     String json = IOUtils.toString(noteFile.getContent().getInputStream(),
-        conf.getString(ConfVars.ZEPPELIN_ENCODING));
+        zConf.getString(ConfVars.ZEPPELIN_ENCODING));
 
     try {
-      Note note = Note.fromJson(noteId, json);
+      Note note = noteParser.fromJson(noteId, json);
       // setPath here just for testing, because actually NoteManager will setPath
       note.setPath(notePath);
       return note;
     } catch (CorruptedNoteException e) {
       String errorMessage = String.format(
           "Fail to parse note json. Please check the file at this path to resolve the issue. "
-              + "Path: %s, "
-              + "Content: %s",
+          + "Path: %s, "
+          + "Content: %s",
           rootNotebookFolder + notePath, json
       );
       throw new CorruptedNoteException(noteId, errorMessage, e);
@@ -162,7 +163,7 @@ public class VFSNotebookRepo implements NotebookRepo {
     OutputStream out = null;
     try {
       out = noteJson.getContent().getOutputStream(false);
-      IOUtils.write(note.toJson().getBytes(conf.getString(ConfVars.ZEPPELIN_ENCODING)), out);
+      IOUtils.write(note.toJson().getBytes(zConf.getString(ConfVars.ZEPPELIN_ENCODING)), out);
     } finally {
       if (out != null) {
         out.close();
