@@ -33,45 +33,37 @@ import java.util.LinkedList;
 import java.util.List;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.conf.ZeppelinConfiguration.ConfVars;
-import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-public class HeliumBundleFactoryTest {
+class HeliumBundleFactoryTest {
   private HeliumBundleFactory hbf;
   private File nodeInstallationDir;
-  private String zeppelinHomePath;
 
   @BeforeEach
   public void setUp() throws InstallationException, TaskRunnerException, IOException {
-    zeppelinHomePath = System.getProperty(ConfVars.ZEPPELIN_HOME.getVarName());
-    System.setProperty(ConfVars.ZEPPELIN_HOME.getVarName(), "../");
-
-    ZeppelinConfiguration conf = ZeppelinConfiguration.create();
+    ZeppelinConfiguration zConf = ZeppelinConfiguration.load();
+    zConf.setProperty(ConfVars.ZEPPELIN_HOME.getVarName(),
+        new File("../").getAbsolutePath().toString());
     nodeInstallationDir =
-        new File(conf.getAbsoluteDir(ConfVars.ZEPPELIN_DEP_LOCALREPO), HELIUM_LOCAL_REPO);
+        new File(zConf.getAbsoluteDir(ConfVars.ZEPPELIN_DEP_LOCALREPO), HELIUM_LOCAL_REPO);
 
-    hbf = new HeliumBundleFactory(conf);
+    hbf = new HeliumBundleFactory(zConf);
     hbf.installNodeAndNpm();
     hbf.copyFrameworkModulesToInstallPath(true);
   }
 
-  @AfterEach
-  public void tearDown() throws IOException {
-    if (null != zeppelinHomePath) {
-      System.setProperty(ConfVars.ZEPPELIN_HOME.getVarName(), zeppelinHomePath);
-    }
-  }
+
 
   @Test
-  public void testInstallNpm() throws InstallationException {
+  void testInstallNpm() throws InstallationException {
     assertTrue(new File(nodeInstallationDir, "/node/npm").isFile());
     assertTrue(new File(nodeInstallationDir, "/node/node").isFile());
     assertTrue(new File(nodeInstallationDir, "/node/yarn/dist/bin/yarn").isFile());
   }
 
   @Test
-  public void downloadPackage() throws TaskRunnerException {
+  void downloadPackage() throws TaskRunnerException {
     HeliumPackage pkg =
         newHeliumPackage(
             HeliumType.VISUALIZATION,
@@ -88,7 +80,7 @@ public class HeliumBundleFactoryTest {
   }
 
   @Test
-  public void bundlePackage() throws IOException, TaskRunnerException {
+  void bundlePackage() throws IOException, TaskRunnerException {
     HeliumPackage pkg =
         newHeliumPackage(
             HeliumType.VISUALIZATION,
@@ -109,7 +101,7 @@ public class HeliumBundleFactoryTest {
   }
 
   @Test
-  public void bundleLocalPackage() throws IOException, TaskRunnerException {
+  void bundleLocalPackage() throws IOException, TaskRunnerException {
     URL res = Resources.getResource("helium/webpack.config.js");
     String resDir = new File(res.getFile()).getParent();
     String localPkg = resDir + "/../../../src/test/resources/helium/vis1";
@@ -157,7 +149,7 @@ public class HeliumBundleFactoryTest {
   }
 
   @Test
-  public void switchVersion() throws IOException, TaskRunnerException {
+  void switchVersion() throws IOException, TaskRunnerException {
     URL res = Resources.getResource("helium/webpack.config.js");
     String resDir = new File(res.getFile()).getParent();
 
