@@ -24,10 +24,12 @@ import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
+
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 
 
-public class HeliumOnlineRegistryTest {
+class HeliumOnlineRegistryTest {
   // ip 192.168.65.17 belongs to private network
   // request will be ended with connection time out error
   private static final String IP = "192.168.65.17";
@@ -37,11 +39,7 @@ public class HeliumOnlineRegistryTest {
 
   @BeforeEach
   public void setUp() throws Exception {
-    tmpDir = new File(
-            System.getProperty("java.io.tmpdir")
-                    + "/ZeppelinLTest_"
-                    + System.currentTimeMillis()
-    );
+    tmpDir = Files.createTempDirectory("ZeppelinLTest").toFile();
   }
 
   @AfterEach
@@ -50,19 +48,14 @@ public class HeliumOnlineRegistryTest {
   }
 
   @Test
-  public void zeppelinNotebookS3TimeoutPropertyTest() throws IOException {
-    System.setProperty(
-            ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_S3_TIMEOUT.getVarName(),
-            TIMEOUT
-    );
-    System.setProperty(
-            ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_S3_ENDPOINT.getVarName(),
-            IP
-    );
+  void zeppelinNotebookS3TimeoutPropertyTest() throws IOException {
+    ZeppelinConfiguration zConf = ZeppelinConfiguration.load();
+    zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_S3_TIMEOUT.getVarName(), TIMEOUT);
+    zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_S3_ENDPOINT.getVarName(), IP);
     HeliumOnlineRegistry heliumOnlineRegistry = new HeliumOnlineRegistry(
             "https://" + IP,
             "https://" + IP,
-            tmpDir
+            tmpDir, zConf
     );
 
     long start = System.currentTimeMillis();
