@@ -34,7 +34,7 @@ import java.util.concurrent.atomic.AtomicInteger;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
-public class RemoteAngularObjectTest extends AbstractInterpreterTest
+class RemoteAngularObjectTest extends AbstractInterpreterTest
     implements AngularObjectRegistryListener {
 
   private RemoteInterpreter intp;
@@ -74,7 +74,7 @@ public class RemoteAngularObjectTest extends AbstractInterpreterTest
   }
 
   @Test
-  public void testAngularObjectInterpreterSideCRUD() throws InterruptedException, InterpreterException {
+  void testAngularObjectInterpreterSideCRUD() throws InterruptedException, InterpreterException {
     InterpreterResult ret = intp.interpret("get", context);
     Thread.sleep(500); // waitFor eventpoller pool event
     String[] result = ret.message().get(0).getData().split(" ");
@@ -107,7 +107,7 @@ public class RemoteAngularObjectTest extends AbstractInterpreterTest
   }
 
   @Test
-  public void testAngularObjectRemovalOnZeppelinServerSide() throws InterruptedException, InterpreterException {
+  void testAngularObjectRemovalOnZeppelinServerSide() throws InterruptedException, InterpreterException {
     // test if angularobject removal from server side propagate to interpreter process's registry.
     // will happen when notebook is removed.
 
@@ -132,7 +132,7 @@ public class RemoteAngularObjectTest extends AbstractInterpreterTest
   }
 
   @Test
-  public void testAngularObjectAddOnZeppelinServerSide() throws InterruptedException, InterpreterException {
+  void testAngularObjectAddOnZeppelinServerSide() throws InterruptedException, InterpreterException {
     // test if angularobject add from server side propagate to interpreter process's registry.
     // will happen when zeppelin server loads notebook and restore the object into registry
 
