@@ -17,6 +17,7 @@
 
 package org.apache.zeppelin.notebook;
 
+import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.display.AngularObject;
 import org.apache.zeppelin.display.ui.TextBox;
 import org.apache.zeppelin.interpreter.Interpreter;
@@ -30,6 +31,7 @@ import org.apache.zeppelin.notebook.repo.NotebookRepo;
 import org.apache.zeppelin.scheduler.Scheduler;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.apache.zeppelin.user.Credentials;
+import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.mockito.ArgumentCaptor;
@@ -68,6 +70,15 @@ class NoteTest {
 
   private AuthenticationInfo anonymous = new AuthenticationInfo("anonymous");
 
+  private static ZeppelinConfiguration zConf;
+  private static NoteParser noteParser;
+
+  @BeforeAll
+  public static void before() {
+    zConf = ZeppelinConfiguration.load();
+    noteParser = new GsonNoteParser(zConf);
+  }
+
   @BeforeEach
   public void setUp() {
     repo = mock(NotebookRepo.class);
@@ -89,7 +100,7 @@ class NoteTest {
     when(interpreterGroup.getInterpreterSetting()).thenReturn(interpreterSetting);
 
     String pText = "%spark sc.version";
-    Note note = new Note("test", "test", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "test", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
 
     Paragraph p = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     p.setText(pText);
@@ -105,7 +116,8 @@ class NoteTest {
 
   @Test
   void addParagraphWithEmptyReplNameTest() {
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager,
+        paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     Paragraph p = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     assertNull(p.getText());
   }
@@ -113,7 +125,7 @@ class NoteTest {
   @Test
   void addParagraphWithLastReplNameTest() throws InterpreterNotFoundException {
     when(interpreterFactory.getInterpreter(eq("spark"), any())).thenReturn(interpreter);
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     p1.setText("%spark ");
     Paragraph p2 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -124,7 +136,7 @@ class NoteTest {
   @Test
   void insertParagraphWithLastReplNameTest() throws InterpreterNotFoundException {
     when(interpreterFactory.getInterpreter(eq("spark"), any())).thenReturn(interpreter);
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     p1.setText("%spark ");
     Paragraph p2 = note.insertNewParagraph(note.getParagraphs().size(), AuthenticationInfo.ANONYMOUS);
@@ -135,7 +147,7 @@ class NoteTest {
   @Test
   void insertParagraphWithInvalidReplNameTest() throws InterpreterNotFoundException {
     when(interpreterFactory.getInterpreter(eq("invalid"), any())).thenReturn(null);
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     p1.setText("%invalid ");
     Paragraph p2 = note.insertNewParagraph(note.getParagraphs().size(), AuthenticationInfo.ANONYMOUS);
@@ -145,7 +157,8 @@ class NoteTest {
 
   @Test
   void insertParagraphwithUser() {
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager,
+        paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     Paragraph p = note.insertNewParagraph(note.getParagraphs().size(), AuthenticationInfo.ANONYMOUS);
     assertEquals("anonymous", p.getUser());
   }
@@ -153,7 +166,8 @@ class NoteTest {
   @Test
   void clearAllParagraphOutputTest() throws InterpreterNotFoundException {
 
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager,
+        paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
     InterpreterResult result = new InterpreterResult(InterpreterResult.Code.SUCCESS, InterpreterResult.Type.TEXT, "result");
     p1.setResult(result);
@@ -170,7 +184,8 @@ class NoteTest {
 
   @Test
   void personalizedModeReturnDifferentParagraphInstancePerUser() {
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager,
+        paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     String user1 = "user1";
     String user2 = "user2";
     note.setPersonalizedMode(true);
@@ -184,7 +199,8 @@ class NoteTest {
   }
 
   public void testNoteJson() throws IOException {
-    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager, paragraphJobListener, credentials, noteEventListener);
+    Note note = new Note("test", "", interpreterFactory, interpreterSettingManager,
+        paragraphJobListener, credentials, noteEventListener, zConf, noteParser);
     note.setName("/test_note");
     note.getConfig().put("config_1", "value_1");
     note.getInfo().put("info_1", "value_1");
@@ -197,12 +213,12 @@ class NoteTest {
     note.getAngularObjects().put("ao_1", Arrays.asList(new AngularObject("name_1", "value_1", note.getId(), p.getId(), null)));
 
     // test Paragraph Json
-    Paragraph p2 = Paragraph.fromJson(p.toJson());
+    Paragraph p2 = p.fromJson(p.toJson());
     assertEquals(p2.settings, p.settings);
     assertEquals(p2, p);
 
     // test Note Json
-    Note note2 = Note.fromJson(null, note.toJson());
+    Note note2 = noteParser.fromJson(null, note.toJson());
     assertEquals(note2, note);
   }
 }
