@@ -50,6 +50,7 @@ import org.junit.jupiter.params.provider.MethodSource;
 import org.quartz.SchedulerException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+
 import org.eclipse.aether.RepositoryException;
 
 import java.io.File;
@@ -82,8 +83,8 @@ import static org.junit.jupiter.api.Assertions.fail;
 import static org.mockito.Mockito.mock;
 
 
-public class NotebookTest extends AbstractInterpreterTest implements ParagraphJobListener {
-  private static final Logger logger = LoggerFactory.getLogger(NotebookTest.class);
+class NotebookTest extends AbstractInterpreterTest implements ParagraphJobListener {
+  private static final Logger LOGGER = LoggerFactory.getLogger(NotebookTest.class);
 
   private Notebook notebook;
   private NoteManager noteManager;
@@ -97,19 +98,20 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   @Override
   @BeforeEach
   public void setUp() throws Exception {
-    System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_PUBLIC.getVarName(), "true");
-    System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_ENABLE.getVarName(), "true");
     super.setUp();
+    zConf.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_PUBLIC.getVarName(), "true");
+    zConf.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_ENABLE.getVarName(), "true");
 
     notebookRepo = new VFSNotebookRepo();
-    notebookRepo.init(conf);
-    noteManager = new NoteManager(notebookRepo, conf);
-    authorizationService = new AuthorizationService(noteManager, conf);
+    notebookRepo.init(zConf, noteParser);
+    noteManager = new NoteManager(notebookRepo, zConf);
 
-    credentials = new Credentials(conf);
-    notebook = new Notebook(conf, authorizationService, notebookRepo, noteManager, interpreterFactory, interpreterSettingManager, credentials, null);
+    authorizationService = new AuthorizationService(noteManager, zConf, storage);
+
+    credentials = new Credentials(zConf, storage);
+    notebook = new Notebook(zConf, authorizationService, notebookRepo, noteManager, interpreterFactory, interpreterSettingManager, credentials, null);
     notebook.setParagraphJobListener(this);
-    schedulerService = new QuartzSchedulerService(conf, notebook);
+    schedulerService = new QuartzSchedulerService(zConf, notebook);
     notebook.initNotebook();
     notebook.waitForFinishInit(1, TimeUnit.MINUTES);
 
@@ -126,17 +128,17 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testRevisionSupported() throws IOException {
+  void testRevisionSupported() throws IOException {
     NotebookRepo notebookRepo;
     Notebook notebook;
 
     notebookRepo = new DummyNotebookRepo();
-    notebook = new Notebook(conf, mock(AuthorizationService.class), notebookRepo, new NoteManager(notebookRepo, conf), interpreterFactory,
+    notebook = new Notebook(zConf, mock(AuthorizationService.class), notebookRepo, new NoteManager(notebookRepo, zConf), interpreterFactory,
         interpreterSettingManager, credentials, null);
     assertFalse( notebook.isRevisionSupported(), "Revision is not supported in DummyNotebookRepo");
 
     notebookRepo = new DummyNotebookRepoWithVersionControl();
-    notebook = new Notebook(conf, mock(AuthorizationService.class), notebookRepo, new NoteManager(notebookRepo, conf), interpreterFactory,
+    notebook = new Notebook(zConf, mock(AuthorizationService.class), notebookRepo, new NoteManager(notebookRepo, zConf), interpreterFactory,
         interpreterSettingManager, credentials, null);
     assertTrue(notebook.isRevisionSupported(), "Revision is supported in DummyNotebookRepoWithVersionControl");
   }
@@ -144,7 +146,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   public static class DummyNotebookRepo implements NotebookRepo {
 
     @Override
-    public void init(ZeppelinConfiguration zConf) throws IOException {
+    public void init(ZeppelinConfiguration zConf, NoteParser noteParser) throws IOException {
 
     }
 
@@ -197,6 +199,11 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
     public void updateSettings(Map<String, String> settings, AuthenticationInfo subject) {
 
     }
+
+    @Override
+    public NoteParser getNoteParser() {
+      return null;
+    }
   }
 
   public static class DummyNotebookRepoWithVersionControl implements
@@ -225,7 +232,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
     }
 
     @Override
-    public void init(ZeppelinConfiguration zConf) throws IOException {
+    public void init(ZeppelinConfiguration zConf, NoteParser noteParser) throws IOException {
 
     }
 
@@ -278,10 +285,15 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
     public void updateSettings(Map<String, String> settings, AuthenticationInfo subject) {
 
     }
+
+    @Override
+    public NoteParser getNoteParser() {
+      return null;
+    }
   }
 
   @Test
-  public void testSelectingReplImplementation() throws IOException {
+  void testSelectingReplImplementation() throws IOException {
     String noteId = notebook.createNote("note1", anonymous);
     notebook.processNote(noteId,
       note -> {
@@ -310,7 +322,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testReloadAndSetInterpreter() throws IOException {
+  void testReloadAndSetInterpreter() throws IOException {
     String noteId = notebook.createNote("note1", AuthenticationInfo.ANONYMOUS);
     notebook.processNote(noteId,
       note -> {
@@ -339,7 +351,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testReloadAllNotes() throws IOException {
+  void testReloadAllNotes() throws IOException {
     String note1Id = notebook.createNote("note1", AuthenticationInfo.ANONYMOUS);
     notebook.processNote(note1Id,
       note1 -> {
@@ -387,7 +399,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testLoadAllNotes() {
+  void testLoadAllNotes() {
     try {
       assertEquals(0, notebook.getNotesInfo().size());
       String noteId = notebook.createNote("note1", anonymous);
@@ -402,14 +414,14 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
           return null;
         });
     } catch (IOException fe) {
-      logger.warn("Failed to create note and paragraph. Possible problem with persisting note, safe to ignore", fe);
+      LOGGER.warn("Failed to create note and paragraph. Possible problem with persisting note, safe to ignore", fe);
     }
 
     assertEquals(1, notebook.getNotesInfo().size());
   }
 
   @Test
-  public void testPersist() throws IOException, SchedulerException {
+  void testPersist() throws IOException, SchedulerException {
     String noteId = notebook.createNote("note1", anonymous);
     notebook.processNote(noteId,
       note -> {
@@ -427,7 +439,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testCreateNoteWithSubject() throws IOException, SchedulerException, RepositoryException {
+  void testCreateNoteWithSubject() throws IOException, SchedulerException, RepositoryException {
     AuthenticationInfo subject = new AuthenticationInfo("user1");
     String noteId = notebook.createNote("note1", subject);
     assertNotNull(authorizationService.getOwners(noteId));
@@ -439,7 +451,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testClearParagraphOutput() throws IOException, SchedulerException {
+  void testClearParagraphOutput() throws IOException, SchedulerException {
     String noteId = notebook.createNote("note1", anonymous);
     notebook.processNote(noteId,
       note -> {
@@ -463,7 +475,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testRunBlankParagraph() throws IOException, SchedulerException, InterruptedException {
+  void testRunBlankParagraph() throws IOException, SchedulerException, InterruptedException {
     String noteId = notebook.createNote("note1", anonymous);
     notebook.processNote(noteId,
       note -> {
@@ -485,7 +497,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testRemoveNote() throws IOException, InterruptedException {
+  void testRemoveNote() throws IOException, InterruptedException {
     try {
       LOGGER.info("--------------- Test testRemoveNote ---------------");
       // create a note and a paragraph
@@ -521,28 +533,28 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testRemoveCorruptedNote() throws IOException{
-      LOGGER.info("--------------- Test testRemoveCorruptedNote ---------------");
-      // create a note and a paragraph
-      String corruptedNoteId = notebook.createNote("note1", anonymous);
-      String corruptedNotePath = notebook.processNote(corruptedNoteId,
-        corruptedNote -> {
-          return notebookDir.getAbsolutePath() + corruptedNote.getPath() + "_" + corruptedNote.getId() + ".zpln";
-        });
+  void testRemoveCorruptedNote() throws IOException {
+    LOGGER.info("--------------- Test testRemoveCorruptedNote ---------------");
+    // create a note and a paragraph
+    String corruptedNoteId = notebook.createNote("note1", anonymous);
+    String corruptedNotePath = notebook.processNote(corruptedNoteId,
+      corruptedNote -> {
+        return notebookDir.getAbsolutePath() + corruptedNote.getPath() + "_" + corruptedNote.getId() + ".zpln";
+      });
 
-      // corrupt note
-      FileWriter myWriter = new FileWriter(corruptedNotePath);
-      myWriter.write("{{{I'm corrupted;;;");
-      myWriter.close();
-      LOGGER.info("--------------- Finish Test testRemoveCorruptedNote ---------------");
-      int numberOfNotes = notebook.getNotesInfo().size();
-      notebook.removeNote(corruptedNoteId, anonymous);
-      assertEquals(numberOfNotes - 1, notebook.getNotesInfo().size());
-      LOGGER.info("--------------- Finish Test testRemoveCorruptedNote ---------------");
+    // corrupt note
+    FileWriter myWriter = new FileWriter(corruptedNotePath);
+    myWriter.write("{{{I'm corrupted;;;");
+    myWriter.close();
+    LOGGER.info("--------------- Finish Test testRemoveCorruptedNote ---------------");
+    int numberOfNotes = notebook.getNotesInfo().size();
+    notebook.removeNote(corruptedNoteId, anonymous);
+    assertEquals(numberOfNotes - 1, notebook.getNotesInfo().size());
+    LOGGER.info("--------------- Finish Test testRemoveCorruptedNote ---------------");
   }
 
   @Test
-  public void testInvalidInterpreter() throws IOException, InterruptedException {
+  void testInvalidInterpreter() throws IOException, InterruptedException {
     String noteId = notebook.createNote("note1", anonymous);
     notebook.processNote(noteId,
       note -> {
@@ -567,7 +579,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testRunAll() throws Exception {
+  void testRunAll() throws Exception {
     String noteId = notebook.createNote("note1", anonymous);
     notebook.processNote(noteId,
       note -> {
@@ -605,7 +617,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testSchedule() throws InterruptedException, IOException {
+  void testSchedule() throws InterruptedException, IOException {
     // create a note and a paragraph
     String noteId = notebook.createNote("note1", anonymous);
     // use write lock, because note configuration is overwritten
@@ -649,7 +661,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testScheduleAgainstRunningAndPendingParagraph() throws InterruptedException, IOException {
+  void testScheduleAgainstRunningAndPendingParagraph() throws InterruptedException, IOException {
     // create a note
     String noteId = notebook.createNote("note1", anonymous);
     // append running and pending paragraphs to the note
@@ -703,7 +715,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testSchedulePoolUsage() throws InterruptedException, IOException {
+  void testSchedulePoolUsage() throws InterruptedException, IOException {
     final int timeout = 30;
     final String everySecondCron = "* * * * * ?";
     // each run starts a new JVM and the job takes about ~5 seconds
@@ -741,83 +753,74 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testScheduleDisabled() throws InterruptedException, IOException {
+  void testScheduleDisabled() throws InterruptedException, IOException {
+    zConf.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_ENABLE.getVarName(), "false");
+    final int timeout = 10;
+    final String everySecondCron = "* * * * * ?";
+    final CountDownLatch jobsToExecuteCount = new CountDownLatch(5);
+    final String noteId = notebook.createNote("note1", anonymous);
 
-    System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_ENABLE.getVarName(), "false");
-    try {
-      final int timeout = 10;
-      final String everySecondCron = "* * * * * ?";
-      final CountDownLatch jobsToExecuteCount = new CountDownLatch(5);
-      final String noteId = notebook.createNote("note1", anonymous);
-
-      executeNewParagraphByCron(noteId, everySecondCron);
-      afterStatusChangedListener = new StatusChangedListener() {
-        @Override
-        public void onStatusChanged(Job<?> job, Status before, Status after) {
-          if (after == Status.FINISHED) {
-            jobsToExecuteCount.countDown();
-          }
+    executeNewParagraphByCron(noteId, everySecondCron);
+    afterStatusChangedListener = new StatusChangedListener() {
+      @Override
+      public void onStatusChanged(Job<?> job, Status before, Status after) {
+        if (after == Status.FINISHED) {
+          jobsToExecuteCount.countDown();
         }
-      };
+      }
+    };
 
-      //This job should not run because "ZEPPELIN_NOTEBOOK_CRON_ENABLE" is set to false
-      assertFalse(jobsToExecuteCount.await(timeout, TimeUnit.SECONDS));
+    // This job should not run because "ZEPPELIN_NOTEBOOK_CRON_ENABLE" is set to false
+    assertFalse(jobsToExecuteCount.await(timeout, TimeUnit.SECONDS));
 
-      terminateScheduledNote(noteId);
-      afterStatusChangedListener = null;
-    } finally {
-      System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_ENABLE.getVarName(), "true");
-    }
+    terminateScheduledNote(noteId);
+    afterStatusChangedListener = null;
   }
 
   @Test
-  public void testScheduleDisabledWithName() throws InterruptedException, IOException {
+  void testScheduleDisabledWithName() throws InterruptedException, IOException {
 
-    System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_FOLDERS.getVarName(), "/System");
-    try {
-      final int timeout = 30;
-      final String everySecondCron = "* * * * * ?";
-      // each run starts a new JVM and the job takes about ~5 seconds
-      final CountDownLatch jobsToExecuteCount = new CountDownLatch(5);
-      final String noteId = notebook.createNote("note1", anonymous);
+    zConf.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_FOLDERS.getVarName(), "/System");
+    final int timeout = 30;
+    final String everySecondCron = "* * * * * ?";
+    // each run starts a new JVM and the job takes about ~5 seconds
+    final CountDownLatch jobsToExecuteCount = new CountDownLatch(5);
+    final String noteId = notebook.createNote("note1", anonymous);
 
-      executeNewParagraphByCron(noteId, everySecondCron);
-      afterStatusChangedListener = new StatusChangedListener() {
-        @Override
-        public void onStatusChanged(Job<?> job, Status before, Status after) {
-          if (after == Status.FINISHED) {
-            jobsToExecuteCount.countDown();
-          }
+    executeNewParagraphByCron(noteId, everySecondCron);
+    afterStatusChangedListener = new StatusChangedListener() {
+      @Override
+      public void onStatusChanged(Job<?> job, Status before, Status after) {
+        if (after == Status.FINISHED) {
+          jobsToExecuteCount.countDown();
         }
-      };
+      }
+    };
 
-      //This job should not run because it's path does not matches "ZEPPELIN_NOTEBOOK_CRON_FOLDERS"
-      assertFalse(jobsToExecuteCount.await(timeout, TimeUnit.SECONDS));
+    // This job should not run because it's path does not matches "ZEPPELIN_NOTEBOOK_CRON_FOLDERS"
+    assertFalse(jobsToExecuteCount.await(timeout, TimeUnit.SECONDS));
 
-      terminateScheduledNote(noteId);
-      afterStatusChangedListener = null;
+    terminateScheduledNote(noteId);
+    afterStatusChangedListener = null;
 
-      final String noteNameSystemId = notebook.createNote("/System/test1", anonymous);
-      final CountDownLatch jobsToExecuteCountNameSystem = new CountDownLatch(5);
+    final String noteNameSystemId = notebook.createNote("/System/test1", anonymous);
+    final CountDownLatch jobsToExecuteCountNameSystem = new CountDownLatch(5);
 
-      executeNewParagraphByCron(noteNameSystemId, everySecondCron);
-      afterStatusChangedListener = new StatusChangedListener() {
-        @Override
-        public void onStatusChanged(Job<?> job, Status before, Status after) {
-          if (after == Status.FINISHED) {
-            jobsToExecuteCountNameSystem.countDown();
-          }
+    executeNewParagraphByCron(noteNameSystemId, everySecondCron);
+    afterStatusChangedListener = new StatusChangedListener() {
+      @Override
+      public void onStatusChanged(Job<?> job, Status before, Status after) {
+        if (after == Status.FINISHED) {
+          jobsToExecuteCountNameSystem.countDown();
         }
-      };
+      }
+    };
 
-      //This job should run because it's path contains "System/"
-      assertTrue(jobsToExecuteCountNameSystem.await(timeout, TimeUnit.SECONDS));
+    // This job should run because it's path contains "System/"
+    assertTrue(jobsToExecuteCountNameSystem.await(timeout, TimeUnit.SECONDS));
 
-      terminateScheduledNote(noteNameSystemId);
-      afterStatusChangedListener = null;
-    } finally {
-      System.clearProperty(ConfVars.ZEPPELIN_NOTEBOOK_CRON_FOLDERS.getVarName());
-    }
+    terminateScheduledNote(noteNameSystemId);
+    afterStatusChangedListener = null;
   }
 
   private void terminateScheduledNote(String noteId) throws IOException {
@@ -989,7 +992,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testCronNoteInTrash() throws InterruptedException, IOException, SchedulerException {
+  void testCronNoteInTrash() throws InterruptedException, IOException, SchedulerException {
     String noteId = notebook.createNote("~Trash/NotCron", anonymous);
     // use write lock because we overwrite the note config
     notebook.processNote(noteId,
@@ -1017,7 +1020,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testExportAndImportNote() throws Exception {
+  void testExportAndImportNote() throws Exception {
     String noteId = notebook.createNote("note1", anonymous);
 
     notebook.processNote(noteId,
@@ -1068,7 +1071,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testCloneNote() throws Exception {
+  void testCloneNote() throws Exception {
     String noteId = notebook.createNote("note1", anonymous);
     notebook.processNote(noteId,
       note -> {
@@ -1116,7 +1119,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testResourceRemovealOnParagraphNoteRemove() throws Exception {
+  void testResourceRemovealOnParagraphNoteRemove() throws Exception {
     String noteId = notebook.createNote("note1", anonymous);
 
     notebook.processNote(noteId,
@@ -1150,7 +1153,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testAngularObjectRemovalOnNotebookRemove() throws InterruptedException,
+  void testAngularObjectRemovalOnNotebookRemove() throws InterruptedException,
       IOException {
     // create a note and a paragraph
     String noteId = notebook.createNote("note1", anonymous);
@@ -1184,7 +1187,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testAngularObjectRemovalOnParagraphRemove() throws InterruptedException,
+  void testAngularObjectRemovalOnParagraphRemove() throws InterruptedException,
       IOException {
     // create a note and a paragraph
     String noteId = notebook.createNote("note1", anonymous);
@@ -1227,7 +1230,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testAngularObjectRemovalOnInterpreterRestart() throws InterruptedException,
+  void testAngularObjectRemovalOnInterpreterRestart() throws InterruptedException,
       IOException, InterpreterException {
     // create a note and a paragraph
     String noteId = notebook.createNote("note1", anonymous);
@@ -1260,7 +1263,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testPermissions() throws IOException {
+  void testPermissions() throws IOException {
     // create a note and a paragraph
     String noteId = notebook.createNote("note1", anonymous);
     // empty owners, readers or writers means note is public
@@ -1313,7 +1316,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testAuthorizationRoles() throws IOException {
+  void testAuthorizationRoles() throws IOException {
     String user1 = "user1";
     String user2 = "user2";
     Set<String> roles = new HashSet<>(Arrays.asList("admin"));
@@ -1359,10 +1362,11 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testInterpreterSettingConfig() {
+  void testInterpreterSettingConfig() {
     LOGGER.info("testInterpreterSettingConfig >>> ");
     Note note = new Note("testInterpreterSettingConfig", "config_test",
-        interpreterFactory, interpreterSettingManager, this, credentials, new ArrayList<>());
+        interpreterFactory, interpreterSettingManager, this, credentials, new ArrayList<>(), zConf,
+        noteParser);
 
     // create paragraphs
     Paragraph p1 = note.addNewParagraph(anonymous);
@@ -1414,7 +1418,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testAbortParagraphStatusOnInterpreterRestart() throws Exception {
+  void testAbortParagraphStatusOnInterpreterRestart() throws Exception {
     String noteId = notebook.createNote("note1", anonymous);
 
     notebook.processNote(noteId,
@@ -1458,7 +1462,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testPerSessionInterpreterCloseOnNoteRemoval() throws IOException, InterpreterException {
+  void testPerSessionInterpreterCloseOnNoteRemoval() throws IOException, InterpreterException {
     // create a notes
     String note1Id = notebook.createNote("note1", anonymous);
     InterpreterResult result = notebook.processNote(note1Id,
@@ -1502,7 +1506,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testPerSessionInterpreter() throws IOException, InterpreterException {
+  void testPerSessionInterpreter() throws IOException, InterpreterException {
     // create two notes
     String note1Id = notebook.createNote("note1", anonymous);
     notebook.processNote(note1Id,
@@ -1559,7 +1563,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
 
 
   @Test
-  public void testPerNoteSessionInterpreter() throws IOException, InterpreterException {
+  void testPerNoteSessionInterpreter() throws IOException, InterpreterException {
     // create two notes
     String note1Id = notebook.createNote("note1", anonymous);
     notebook.processNote(note1Id,
@@ -1698,7 +1702,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testGetAllNotes() throws Exception {
+  void testGetAllNotes() throws Exception {
     String note1Id = notebook.createNote("note1", anonymous);
     String note2Id = notebook.createNote("note2", anonymous);
     assertEquals(2, notebook.getNotesInfo(noteId -> authorizationService.isReader(noteId, new HashSet<>(Arrays.asList("anonymous")))).size());
@@ -1722,7 +1726,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testCreateDuplicateNote() throws Exception {
+  void testCreateDuplicateNote() throws Exception {
     String note1Id = notebook.createNote("note1", anonymous);
     try {
       notebook.createNote("note1", anonymous);
@@ -1735,7 +1739,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testGetAllNotesWithDifferentPermissions() throws IOException {
+  void testGetAllNotesWithDifferentPermissions() throws IOException {
     List<NoteInfo> notes1 = notebook.getNotesInfo(noteId -> authorizationService.isReader(noteId, new HashSet<>(Arrays.asList("user1"))));
     List<NoteInfo> notes2 = notebook.getNotesInfo(noteId -> authorizationService.isReader(noteId, new HashSet<>(Arrays.asList("user2"))));
     assertEquals(0, notes1.size());
@@ -1771,9 +1775,9 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
   }
 
   @Test
-  public void testPublicPrivateNewNote() throws IOException {
+  void testPublicPrivateNewNote() throws IOException {
     // case of public note
-    assertTrue(conf.isNotebookPublic());
+    assertTrue(zConf.isNotebookPublic());
     assertTrue(authorizationService.isPublic());
 
     List<NoteInfo> notes1 = notebook.getNotesInfo(noteId -> authorizationService.isReader(noteId, new HashSet<>(Arrays.asList("user1"))));
@@ -1799,10 +1803,13 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
     assertEquals(0, authorizationService.getWriters(notePublicId).size());
 
     // case of private note
-    System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_PUBLIC.getVarName(), "false");
-    ZeppelinConfiguration conf2 = ZeppelinConfiguration.create();
-    assertFalse(conf2.isNotebookPublic());
-    // notebook authorization reads from conf, so no need to re-initilize
+
+    ZeppelinConfiguration zConf = ZeppelinConfiguration.load();
+    zConf.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_PUBLIC.getVarName(), "false");
+    assertFalse(zConf.isNotebookPublic());
+    authorizationService = new AuthorizationService(noteManager, zConf, storage);
+    notebook = new Notebook(zConf, authorizationService, notebookRepo, noteManager,
+        interpreterFactory, interpreterSettingManager, credentials, null);
     assertFalse(authorizationService.isPublic());
 
     // check that still 1 note per user
@@ -1833,14 +1840,10 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
     assertEquals(1, authorizationService.getReaders(notePrivateId).size());
     assertEquals(1, authorizationService.getRunners(notePrivateId).size());
     assertEquals(1, authorizationService.getWriters(notePrivateId).size());
-
-    //set back public to true
-    System.setProperty(ConfVars.ZEPPELIN_NOTEBOOK_PUBLIC.getVarName(), "true");
-    ZeppelinConfiguration.create();
   }
 
   @Test
-  public void testCloneImportCheck() throws IOException {
+  void testCloneImportCheck() throws IOException {
     String sourceNoteId = notebook.createNote("note1", new AuthenticationInfo("user"));
     notebook.processNote(sourceNoteId,
       sourceNote -> {
@@ -1869,7 +1872,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
 
   @ParameterizedTest
   @MethodSource("provideMoveTestParameters")
-  public void testMoveNote(String oldName, String newPath) throws InterruptedException, IOException {
+  void testMoveNote(String oldName, String newPath) throws InterruptedException, IOException {
     String noteId = null;
     String newName = FilenameUtils.getBaseName(newPath);
     try {
@@ -1886,7 +1889,7 @@ public class NotebookTest extends AbstractInterpreterTest implements ParagraphJo
       // read note json file to check the name field is updated
       File noteFile = notebook.processNote(noteId,
         note -> {
-          return new File(conf.getNotebookDir() + "/" + notebookRepo.buildNoteFileName(note));
+          return new File(zConf.getNotebookDir() + "/" + notebookRepo.buildNoteFileName(note));
         });
       String noteJson = IOUtils.toString(new FileInputStream(noteFile), StandardCharsets.UTF_8);
       assertTrue(noteJson.contains(newName), noteJson);
