@@ -17,38 +17,43 @@
 
 package org.apache.zeppelin.notebook.repo;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-
 import com.google.common.collect.ImmutableMap;
-import java.io.File;
-import java.io.IOException;
-import java.nio.charset.StandardCharsets;
-import java.nio.file.Files;
-import java.util.List;
-import java.util.Map;
+
 import org.apache.commons.io.FileUtils;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
+import org.apache.zeppelin.notebook.GsonNoteParser;
 import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.NoteInfo;
+import org.apache.zeppelin.notebook.NoteParser;
 import org.apache.zeppelin.notebook.Paragraph;
 import org.apache.zeppelin.user.AuthenticationInfo;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-public class VFSNotebookRepoTest {
+import java.io.File;
+import java.nio.file.Files;
+import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.util.List;
+import java.util.Map;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
+class VFSNotebookRepoTest {
 
   private ZeppelinConfiguration zConf;
+  private NoteParser noteParser;
   private VFSNotebookRepo notebookRepo;
 
   @BeforeEach
   public void setUp() throws IOException {
-    File notebookDir = Files.createTempDirectory("notebookDir").toFile();
-    System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_DIR.getVarName(),
-        notebookDir.getAbsolutePath());
+    File notebookDir = Files.createTempDirectory(this.getClass().getSimpleName()).toFile();
+    zConf = ZeppelinConfiguration.load();
+    noteParser = new GsonNoteParser(zConf);
+    zConf.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_NOTEBOOK_DIR.getVarName(), notebookDir.getAbsolutePath());
     notebookRepo = new VFSNotebookRepo();
-    zConf = ZeppelinConfiguration.create();
-    notebookRepo.init(zConf);
+    notebookRepo.init(zConf, noteParser);
   }
 
   @AfterEach
@@ -58,12 +63,13 @@ public class VFSNotebookRepoTest {
   }
 
   @Test
-  public void testBasics() throws IOException {
+  void testBasics() throws IOException {
     assertEquals(0, notebookRepo.list(AuthenticationInfo.ANONYMOUS).size());
 
     // create note1
     Note note1 = new Note();
     note1.setPath("/my_project/my_note1");
+    note1.setNoteParser(noteParser);
     Paragraph p1 = note1.insertNewParagraph(0, AuthenticationInfo.ANONYMOUS);
     p1.setText("%md hello world");
     p1.setTitle("my title");
@@ -77,6 +83,7 @@ public class VFSNotebookRepoTest {
     // create note2
     Note note2 = new Note();
     note2.setPath("/my_note2");
+    note2.setNoteParser(noteParser);
     Paragraph p2 = note2.insertNewParagraph(0, AuthenticationInfo.ANONYMOUS);
     p2.setText("%md hello world2");
     p2.setTitle("my title2");
@@ -90,6 +97,7 @@ public class VFSNotebookRepoTest {
     notebookRepo.move(note2.getId(), note2.getPath(), "/my_project2/my_note2", AuthenticationInfo.ANONYMOUS);
 
     Note note3 = notebookRepo.get(note2.getId(), newPath, AuthenticationInfo.ANONYMOUS);
+    note3.setNoteParser(noteParser);
     assertEquals(note2, note3);
 
     // move folder
@@ -98,6 +106,7 @@ public class VFSNotebookRepoTest {
     assertEquals(2, noteInfos.size());
 
     Note note4 = notebookRepo.get(note3.getId(), "/my_project3/my_project2/my_note2", AuthenticationInfo.ANONYMOUS);
+    note4.setNoteParser(noteParser);
     assertEquals(note3, note4);
 
     // remote note1
@@ -106,12 +115,13 @@ public class VFSNotebookRepoTest {
   }
 
   @Test
-  public void testNoteNameWithColon() throws IOException {
+  void testNoteNameWithColon() throws IOException {
     assertEquals(0, notebookRepo.list(AuthenticationInfo.ANONYMOUS).size());
 
     // create note with colon in name
     Note note1 = new Note();
     note1.setPath("/my_project/my:note1");
+    note1.setNoteParser(noteParser);
     Paragraph p1 = note1.insertNewParagraph(0, AuthenticationInfo.ANONYMOUS);
     p1.setText("%md hello world");
     p1.setTitle("my title");
@@ -121,7 +131,7 @@ public class VFSNotebookRepoTest {
   }
 
   @Test
-  public void testUpdateSettings() throws IOException {
+  void testUpdateSettings() throws IOException {
     List<NotebookRepoSettingsInfo> repoSettings = notebookRepo.getSettings(AuthenticationInfo.ANONYMOUS);
     assertEquals(1, repoSettings.size());
     NotebookRepoSettingsInfo settingInfo = repoSettings.get(0);
